// ST7735TestMain.c
// Runs on TM4C1294
// Test the functions in ST7735.c by printing basic
// patterns to the LCD.
// Daniel Valvano
// May 14, 2014

/* This example accompanies the book
   "Embedded Systems: Real Time Interfacing to Arm Cortex M Microcontrollers",
   ISBN: 978-1463590154, Jonathan Valvano, copyright (c) 2014

 Copyright 2014 by Jonathan W. Valvano, valvano@mail.utexas.edu
    You may use, edit, run or distribute this file
    as long as the above copyright notice remains
 THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 VALVANO SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 For more information about my classes, my research, and my books, see
 http://users.ece.utexas.edu/~valvano/
 */

// Backlight (pin 10) connected to +3.3 V
// MISO (pin 9) unconnected 
// SCK (pin 8) connected to PA2 (SSI0Clk)
// MOSI (pin 7) connected to PA4 (SSI0XDAT0/SSI0Tx)
// TFT_CS (pin 6) connected to PA3 (SSI0Fss)
// CARD_CS (pin 5) unconnected
// Data/Command (pin 4) connected to PA6 (GPIO)
// RESET (pin 3) connected to PA7 (GPIO)
// VCC (pin 2) connected to +3.3 V
// Gnd (pin 1) connected to ground
#include <stdint.h>
#include <stdio.h>
#include "ST7735.h"
#include "PLL.h"

#define GPIO_PORTJ0             (*((volatile uint32_t *)0x40060004))
#define GPIO_PORTJ_DIR_R        (*((volatile uint32_t *)0x40060400))
#define GPIO_PORTJ_AFSEL_R      (*((volatile uint32_t *)0x40060420))
#define GPIO_PORTJ_PUR_R        (*((volatile uint32_t *)0x40060510))
#define GPIO_PORTJ_DEN_R        (*((volatile uint32_t *)0x4006051C))
#define GPIO_PORTJ_AMSEL_R      (*((volatile uint32_t *)0x40060528))
#define GPIO_PORTJ_PCTL_R       (*((volatile uint32_t *)0x4006052C))
#define SYSCTL_RCGCGPIO_R       (*((volatile uint32_t *)0x400FE608))
#define SYSCTL_RCGCGPIO_R8      0x00000100  // GPIO Port J Run Mode Clock
                                            // Gating Control
#define SYSCTL_PRGPIO_R         (*((volatile uint32_t *)0x400FEA08))
#define SYSCTL_PRGPIO_R8        0x00000100  // GPIO Port J Peripheral Ready

// Omit the horse picture when using the free compiler.
// An image that fills the whole ST7735 display requires
// 160x128x2 = 40,960 bytes, which exceeds the free limit.
#define FREE  1

// test image
// [blue] [green]
// [red ] [white]
const uint16_t Test[] = {
  0x001F, 0xFFFF, 0xF800, 0x07E0
};
// test image2
// [red]   [yellow]  [green]   [blue]    [black]
// [red]   [yellow]  [green]   [blue]    [white]
// [red]   [yellow]  [green]   [blue]    [black]
// [red]   [yellow]  [green]   [blue]    [white]
// [red]   [yellow]  [green]   [blue]    [black]
// [black] [75%grey] [50%grey] [25%grey] [white]
const uint16_t Test2[] = {
  0x0000, 0x4208, 0x8410, 0xC618, 0xFFFF,
  0x001F, 0x07FF, 0x07E0, 0xF800, 0x0000,
  0x001F, 0x07FF, 0x07E0, 0xF800, 0xFFFF,
  0x001F, 0x07FF, 0x07E0, 0xF800, 0x0000,
  0x001F, 0x07FF, 0x07E0, 0xF800, 0xFFFF,
  0x001F, 0x07FF, 0x07E0, 0xF800, 0x0000
};
// 40x160 Longhorn logo
const uint16_t Logo[] = {
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x632D, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x4A49, 0x5AAB, 0x8410, 0xCE59,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x5AAB, 0xE73C, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x2966, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x2966, 0xE73C, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x738E, 0xF79E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xCE59, 0xAD75, 0x632D,
 0x20E4, 0x20E4, 0x20E4, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x39C7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xC639, 0x2966, 0x20E4, 0x20E4, 0xE73C, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xD6BA, 0x20E4, 0x20E4, 0x9CF3, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x8410, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8C72, 0x20E4, 0x632D, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xE71C, 0x20E4, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x39C7, 0x4A49, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xF79E, 0x20E4, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0x20E4, 0x9472, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD75, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0x5AAB, 0x20E4, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9CF3, 0x20E4, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xD6BA, 0x2966, 0x20E4, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF79E, 0x9472, 0x20E4, 0x20E4, 0xAD75, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x2966, 0x632D, 0x9472, 0x9472, 0x9472, 0x9472,
 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x5AAB, 0x4A49, 0x20E4, 0x20E4,
 0x2966, 0xBDD7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x4A49, 0x9CF3, 0xF79E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x20E4, 0x8410, 0x9472, 0xAD75, 0xCE59, 0xCE59,
 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x4A49, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x5AAB, 0x5AAB, 0x5AAB, 0x4A49, 0x20E4, 0x39C7, 0xD6BA,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x738E, 0xE73C, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0x8C72, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8410, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xF79E, 0x2966, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x39C7, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472,
 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x738E, 0x2966, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x39C7, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472,
 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x39C7, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xF79E, 0x39C7, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xE77F, 0x9E1E, 0xF7BF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xE71C, 0xF79E, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0x447C, 0x139B, 0x7D9D, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x139B, 0x139B, 0x54BC, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x20E4, 0xF79E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0x139B, 0x139B, 0x54BC, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x8410, 0xE73C, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x139B, 0x139B, 0x23FB, 0xFFFF, 0xFFFF,
 0xFFFF, 0x5AAB, 0x5AAB, 0x39C7, 0x20E4, 0x20E4, 0x39C7, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0x343C, 0x139B, 0x139B, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x54BC, 0x139B, 0x139B, 0xC6FE, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0x7D9D, 0x139B, 0x139B, 0x9E1E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAE5E, 0x139B, 0x139B, 0x343C, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xF7BF, 0x139B, 0x139B, 0x139B, 0x8DDD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x5CFD, 0x139B, 0x139B, 0x23FB,
 0xF7BF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xC6FE, 0x139B, 0x139B, 0x139B, 0x64FD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x54BC, 0x139B, 0x139B,
 0x139B, 0x7D9D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xE77F, 0x139B, 0x139B, 0x139B, 0x139B, 0x7D9D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8DDD, 0x139B,
 0x139B, 0x139B, 0x139B, 0x6D5D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x447C, 0x139B, 0x139B, 0x139B, 0x139B, 0xAE5E, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD73F,
 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0xC6FE, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8DDD, 0x139B, 0x139B, 0x139B, 0x139B, 0x343C, 0xF7BF, 0xF7BF,
 0x23FB, 0x343C, 0xD73F, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xF7BF, 0x23FB, 0x139B, 0x139B, 0x139B, 0x139B, 0x9E1E, 0xC6FE, 0x139B, 0x139B, 0x343C, 0xF7BF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8DDD, 0x139B, 0x139B, 0x139B, 0x139B, 0x343C, 0x6D3D,
 0x139B, 0x139B, 0x139B, 0xAE5E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xF7BF, 0x23FB, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x8DDD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x6D3D, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x8DDD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xE77F, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0xAE5E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x447C, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0xE77F, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0x8DDD, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x64FD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x54BC, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x139B, 0x54BC, 0xAE5E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0x8DDD, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x343C, 0xAE5E,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x23FB, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x343C, 0xC6FE, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD73F,
 0xC6FE, 0xC6FE, 0xF7BF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xF7BF, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x343C, 0x8DDD, 0xAE5E, 0x7D9D, 0x343C, 0x139B, 0x139B, 0x139B, 0x139B, 0x9E1E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xC6FE, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x139B, 0x64FD, 0xF7BF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xC6FE, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x64FD, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9E1E, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x8DDD, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x54BC, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAE5E, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x447C, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x8DDD, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xC6FE, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x64FD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xD73F, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x6D5D, 0xF7BF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x23FB, 0x7D9D, 0x8DDD, 0x7D9D, 0x343C, 0x139B,
 0x139B, 0x139B, 0x139B, 0x9E1E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0x23FB, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x23FB, 0x8DDD, 0xF7BF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD73F, 0xC6FE, 0xC6FE, 0xE77F, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x6D3D, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x6D5D, 0xE77F, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xE77F, 0x447C, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x6D5D, 0xE77F, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9E1E, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x343C, 0xC6FE, 0xF7BF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0x8DDD, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0xD73F, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x447C, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x7D9D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xD73F, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x54BC, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x6D3D, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B,
 0x139B, 0x139B, 0x139B, 0x54BC, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xE77F, 0x139B, 0x139B, 0x139B, 0x139B, 0x139B, 0x64FD, 0x139B, 0x139B, 0x139B, 0x6D5D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8DDD, 0x139B, 0x139B, 0x139B, 0x139B, 0x343C, 0xF7BF,
 0x139B, 0x139B, 0x139B, 0xAE5E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xF7BF, 0x23FB, 0x139B, 0x139B, 0x139B, 0x139B, 0xAE5E, 0xFFFF, 0x343C, 0x139B, 0x6D5D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7D9D, 0x139B, 0x139B, 0x139B, 0x139B, 0x54BC, 0xFFFF, 0xFFFF,
 0xD73F, 0xC6FE, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xC6FE,
 0x139B, 0x139B, 0x139B, 0x139B, 0x23FB, 0xE77F, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x343C, 0x139B, 0x139B, 0x139B, 0x23FB, 0xD73F, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8DDD, 0x139B,
 0x139B, 0x139B, 0x139B, 0xAE5E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xE77F, 0x23FB, 0x139B, 0x139B, 0x139B, 0xAE5E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x6D3D, 0x139B, 0x139B,
 0x139B, 0x9E1E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF7BF, 0x139B, 0x139B, 0x139B, 0x54BC, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9E1E, 0x139B, 0x139B, 0x139B,
 0xE77F, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x447C, 0x139B, 0x139B, 0x7D9D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x139B, 0x139B, 0x139B, 0xE77F,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xC6FE, 0x139B, 0x139B, 0x54BC, 0xFFFF, 0xFFFF, 0xAD75, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xC639, 0xE73C, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xB69E, 0x139B, 0x139B, 0x7D9D, 0xFFFF,
 0xFFFF, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8C72, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0x8DDD, 0x139B, 0x139B, 0x8DDD, 0xFFFF, 0xFFFF, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0x738E, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8DDD, 0x139B, 0x139B, 0xB6BE, 0xFFFF,
 0xFFFF, 0x20E4, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x2966, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0x8DDD, 0x139B, 0x139B, 0xC6FE, 0xFFFF, 0xFFFF, 0x20E4, 0x20E4, 0x4A49, 0x5AAB, 0x5AAB, 0x5AAB, 0x5AAB,
 0x5AAB, 0x5AAB, 0x5AAB, 0x5AAB, 0x5AAB, 0x5AAB, 0x5AAB, 0x5AAB, 0x5AAB, 0x5AAB, 0x5AAB, 0x5AAB, 0x5AAB, 0x5AAB, 0x5AAB, 0x5AAB,
 0x5AAB, 0x5AAB, 0x2966, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xB69E, 0x139B, 0x139B, 0xD73F, 0xFFFF,
 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xE77F, 0x23FB, 0x447C, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x738E, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59,
 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0x4A49, 0x4A49, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59,
 0xCE59, 0xBDD7, 0x4A49, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x9472, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x52AB, 0x5AAB, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xC639, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x9472, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x52AB, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xC639, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x9472, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x4A49, 0x5AAB, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xC639, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x9472, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF79E, 0x20E4, 0x20E4, 0xF79E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xC639, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x9472, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x738E, 0x20E4, 0x20E4, 0x738E,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBDD7, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x632D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xAD55, 0x8410, 0x39C7, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x39C7, 0x738E, 0xAD75, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0x8410, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59,
 0xCE59, 0xCE59, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF79E, 0x2966, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x738E, 0xCE59, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x632D, 0x20E4, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x632D, 0x5AAB, 0x5AAB, 0x5AAB, 0x5AAB, 0x2966, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF79E, 0x4A49, 0x20E4, 0x20E4, 0x39C7, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9472, 0x2966,
 0x2966, 0x8410, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9CF3, 0x738E, 0xBDD7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0xAD75, 0x9472, 0x9472, 0x9472, 0x9472, 0xAD75, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x738E, 0x2966, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x2966, 0x738E, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xE71C, 0x5AAB,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x632D, 0xF79E,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0x2966, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x2966, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x738E, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0xAD75, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0x8C72, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x2966, 0x632D, 0x9472, 0xCE59, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xCE59, 0xBDD7, 0x8410, 0x39C7, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xC639, 0x20E4, 0x20E4, 0x20E4, 0x39C7, 0xAD75,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xC639, 0x5AAB, 0x20E4,
 0x20E4, 0x20E4, 0x2966, 0xF79E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0x39C7, 0x20E4, 0x2966, 0x9CF3, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9CF3, 0x20E4, 0x20E4, 0x20E4, 0x9472, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0x20E4, 0x2966, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xAD55, 0x20E4, 0x20E4, 0x2966, 0xF79E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x4A49, 0x20E4, 0xAD75, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8410, 0x20E4, 0x20E4, 0xBDD7, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xF79E, 0x2966, 0x20E4, 0x738E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xE71C, 0x20E4, 0xE73C, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF79E, 0x20E4, 0x9CF3, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBDD7, 0x20E4, 0x9472, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xBDD7, 0x20E4, 0xE73C, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x738E, 0x2966, 0xF79E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x5AAB, 0x738E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xE71C, 0x20E4, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xBDD7, 0x2966, 0xE73C, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0x39E7, 0x20E4, 0x632D, 0xF79E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x2966, 0xAD75, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0x20E4, 0x20E4, 0x20E4, 0x2966, 0xAD75, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA,
 0x2966, 0xAD75, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x39C7, 0x9CF3, 0xE73C, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xC639, 0x39C7, 0xAD75, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x632C, 0xFFFF, 0xFFFF, 0xE71C, 0xCE59, 0xCE59, 0xCE59, 0x9CF3,
 0x9472, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xC639, 0x5AAB, 0xD6BA,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF79E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xAD75, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xC639, 0xE73C, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0x8C72, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x738E, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xD6BA, 0x2966, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x20E4, 0x5AAB, 0x5AAB, 0x8410, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472,
 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x8410, 0x5AAB, 0x5AAB, 0x2966, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x20E4, 0x20E4, 0x20E4, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x738E, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0x4A49, 0x4A49, 0xCE59,
 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xAD75, 0x4A49, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x9472, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x52AB, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xBDD7, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x9472, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x52AB, 0x5AAB, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xC639, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x9472, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x4A49, 0x5AAB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xC639, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x9472, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF79E, 0x20E4, 0x20E4, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xC639, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x9472, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x738E, 0x20E4, 0x20E4, 0x738E, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xBDD7, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x632D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0x8410, 0x39C7, 0x20E4, 0x20E4, 0x20E4, 0x20E4,
 0x39C7, 0x8410, 0xAD75, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8410, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x20E4, 0x20E4, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xAD55, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0x9472, 0xAD75, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xF79E, 0x39C7, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0x20E4, 0x20E4, 0x2966, 0x8410, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x632D, 0x20E4, 0x20E4, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x5AAB, 0x5AAB, 0x5AAB, 0x5AAB, 0x4A49, 0x2966, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF79E,
 0x5AAB, 0x20E4, 0x20E4, 0x39C7, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9CF3, 0x2966, 0x2966, 0x738E, 0xCE59, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9CF3, 0x738E, 0xBDD7,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF,
 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF
};
// 120x160 horse picture
#if (FREE == 0)
const uint16_t Calvin[] = {
 0xCD94, 0xCDB5, 0xCDB5, 0xCDB5, 0xCDB5, 0xCDB5, 0xCDB5, 0xD5D5, 0xD5B5, 0xD5B5, 0xD5D5, 0xD5D5, 0xD5D5, 0xCDD5, 0xD5D5, 0xCDB5,
 0xCDB5, 0xCDB5, 0xCDB5, 0xCDB4, 0xCDB4, 0xCDB4, 0xCDB4, 0xCD94, 0xCDB4, 0xCDB4, 0xCD94, 0xCDB4, 0xCDB4, 0xC594, 0xC594, 0xC594,
 0xB512, 0xC594, 0xC574, 0xBD33, 0xACD1, 0x9C4F, 0x9C91, 0x734C, 0x734C, 0x4A69, 0x4A48, 0x4208, 0x3A08, 0x3A08, 0x4249, 0x3A49,
 0x3208, 0x3A28, 0x31C7, 0x3A28, 0x31C7, 0x29C6, 0x31E8, 0x31E7, 0x3186, 0x29A6, 0x3186, 0x29C6, 0x3AA8, 0x3288, 0x3ACA, 0x52CA,
 0x5B4C, 0x73CD, 0xC658, 0x5B0B, 0xCEBA, 0xC679, 0xB5F7, 0xB618, 0xA575, 0x94D3, 0x73F0, 0x5B2D, 0x39E7, 0x2965, 0x1082, 0x0862,
 0x0061, 0x0842, 0x0862, 0x1903, 0x3206, 0x3247, 0x21E5, 0x19C5, 0x19E6, 0x19E7, 0x2A69, 0x1A07, 0x4B0C, 0x3A49, 0x5B0C, 0x5B0B,
 0x6B2C, 0x5ACA, 0x62EB, 0x62EB, 0x630C, 0x5ACB, 0x5AAA, 0x62EB, 0x62EB, 0x62EB, 0x62EB, 0x5ACB, 0x5ACA, 0x630B, 0x5AAA, 0x5A8A,
 0x62EB, 0x5ACB, 0x5ACB, 0x5ACA, 0x632C, 0x6B2D, 0x6B2C, 0x630B, 0xCDB5, 0xCDB5, 0xCDB5, 0xCDB5, 0xCDB5, 0xCDB5, 0xD5D5, 0xD5D5,
 0xD5D6, 0xD5D5, 0xD5D6, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5B5, 0xCDB5, 0xCDB5, 0xCDB4, 0xCDB5, 0xCDB4, 0xCDB4, 0xCDB4,
 0xCDB4, 0xCDB4, 0xCD94, 0xC594, 0xCDB4, 0xCDB4, 0xC594, 0xC594, 0xA46F, 0xC573, 0xC594, 0xB512, 0x83AD, 0xA4D2, 0x83AD, 0x6B0B,
 0x9450, 0x4A89, 0x4A48, 0x4208, 0x4208, 0x4228, 0x4228, 0x4249, 0x3A28, 0x39E7, 0x31C7, 0x3208, 0x3207, 0x3207, 0x31E8, 0x31C7,
 0x2945, 0x5B0B, 0x39E7, 0x4268, 0x42A9, 0x42EA, 0x4AEB, 0x7BEF, 0x73CF, 0x94F2, 0xCEBA, 0xC679, 0xB618, 0xBE38, 0xADD7, 0x94F3,
 0x8CD3, 0x7C51, 0x73F0, 0x52EB, 0x52AA, 0x2124, 0x0841, 0x0821, 0x0000, 0x0821, 0x1062, 0x0841, 0x18C4, 0x2145, 0x29A6, 0x21C6,
 0x2247, 0x2AA9, 0x2207, 0x2A69, 0x428A, 0x532C, 0x5AEB, 0x630C, 0x6B2C, 0x62EB, 0x6B2C, 0x62EB, 0x62EB, 0x5ACB, 0x5ACB, 0x6B4D,
 0x5AAA, 0x5AAA, 0x5ACA, 0x62EB, 0x5ACB, 0x5AAA, 0x62CB, 0x62EB, 0x5ACA, 0x5ACB, 0x62EB, 0x5ACB, 0x6B4D, 0x736D, 0x734D, 0x5ACB,
 0xCDB5, 0xCDB5, 0xD5B5, 0xD5B5, 0xD5D5, 0xD5D5, 0xD5D5, 0xCDB5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5F6, 0xD5D5, 0xD5D5,
 0xD5D5, 0xCDB5, 0xCDB5, 0xCDB5, 0xCDD5, 0xCDB5, 0xCDB4, 0xCDB4, 0xCDB4, 0xCDB4, 0xCDB4, 0xCDB4, 0xCD94, 0xCDB4, 0xCDB4, 0xCDB4,
 0x72E9, 0xC594, 0xBD53, 0x9C4F, 0x83EE, 0x83CD, 0x944F, 0x8BEE, 0x7BAD, 0x4248, 0x5289, 0x4A28, 0x4A28, 0x4208, 0x4228, 0x4228,
 0x3A07, 0x31C6, 0x3A07, 0x3208, 0x3208, 0x3208, 0x3A08, 0x31C7, 0x4228, 0x4A89, 0x4249, 0x4288, 0x6BCE, 0x532B, 0x530C, 0x4269,
 0xCEFB, 0xC679, 0xB617, 0xADD7, 0x9CF3, 0x8471, 0x9D34, 0x94F3, 0x94F3, 0x6B8E, 0x632C, 0x52AA, 0x4A69, 0x52CA, 0x31E7, 0x1904,
 0x10A2, 0x0862, 0x1082, 0x2945, 0x2986, 0x10C3, 0x08A4, 0x10E5, 0x2227, 0x330A, 0x2248, 0x32AA, 0x2A08, 0x532C, 0x4AAA, 0x632C,
 0x6B4C, 0x630B, 0x630B, 0x62EB, 0x5AA9, 0x5269, 0x632C, 0x6B2C, 0x630B, 0x5ACA, 0x62EB, 0x5AAA, 0x62EB, 0x5AAA, 0x62EB, 0x6B0C,
 0x5A8A, 0x5ACB, 0x5ACA, 0x630C, 0x632C, 0x6B4D, 0x6B4D, 0x528A, 0xCDB5, 0xCDB5, 0xD5B5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5,
 0xD5D5, 0xD5D5, 0xD5F6, 0xD5F6, 0xD5F6, 0xD5F6, 0xD5D5, 0xD5D5, 0xCDD5, 0xD5B5, 0xD5B5, 0xD5D5, 0xD5D5, 0xCDB5, 0xCDB4, 0xCDB5,
 0xCDB4, 0xCDD5, 0xCDB4, 0xCDB4, 0xCDB5, 0xACB0, 0xCDB4, 0xCD94, 0x83AC, 0xC5B4, 0xC594, 0xACF1, 0x838C, 0x8BEE, 0x83CD, 0x6B2B,
 0x8C0F, 0x4A69, 0x5AAA, 0x41C7, 0x4228, 0x4208, 0x4249, 0x4A69, 0x31E7, 0x39E7, 0x3A07, 0x31E7, 0x3A08, 0x3A28, 0x3A29, 0x4A8A,
 0x52EB, 0x6B8E, 0x6B6E, 0x634D, 0x532B, 0x3A68, 0xDF7D, 0xC699, 0xB5F7, 0xB5F7, 0x94D3, 0x94D2, 0xA595, 0xA596, 0x8D14, 0x7C71,
 0x6BEF, 0x6BAE, 0x52CB, 0x5ACB, 0x4A49, 0x4228, 0x39E7, 0x3A07, 0x4228, 0x3A08, 0x31A6, 0x2145, 0x18E4, 0x1082, 0x0862, 0x10C4,
 0x08C3, 0x2A89, 0x32CA, 0x32AA, 0x4AEB, 0x4289, 0x5B2C, 0x632C, 0x632C, 0x632C, 0x630C, 0x632C, 0x5AA9, 0x62EB, 0x630C, 0x630C,
 0x5ACA, 0x62EB, 0x5ACA, 0x62EB, 0x5AAA, 0x62EB, 0x5AAA, 0x5AAA, 0x5AAA, 0x5ACA, 0x5AAA, 0x62EB, 0x630C, 0x736D, 0x734D, 0x62CB,
 0xCDB4, 0xD5B5, 0xD5D5, 0xD5B5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5F6, 0xD5F6, 0xD5F6, 0xD5F6, 0xD5F6, 0xD5F6, 0xD5D5,
 0xCDD5, 0xD5D5, 0xD5D5, 0xD5D5, 0xCDD5, 0xCDD5, 0xCDB4, 0xCDB5, 0xCDB5, 0xCDB5, 0xCDD4, 0xCDB4, 0xCDB4, 0x72E9, 0xCDB4, 0xCDB4,
 0xBD53, 0xCDD4, 0xC594, 0x6B0A, 0x736C, 0x7B6C, 0x7BAD, 0x736D, 0x8410, 0x4A6A, 0x4228, 0x4A27, 0x41E7, 0x4228, 0x39E7, 0x4269,
 0x3A28, 0x3A48, 0x3A28, 0x3A28, 0x4249, 0x5B4C, 0x7C50, 0x4AAA, 0x73CE, 0x8432, 0x632F, 0x5AED, 0x426A, 0xADF7, 0xBE38, 0xA575,
 0x94F3, 0xA555, 0x8CB2, 0x9D54, 0xADB6, 0x73EF, 0x8CD3, 0x7410, 0x73EF, 0x634C, 0x52AA, 0x52AA, 0x4248, 0x31C7, 0x31A6, 0x2965,
 0x2965, 0x2965, 0x2104, 0x18C3, 0x18E4, 0x0883, 0x0062, 0x08A3, 0x00A3, 0x2268, 0x2A69, 0x2A89, 0x4AEB, 0x4AAA, 0x632C, 0x5AEB,
 0x6B4C, 0x630B, 0x6B2C, 0x630B, 0x5289, 0x630C, 0x630B, 0x62EB, 0x62CA, 0x62EB, 0x630B, 0x5ACA, 0x5AEB, 0x62EB, 0x62EB, 0x5AAA,
 0x5AAA, 0x5AAA, 0x630B, 0x62CB, 0x5ACB, 0x630C, 0x6B4D, 0x5ACB, 0xD5B5, 0xD5B5, 0xD5B5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5,
 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F6, 0xD5F6, 0xD5F6, 0xD5F6, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5B4, 0xD5D5, 0xCDD5, 0xCDD5, 0xCDD5,
 0xCDB5, 0xCDD5, 0xCDD5, 0xCDD5, 0xCDD4, 0x6288, 0xCDB5, 0xCDB4, 0xDE77, 0xC5B4, 0xACF2, 0x9470, 0x6B4C, 0x6B2C, 0x7B8D, 0x5A8A,
 0x5ACB, 0x4A8A, 0x4A69, 0x4A69, 0x3A28, 0x31C7, 0x3A08, 0x3A28, 0x3A48, 0x4289, 0x4269, 0x5B0C, 0x9D34, 0x7C2F, 0x7C50, 0x94D3,
 0x94F3, 0x634E, 0x6B70, 0x2127, 0x3A09, 0x52EB, 0x84B1, 0xA595, 0xADD6, 0x9513, 0x8CB2, 0xA575, 0xADB6, 0x7C51, 0x8CB2, 0x73F0,
 0x73CF, 0x5B2C, 0x52EB, 0x4AAA, 0x4A69, 0x4228, 0x31A6, 0x2945, 0x2965, 0x3165, 0x3186, 0x2145, 0x2104, 0x18E4, 0x0882, 0x0862,
 0x08A3, 0x2A48, 0x32CA, 0x2A48, 0x530C, 0x530B, 0x632C, 0x6B4D, 0x632C, 0x630B, 0x632B, 0x6B2C, 0x62EB, 0x6B2C, 0x5ACB, 0x632C,
 0x62EB, 0x62EB, 0x5289, 0x5ACA, 0x62EB, 0x630B, 0x5AAA, 0x5ACA, 0x5ACB, 0x630B, 0x62EB, 0x5AAA, 0x528A, 0x632C, 0x738E, 0x6B2C,
 0xD5B5, 0xD5B5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5,
 0xD5F5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xCDD5, 0xD5D5, 0xD5D5, 0xCDD5, 0xCDD5, 0xCDD5, 0xCDD5, 0xCDB4, 0xBD32, 0xC5B4, 0xCDD5,
 0xC594, 0xA4D2, 0x736C, 0x632B, 0x632C, 0x5AEA, 0x738D, 0x736D, 0x632C, 0x4A69, 0x3A28, 0x4269, 0x3A69, 0x3A48, 0x3A48, 0x4269,
 0x52EB, 0x636C, 0xA575, 0x94F2, 0x8491, 0x9513, 0x8CD2, 0x94F3, 0xC67A, 0x636E, 0x528C, 0x526C, 0x630E, 0x3A08, 0x9D14, 0xADD6,
 0xA554, 0x8CD2, 0x94F3, 0xADB6, 0x8CD3, 0x94D3, 0x8CD3, 0x8471, 0x73CF, 0x73CF, 0x634D, 0x5B0B, 0x5B0B, 0x52CB, 0x4249, 0x4208,
 0x31A6, 0x31A6, 0x3186, 0x2966, 0x2125, 0x18C3, 0x1082, 0x0862, 0x0862, 0x2207, 0x32C9, 0x3249, 0x29E7, 0x5B2C, 0x52CA, 0x6B6D,
 0x62EB, 0x630B, 0x632B, 0x62EA, 0x630B, 0x62EB, 0x630B, 0x630B, 0x630B, 0x62EB, 0x62EB, 0x630B, 0x630C, 0x5AAA, 0x5289, 0x5ACB,
 0x5AAA, 0x6B2C, 0x62EB, 0x5AAA, 0x6B4C, 0x5AEB, 0x632C, 0x736D, 0xD5B5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5F5,
 0xD5D5, 0xD5F6, 0xD5F6, 0xD5F6, 0xD5F5, 0xD615, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xCDD5, 0xD5D5, 0xD5D5,
 0xCDD5, 0xCDD5, 0xCDD5, 0xCDD5, 0xCDD5, 0xEE98, 0xCDB4, 0xCDD5, 0xC5B5, 0x8C30, 0x7B8D, 0x8C2F, 0x83EF, 0x738D, 0x632B, 0x5B0B,
 0x5B0B, 0x4A89, 0x4AAA, 0x4ACA, 0x4A8A, 0x4269, 0x4AAA, 0x6B8E, 0xB5F7, 0xADB6, 0x8CD2, 0x9513, 0x9D55, 0x9514, 0xB618, 0xEFBE,
 0xC659, 0x6B8F, 0x52AC, 0xC61A, 0x2947, 0x4229, 0x2965, 0x9D54, 0x7C10, 0x94F3, 0x9D34, 0x7C10, 0x9D14, 0x7C30, 0x7BEF, 0x6B6D,
 0x636D, 0x5B4C, 0x52EB, 0x52EB, 0x5B2C, 0x52EB, 0x6B8E, 0x5B0C, 0x634C, 0x4A8A, 0x4208, 0x31A7, 0x2945, 0x0841, 0x0861, 0x0861,
 0x0062, 0x19A6, 0x330A, 0x2A28, 0x3A49, 0x530C, 0x6B8D, 0x632B, 0x632C, 0x630B, 0x6B2C, 0x630B, 0x6B6C, 0x6B2C, 0x5AEB, 0x630B,
 0x6B4C, 0x6B0B, 0x62EB, 0x630C, 0x630B, 0x630B, 0x6B2C, 0x5ACB, 0x5AA9, 0x62EB, 0x5AAA, 0x5ACB, 0x62EC, 0x62EC, 0x630C, 0x738E,
 0xD5D5, 0xD5D4, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F6, 0xD5F6, 0xD5F6,
 0xD5F5, 0xD5D5, 0xD5F5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xCDD5, 0xCDD5, 0xCDD5, 0xCDD5, 0xCDB4, 0xD5F5, 0xCDB5, 0xAD12,
 0x83CE, 0xAD54, 0x5289, 0x6B4C, 0x5AAA, 0x6B8D, 0x52AA, 0x632C, 0x5AEB, 0x4269, 0x4ACA, 0x5B0B, 0x94D3, 0x740F, 0xCEBA, 0xADB6,
 0xA575, 0x9D54, 0x9D75, 0xA596, 0xA5B6, 0xADD7, 0xCEDA, 0xBE38, 0xADD6, 0x94D3, 0x5B0D, 0x52AD, 0x2947, 0x4A6B, 0x2146, 0x8C92,
 0x94F3, 0x94D3, 0x6BAE, 0x8430, 0x8C91, 0x73CF, 0x5AEB, 0x52AA, 0x52AA, 0x528A, 0x4A69, 0x4AAA, 0x52AA, 0x6B8D, 0x6B8D, 0x6B8D,
 0x6B8E, 0x52AA, 0x4A69, 0x31C7, 0x2925, 0x0861, 0x0020, 0x0862, 0x0041, 0x2A27, 0x3269, 0x3A89, 0x5B4D, 0x52EB, 0x636D, 0x6B6D,
 0x6B4C, 0x6B6C, 0x630B, 0x62EA, 0x62EA, 0x5AAA, 0x6B2C, 0x62EB, 0x6B2C, 0x6B2C, 0x5ACA, 0x62EB, 0x5AEB, 0x630C, 0x5AAA, 0x62EB,
 0x630B, 0x62EB, 0x62EB, 0x5ACA, 0x6B2C, 0x62EB, 0x6B2C, 0x632C, 0xD5B4, 0xD5D5, 0xD5B5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5F5,
 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xDE16, 0xD5F6, 0xD5F6, 0xDE16, 0xD5F6, 0xD5F5, 0xD5F5, 0xD5D5, 0xD5F5, 0xD5D5, 0xD5D5, 0xD5D5,
 0xCDD5, 0xCDD5, 0xCDD5, 0xCDD5, 0xCDD4, 0xCDB4, 0xCDF6, 0x9470, 0xA4F3, 0x632B, 0x4A89, 0x52AA, 0x4AA9, 0x52CA, 0x5B0B, 0x6B6D,
 0x73AE, 0x8491, 0x9533, 0x9D54, 0xADD6, 0xADD6, 0xB617, 0xADD6, 0xA5B6, 0xADF7, 0x9D55, 0xADF7, 0xB618, 0xBE38, 0xA596, 0xA575,
 0x7430, 0x9D75, 0x7C31, 0x4A8C, 0x52CD, 0x0844, 0x10E5, 0x29C8, 0x9D33, 0x8471, 0x73EF, 0x73CF, 0x6B8E, 0x634C, 0x4AA9, 0x4248,
 0x4207, 0x41E7, 0x528A, 0x634C, 0x73CF, 0x7C10, 0x634C, 0x4207, 0x39C7, 0x4A48, 0x39C7, 0x2966, 0x10A3, 0x0841, 0x0041, 0x0041,
 0x0041, 0x1124, 0x3AAA, 0x4B0B, 0x3A89, 0x4289, 0x5B0B, 0x6B6C, 0x6B4C, 0x6B2C, 0x630B, 0x630B, 0x630B, 0x630C, 0x6B6D, 0x630C,
 0x630B, 0x5AAA, 0x5ACA, 0x630B, 0x630B, 0x6B2C, 0x62EB, 0x5ACA, 0x5AAA, 0x5AAA, 0x62EA, 0x630B, 0x5AAA, 0x6B4C, 0x630B, 0x6B4C,
 0xD5D4, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F6, 0xD5F6, 0xD5F5, 0xD5F6, 0xD616, 0xD5F6, 0xD616,
 0xD5F6, 0xD5F5, 0xD5D5, 0xD5F5, 0xD5F5, 0xD5F5, 0xCDD5, 0xD5F5, 0xD5F5, 0xCDD5, 0xCDD5, 0xCDD5, 0xCDD5, 0xCDD4, 0xA4B1, 0x62EB,
 0x5AEB, 0x52AA, 0x4A89, 0x636C, 0x4A48, 0x634C, 0x73AE, 0xB5B6, 0xA575, 0xB5F7, 0xADF7, 0xADF7, 0xBE79, 0xB5F7, 0xADF7, 0xADF7,
 0xA5B6, 0xA5D6, 0x9D96, 0xB638, 0xC69A, 0xADF7, 0x94F3, 0x8492, 0x9D34, 0xC69A, 0xB5F8, 0x52CC, 0x39CA, 0x18A6, 0x3A09, 0x10E3,
 0x5B0C, 0x73CE, 0x634C, 0x5B0B, 0x5B0C, 0x4248, 0x4227, 0x39C6, 0x39C6, 0x5289, 0x634D, 0x73CF, 0x5B2C, 0x52EB, 0x73CE, 0x2985,
 0x3186, 0x2965, 0x18C3, 0x0842, 0x1083, 0x0021, 0x0842, 0x1083, 0x0882, 0x08E3, 0x2A49, 0x3AAA, 0x42AA, 0x530B, 0x5B0B, 0x5B0B,
 0x6B4C, 0x73AD, 0x6B2B, 0x630B, 0x632B, 0x5B0B, 0x738E, 0x6B2C, 0x62EB, 0x5ACA, 0x62EB, 0x5AAA, 0x62EB, 0x630B, 0x62EB, 0x62EB,
 0x5ACA, 0x5ACA, 0x62EB, 0x5AA9, 0x630B, 0x632C, 0x738E, 0x62EB, 0xD5D4, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5F5, 0xD5F5, 0xD5F5, 0xDDF5,
 0xD616, 0xD5F6, 0xD5F6, 0xD616, 0xD5F6, 0xD616, 0xD616, 0xD616, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F6, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5,
 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5D5, 0xCDD5, 0xC594, 0x5AAA, 0x6B2C, 0x4A28, 0x5ACA, 0x5AEB, 0x94D2, 0xA595, 0xADB6, 0xB618,
 0xB638, 0xB618, 0xBE59, 0xB638, 0xAE17, 0xAE18, 0xADF7, 0xADF7, 0x9D96, 0xBE79, 0xB639, 0xB618, 0xB638, 0x84D3, 0xA596, 0xA5D7,
 0xB618, 0xADD7, 0xB618, 0x632E, 0x630F, 0x3169, 0x10A4, 0x18E5, 0x1924, 0x634D, 0x634C, 0x5B2B, 0x52CA, 0x39E7, 0x39A6, 0x39C6,
 0x39E7, 0x52AA, 0x6B6D, 0x52CA, 0x5B2C, 0x4A69, 0x39E7, 0x52CB, 0x39C6, 0x18E3, 0x1062, 0x0842, 0x10A3, 0x0862, 0x10A3, 0x0882,
 0x0862, 0x21C6, 0x328A, 0x4B0C, 0x4ACB, 0x52EB, 0x634C, 0x5B0B, 0x632C, 0x6B2C, 0x5AEA, 0x6B2B, 0x630B, 0x630C, 0x73AE, 0x6B4C,
 0x630B, 0x6B0B, 0x5289, 0x52AA, 0x62EC, 0x6B2C, 0x5ACA, 0x62CB, 0x5ACB, 0x62EB, 0x62EB, 0x630B, 0x6B2C, 0x6B2C, 0x5AAB, 0x62EB,
 0xD5B4, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5F5, 0xD5F5, 0xD5F6, 0xD5F5, 0xD5F5, 0xD5F6, 0xD5F6, 0xD5F6, 0xD5F6, 0xD5F6, 0xD5F6,
 0xD5F6, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5D5, 0xD5F5, 0xCDD5, 0xCDD5, 0x8BEE, 0x83AE,
 0x8C0F, 0x630B, 0x94F3, 0xAD96, 0xBE38, 0xBE59, 0xBE79, 0xBE38, 0xBE58, 0xB618, 0xB638, 0xB638, 0xAE38, 0xADF7, 0xA5B7, 0xB639,
 0xB659, 0xB638, 0xBE79, 0x8CD3, 0x8CF3, 0xAE18, 0xADF8, 0xADF7, 0xADF7, 0xB638, 0xADD7, 0xADD7, 0x420A, 0x39CA, 0x0864, 0x2126,
 0x10C4, 0x2986, 0x5B0B, 0x5B0C, 0x52CA, 0x4207, 0x39C6, 0x39E7, 0x4228, 0x6B8D, 0x634D, 0x5B0C, 0x73CF, 0x4229, 0x4249, 0x4A68,
 0x2986, 0x18E3, 0x1082, 0x0020, 0x0841, 0x1082, 0x0021, 0x10C3, 0x1924, 0x21E6, 0x428A, 0x4B2D, 0x4AEB, 0x4289, 0x52EB, 0x632C,
 0x632C, 0x6B6D, 0x630B, 0x630B, 0x62EA, 0x62EB, 0x6B6D, 0x738D, 0x630B, 0x5ACA, 0x5AAA, 0x5ACA, 0x630B, 0x6B2C, 0x5ACA, 0x62EA,
 0x5AAA, 0x62EB, 0x62EB, 0x630B, 0x5ACB, 0x632C, 0x632C, 0x630C, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5D5, 0xD5F5, 0xD5F5, 0xD5F6, 0xD5F5,
 0xD5F6, 0xD5F5, 0xD5F6, 0xD5F6, 0xD5F6, 0xD616, 0xDE16, 0xDE16, 0xD5F6, 0xD5F6, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5,
 0xD5F5, 0xD5F5, 0xD5D5, 0xD5D5, 0xD5D5, 0xCDD5, 0x49E6, 0x8C0E, 0x6B8D, 0xBE17, 0xADD7, 0xBE58, 0xBE59, 0xBE7A, 0xB659, 0xBE59,
 0xB638, 0xB638, 0xB638, 0xAE18, 0xA5D7, 0xAE18, 0xC6DB, 0xB638, 0x9D96, 0x8D14, 0x84B3, 0x8CD3, 0xBE79, 0xADF7, 0xA596, 0xB618,
 0xBE38, 0xB618, 0xB5F7, 0xA575, 0x5AEC, 0x4A4C, 0x18C6, 0x18E5, 0x2146, 0x10C3, 0x4248, 0x634C, 0x5AEB, 0x4227, 0x39E6, 0x3A07,
 0x4A89, 0x5B2C, 0x636C, 0x73AE, 0x6B8E, 0x3A08, 0x3A28, 0x39C7, 0x0841, 0x0020, 0x0020, 0x0821, 0x0841, 0x1082, 0x0861, 0x2104,
 0x2185, 0x2A27, 0x534D, 0x432C, 0x428A, 0x5B4C, 0x636D, 0x632C, 0x6B4C, 0x632B, 0x632B, 0x632B, 0x6B2B, 0x62EB, 0x5B0B, 0x6B4C,
 0x62EB, 0x5ACA, 0x630B, 0x62EB, 0x5ACB, 0x62EB, 0x5ACA, 0x5A89, 0x62EB, 0x632C, 0x736D, 0x62EA, 0x5ACA, 0x632C, 0x6B4D, 0x6B2C,
 0xD5D5, 0xD5D5, 0xD5F5, 0xD5D5, 0xD5D5, 0xD5F5, 0xD5F6, 0xD5F6, 0xD5F5, 0xD5F5, 0xD616, 0xD5F6, 0xDE16, 0xD616, 0xDE16, 0xDE16,
 0xD5F6, 0xD5F6, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F6, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xCDD5, 0xCDD5, 0x83EE, 0xBE17,
 0xADB7, 0xC67A, 0xBE59, 0xB639, 0xB659, 0xB639, 0xB639, 0xB659, 0xAE38, 0xADF8, 0xADF7, 0xADF8, 0xCF1C, 0xA596, 0x8D14, 0x9D75,
 0x84B2, 0xADF7, 0xADD7, 0x9D55, 0xA596, 0xADF8, 0xB618, 0xB618, 0xADB7, 0xA5B6, 0x8CD3, 0x8471, 0x6B8E, 0x2948, 0x3169, 0x0843,
 0x0884, 0x10C3, 0x2145, 0x73EF, 0x52CA, 0x4248, 0x4A69, 0x6B6D, 0x8450, 0x8450, 0x8471, 0x636D, 0x4269, 0x31C7, 0x2986, 0x31A7,
 0x10C3, 0x0020, 0x0841, 0x10A3, 0x0861, 0x1082, 0x10A2, 0x1903, 0x2A07, 0x326A, 0x4B0C, 0x3ACB, 0x52EC, 0x634D, 0x5B0B, 0x6B6C,
 0x6B4C, 0x6B4C, 0x630B, 0x6B2B, 0x736D, 0x632B, 0x634C, 0x6B4C, 0x630B, 0x62EB, 0x5AAA, 0x5ACA, 0x630B, 0x5ACB, 0x5ACA, 0x62EB,
 0x6B4C, 0x630C, 0x6B4D, 0x5ACA, 0x5AEB, 0x6B4D, 0x630C, 0x6B2C, 0xD5D5, 0xD5D5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F6, 0xD5F6,
 0xD5F6, 0xD5F5, 0xDE16, 0xD5F6, 0xDE16, 0xD616, 0xDE16, 0xDE16, 0xD616, 0xD5F6, 0xD5F5, 0xD5F6, 0xD5F6, 0xD5F5, 0xD5F5, 0xD5F6,
 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xCDF5, 0xC5F6, 0xBE17, 0xBE59, 0xBE7A, 0xBE79, 0xB639, 0xAE39, 0xAE38, 0xB638, 0xAE38, 0xAE18,
 0xA618, 0x9D96, 0xA5D8, 0x7C93, 0x9535, 0x9D76, 0x9514, 0xADD7, 0xAE19, 0xAE18, 0x9D75, 0xA596, 0xA5B6, 0xA576, 0x9514, 0xA5B7,
 0x9D35, 0x9D34, 0x8CB2, 0x7C10, 0x7C10, 0x52AC, 0x39EA, 0x1086, 0x2147, 0x0042, 0x1944, 0x31E7, 0x638D, 0x634C, 0x6BCF, 0x6BCF,
 0x73CF, 0x8C91, 0x73CE, 0x5B0B, 0x4A69, 0x2945, 0x2986, 0x2126, 0x10A3, 0x0882, 0x10C3, 0x1925, 0x18C3, 0x18C3, 0x2104, 0x2165,
 0x21E6, 0x3269, 0x42CA, 0x32AA, 0x5B2D, 0x632C, 0x632C, 0x6B4D, 0x6B6D, 0x632B, 0x6B4C, 0x632B, 0x6B2C, 0x6B2C, 0x6B4C, 0x62EA,
 0x6B2B, 0x62EA, 0x62EB, 0x62CB, 0x630C, 0x630B, 0x6B2C, 0x62EB, 0x5ACA, 0x5AEB, 0x630C, 0x6B2B, 0x630B, 0x630C, 0x632C, 0x7BAE,
 0xD5D5, 0xD5D5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD616, 0xDE16, 0xDE16, 0xD616, 0xDE16, 0xD616, 0xD616, 0xD616, 0xD616,
 0xD616, 0xD616, 0xD616, 0xD5F5, 0xD5F6, 0xD5F5, 0xD5F5, 0xD615, 0xD5F5, 0xD5F5, 0xD5F6, 0xCDD5, 0xCE37, 0xC658, 0xC69A, 0xC69A,
 0xBE9A, 0xAE19, 0xAE39, 0xADF8, 0xAE39, 0xB659, 0xB659, 0xA5F7, 0xADF8, 0xA5B7, 0xADD7, 0xA576, 0x9534, 0xA576, 0x7C10, 0x73EF,
 0x8491, 0xA596, 0x9D55, 0x8CD3, 0x94F3, 0x9D55, 0x9D75, 0x9D55, 0x8CB2, 0x7C51, 0x94F3, 0x8471, 0x8492, 0x6B8E, 0x5ACD, 0x20E7,
 0x0823, 0x0883, 0x10E3, 0x31A7, 0x8450, 0x634D, 0x7C30, 0x6BCF, 0x5B2C, 0x73CE, 0x4A89, 0x31E7, 0x39E7, 0x3A07, 0x3A08, 0x2144,
 0x10A3, 0x18E3, 0x2145, 0x2104, 0x2144, 0x2124, 0x1924, 0x2A06, 0x21E6, 0x3ACB, 0x2A49, 0x2A69, 0x532D, 0x634C, 0x6BAE, 0x6B6D,
 0x6B4C, 0x6B2C, 0x6B2C, 0x6B2C, 0x62EA, 0x630B, 0x736D, 0x736D, 0x630B, 0x62EB, 0x5ACA, 0x632C, 0x62EB, 0x630B, 0x5ACB, 0x62CB,
 0x5ACB, 0x5ACB, 0x5AAA, 0x6B2C, 0x62EB, 0x5AEB, 0x632C, 0x6B4D, 0xD5D5, 0xD5D5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD615, 0xD615, 0xD615,
 0xDE16, 0xDE16, 0xDE16, 0xDE16, 0xD616, 0xD616, 0xDE16, 0xD616, 0xD616, 0xD616, 0xD616, 0xD616, 0xD615, 0xD615, 0xD615, 0xD615,
 0xD5F5, 0xD5F5, 0xCDF5, 0xC5F7, 0xC679, 0xC6BA, 0xC69A, 0xC6BB, 0xAE19, 0xAE18, 0xAE19, 0xAE39, 0xAE59, 0xA5D7, 0x9D76, 0xBE59,
 0x8CB2, 0x73AE, 0x5ACB, 0x5AAB, 0x5289, 0x630C, 0x5AEB, 0x7BCF, 0x6BAE, 0xADB6, 0x94F4, 0x9D34, 0x94F3, 0x9514, 0x8CF3, 0x8492,
 0x73EF, 0x7C31, 0x6BCF, 0x73F0, 0x8451, 0x6BAF, 0x31A8, 0x2948, 0x0023, 0x31C9, 0x08A3, 0x2965, 0x52EB, 0x73EF, 0x634D, 0x4249,
 0x632C, 0x52AA, 0x31A6, 0x31A6, 0x31A6, 0x31A6, 0x2965, 0x1903, 0x2104, 0x2965, 0x2985, 0x2965, 0x2985, 0x29E6, 0x3267, 0x1184,
 0x2227, 0x328A, 0x3ACB, 0x3249, 0x530C, 0x6B8D, 0x634C, 0x632C, 0x6B6D, 0x6B4C, 0x630B, 0x630B, 0x630B, 0x5ACA, 0x6B2C, 0x6B4C,
 0x6B2C, 0x62EA, 0x62EB, 0x630B, 0x632B, 0x630B, 0x5ACA, 0x5AEA, 0x5ACB, 0x62EB, 0x630C, 0x62EB, 0x62EB, 0x62EB, 0x6B4C, 0x6B2C,
 0xD5D5, 0xD5D5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD616, 0xD616, 0xDE16, 0xD616, 0xD616, 0xDE16, 0xDE16, 0xD616, 0xD616, 0xDE16, 0xD616,
 0xD616, 0xD616, 0xD616, 0xD5F6, 0xD616, 0xD616, 0xD616, 0xD616, 0xD5F5, 0xCDF5, 0xBDF6, 0xCEBA, 0xC6DB, 0xC6BA, 0xC6DB, 0xBE7A,
 0xAE39, 0xAE39, 0xA5F8, 0x9DB7, 0x9556, 0x9555, 0xD6FB, 0xA555, 0x73AE, 0x630B, 0x5228, 0x1861, 0x1061, 0x18C3, 0x8431, 0x94D3,
 0xAD96, 0x9D14, 0xA534, 0x94D3, 0x8CB2, 0x8471, 0x7410, 0x7C51, 0x8CD3, 0x6BAE, 0x8492, 0x9514, 0x8472, 0x6BCF, 0x636E, 0x4A4C,
 0x18C6, 0x10C6, 0x10A4, 0x1904, 0x31C7, 0x4A8A, 0x31C7, 0x2145, 0x29A6, 0x4228, 0x3A07, 0x2985, 0x3185, 0x39C6, 0x2986, 0x29A6,
 0x31C6, 0x29E6, 0x2A27, 0x3A68, 0x42C9, 0x2A67, 0x2A87, 0x11A4, 0x19E6, 0x2227, 0x32AA, 0x2A48, 0x4AAA, 0x4228, 0x634D, 0x6B6D,
 0x6B2C, 0x6B6D, 0x6B2C, 0x632C, 0x6B2C, 0x62EB, 0x62EB, 0x6B4C, 0x6B2B, 0x5289, 0x632B, 0x630B, 0x62EA, 0x62CA, 0x5AEA, 0x5ACA,
 0x62EB, 0x5ACB, 0x6B2C, 0x6B2C, 0x62EB, 0x62EB, 0x6B4C, 0x6B4C, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F6, 0xD5F6, 0xDE16,
 0xDE16, 0xDE16, 0xDE16, 0xDE16, 0xD616, 0xDE16, 0xD616, 0xD616, 0xD616, 0xD616, 0xD616, 0xD616, 0xD616, 0xD616, 0xD5F6, 0xD616,
 0xD5F6, 0xC5F6, 0xCEBA, 0xC6DB, 0xBE9A, 0xC6DB, 0xB659, 0xBE5A, 0xA618, 0x9DD8, 0x8515, 0x84D4, 0x8CF4, 0xA595, 0xC638, 0xA513,
 0x94B2, 0x3185, 0x18A2, 0x1882, 0x20C3, 0x3186, 0x8451, 0x8CD3, 0x8C92, 0x8451, 0x8451, 0x8430, 0x8471, 0x73CE, 0x6BAE, 0x7C30,
 0x9D55, 0xA575, 0x9534, 0x8CB2, 0x73F0, 0x8471, 0x634D, 0x422A, 0x39CA, 0x2108, 0x0863, 0x10C3, 0x1924, 0x2985, 0x2986, 0x2965,
 0x3207, 0x5B0C, 0x31C7, 0x2965, 0x31A6, 0x2985, 0x2986, 0x29A5, 0x2A06, 0x2A88, 0x1A26, 0x2247, 0x2AC8, 0x2246, 0x2246, 0x0983,
 0x2227, 0x2227, 0x3B0B, 0x2A48, 0x4AEB, 0x636D, 0x632D, 0x6B6D, 0x6B4C, 0x634C, 0x6B4C, 0x632C, 0x630B, 0x62EB, 0x6B2C, 0x6B2C,
 0x630B, 0x630B, 0x630B, 0x630B, 0x630B, 0x6B0B, 0x630B, 0x5ACA, 0x62EA, 0x630B, 0x630B, 0x62EB, 0x62EB, 0x6B4C, 0x6B6D, 0x632C,
 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD616, 0xD616, 0xDE16, 0xDE16, 0xD616, 0xDE16, 0xDE16, 0xD616, 0xC5B5, 0xD616, 0xD5F5,
 0xDE36, 0xDE16, 0xD616, 0xD616, 0xD616, 0xD616, 0xD616, 0xD616, 0xCE16, 0xCE99, 0xC6BA, 0xBE9A, 0xC6BB, 0xBE7A, 0xB67A, 0xA5F8,
 0x9D97, 0x7CB4, 0x84B4, 0x7C51, 0x9D35, 0xBE38, 0xC679, 0xAD75, 0x840F, 0x5289, 0x28C2, 0x1061, 0x20C3, 0x52AA, 0x738E, 0x636D,
 0x7C30, 0x9D14, 0x94F3, 0x8492, 0x7410, 0x638E, 0x94F4, 0xA596, 0xB5F7, 0xADB6, 0x9D34, 0x8491, 0x8471, 0x6B8E, 0x530C, 0x8CD3,
 0x39C9, 0x0842, 0x0862, 0x08A3, 0x1104, 0x1104, 0x2164, 0x31C7, 0x4228, 0x3A28, 0x31A6, 0x2165, 0x2965, 0x2985, 0x2985, 0x29A6,
 0x2246, 0x2A87, 0x2267, 0x2A87, 0x1A26, 0x2A87, 0x32A8, 0x19E5, 0x2227, 0x3269, 0x536D, 0x2228, 0x5B0C, 0x634C, 0x6B6D, 0x634D,
 0x6B6C, 0x6B4C, 0x6B2C, 0x630B, 0x6B4C, 0x632C, 0x62EB, 0x632B, 0x630B, 0x6B2B, 0x6B4B, 0x5ACA, 0x5AEA, 0x5ACA, 0x630B, 0x5ACA,
 0x62EA, 0x62EB, 0x62EB, 0x62CA, 0x6B4C, 0x5289, 0xA513, 0x6B6D, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD5F5, 0xD616, 0xDE16, 0xDE16,
 0xDE16, 0xD616, 0xDE16, 0xDE16, 0xD5F6, 0xB553, 0x83CE, 0xB574, 0xCDF6, 0xD616, 0xD616, 0xDE16, 0xD616, 0xD616, 0xD616, 0xCE16,
 0xCE58, 0xCEDB, 0xC6BB, 0xC6BA, 0xBE7A, 0xB659, 0x9555, 0x8D55, 0x8D15, 0x7431, 0x8492, 0x73CF, 0x9534, 0xC679, 0xC69A, 0xB5D7,
 0xA533, 0x630B, 0x20A2, 0x1041, 0x18C3, 0x6B6D, 0x5289, 0x7C0F, 0x7C30, 0x94F3, 0x7431, 0x84B3, 0x7C51, 0xA576, 0xB618, 0xADD7,
 0x9D54, 0x9D14, 0x8450, 0x5B0B, 0x4A8A, 0x52EB, 0x3A28, 0x94F3, 0x2165, 0x2986, 0x08A3, 0x1905, 0x1104, 0x08E3, 0x2144, 0x31C6,
 0x4248, 0x31E7, 0x2965, 0x2165, 0x2164, 0x2965, 0x2164, 0x2A27, 0x1A46, 0x2AA7, 0x2267, 0x2226, 0x2A67, 0x3AC8, 0x2205, 0x11A4,
 0x2247, 0x2A69, 0x432C, 0x3249, 0x5B0C, 0x6BAE, 0x634D, 0x6B4D, 0x6B6D, 0x632C, 0x632C, 0x6B2C, 0x6B2B, 0x62EB, 0x6B2C, 0x630B,
 0x630B, 0x630B, 0x630A, 0x62EA, 0x632B, 0x62EB, 0x62EA, 0x5AEA, 0x5ACA, 0x5AC9, 0x5ACA, 0x6B2B, 0x62EB, 0x5AEA, 0x630B, 0x6B4C,
 0xD5F5, 0xD5F5, 0xD5F5, 0xDE16, 0xD5F5, 0xDE16, 0xD616, 0xDE16, 0xDE16, 0xD616, 0xDE36, 0xDE36, 0xD616, 0xD616, 0xBDB5, 0xA513,
 0xAD96, 0xAD75, 0xB575, 0xC5D6, 0xCE16, 0xD5F6, 0xCDF6, 0xCE16, 0xCEBB, 0xBE9A, 0xC6BB, 0xBE7A, 0xB639, 0x9D56, 0x9D76, 0x7C93,
 0x8CF4, 0x9514, 0x7C51, 0x7410, 0x9535, 0xC69A, 0xBE38, 0xAD95, 0x9491, 0x41C6, 0x18A2, 0x1861, 0x1082, 0x6B4D, 0x5ACB, 0x5B0B,
 0x6B8E, 0x73EF, 0x8CB3, 0x8CB3, 0x8492, 0x9514, 0x9D34, 0x94F3, 0x636D, 0x632C, 0x5AEB, 0x52AA, 0x4AAA, 0x4249, 0x31E7, 0x638E,
 0x2146, 0x08A3, 0x1924, 0x2145, 0x1925, 0x1905, 0x1904, 0x2145, 0x2985, 0x2965, 0x2145, 0x2144, 0x1924, 0x2164, 0x29E5, 0x2A67,
 0x2267, 0x32C8, 0x1A05, 0x2267, 0x2AA8, 0x2225, 0x19E5, 0x19E5, 0x2A68, 0x328A, 0x4B0C, 0x2A08, 0x5B0C, 0x634C, 0x632D, 0x6B8D,
 0x6B6D, 0x634C, 0x5ACB, 0x630B, 0x630B, 0x630B, 0x630B, 0x632C, 0x632B, 0x62EA, 0x6B4C, 0x62EB, 0x630B, 0x62EB, 0x630B, 0x5ACA,
 0x62EA, 0x630B, 0x62EA, 0x5AEA, 0x5ACA, 0x630B, 0x738D, 0x6B6C, 0xD5F5, 0xD5F5, 0xDDF5, 0xDE15, 0xD616, 0xDE16, 0xDE16, 0xDE16,
 0xDE36, 0xDE36, 0xDE36, 0xDE16, 0xDE36, 0xDE36, 0xE657, 0xD637, 0x9471, 0x9D14, 0xA575, 0xADD7, 0xB5D6, 0xC5D6, 0xBDD6, 0xCE79,
 0xC6BA, 0xBEBA, 0xBE9A, 0xBE59, 0xA5D7, 0x9D76, 0x7C72, 0x8CD4, 0x9534, 0x6BAF, 0x8CD4, 0x9D75, 0xADF7, 0xADD7, 0xB5D7, 0xA554,
 0x8C70, 0x2903, 0x18A2, 0x1862, 0x1881, 0x39C7, 0x4A49, 0x52EB, 0x73EF, 0x7410, 0x94F4, 0x7C51, 0x8C92, 0x8471, 0x7C10, 0x52CB,
 0x4208, 0x4249, 0x4A69, 0x4A69, 0x4A89, 0x4228, 0x31C7, 0x3A49, 0x10E3, 0x1104, 0x10E4, 0x2104, 0x10E4, 0x1905, 0x10A3, 0x10E4,
 0x2124, 0x2124, 0x1904, 0x1924, 0x2144, 0x1164, 0x2A67, 0x1A05, 0x2226, 0x2A87, 0x32C9, 0x2A67, 0x1A05, 0x2246, 0x2205, 0x19C5,
 0x2207, 0x3AAA, 0x430B, 0x3AAB, 0x634D, 0x6B8D, 0x634D, 0x6B8D, 0x6B4D, 0x634D, 0x5B0B, 0x630C, 0x6B6D, 0x630B, 0x632B, 0x5ACA,
 0x630B, 0x5ACA, 0x630B, 0x5ACA, 0x6B2B, 0x62EB, 0x62EB, 0x5ACA, 0x5AEB, 0x5ACA, 0x4A48, 0x630B, 0x5AAA, 0x630B, 0x630B, 0x630B,
 0xD5F5, 0xD5F5, 0xD5F5, 0xDE16, 0xDE16, 0xDE16, 0xD616, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE16, 0xDE16, 0xD616,
 0xD637, 0x8C50, 0x8C92, 0x94F3, 0x9D55, 0xA596, 0xB5F7, 0xC6BA, 0xBE7A, 0xBE9A, 0xBE9A, 0xA5F8, 0x9555, 0x8D14, 0x7431, 0x9D56,
 0x7C31, 0x7C51, 0x84D3, 0xB639, 0xC69A, 0xADB6, 0xB5D6, 0x8451, 0x7BCE, 0x5289, 0x1882, 0x1882, 0x20E3, 0x3185, 0x4A69, 0x634D,
 0x7C51, 0x7C30, 0x8451, 0x6B8E, 0x7C10, 0x6B8E, 0x5AEB, 0x3A07, 0x4228, 0x52AA, 0x5B2C, 0x5B0B, 0x52AA, 0x4269, 0x4249, 0x4A6A,
 0x1082, 0x0861, 0x10E4, 0x00C3, 0x1925, 0x1925, 0x2966, 0x08A2, 0x10A2, 0x10C3, 0x10C3, 0x18E3, 0x10C4, 0x29E6, 0x2A66, 0x2226,
 0x1A05, 0x2267, 0x2246, 0x2AA8, 0x2247, 0x2245, 0x1A06, 0x21C6, 0x2228, 0x3AAA, 0x42CA, 0x3269, 0x52CB, 0x6B6D, 0x634D, 0x6B4D,
 0x634C, 0x632C, 0x630B, 0x6B2C, 0x630B, 0x6B2B, 0x6B0B, 0x630C, 0x736C, 0x62EB, 0x630B, 0x6B4C, 0x5AEA, 0x5ACA, 0x632B, 0x5ACA,
 0x5289, 0x62EA, 0x62CA, 0x5AA9, 0x62EA, 0x62CA, 0x836D, 0x72AB, 0xD5F5, 0xD5F5, 0xD615, 0xD615, 0xDE16, 0xDE16, 0xDE16, 0xDE16,
 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE16, 0xDE36, 0xD636, 0xC5F6, 0x9CF3, 0x94F4, 0x94F3, 0x8CD3, 0xC679, 0xC69A,
 0xC6BB, 0xBE7A, 0xADF8, 0xA5B7, 0x84B3, 0x9514, 0x9535, 0x9514, 0x84D3, 0x84B3, 0xBE9A, 0xBE59, 0xADB6, 0xA595, 0xA575, 0x73AE,
 0x6B2C, 0x4A28, 0x2925, 0x2925, 0x3165, 0x39C6, 0x4A49, 0x6BAE, 0x73CF, 0x73AE, 0x6B8D, 0x52CA, 0x632C, 0x5B0B, 0x52CB, 0x4A49,
 0x5AEB, 0x528A, 0x5B0C, 0x5B0C, 0x5B0B, 0x52AA, 0x8410, 0x1083, 0x1062, 0x0841, 0x0862, 0x08A3, 0x3A08, 0x3146, 0x1042, 0x0021,
 0x0861, 0x0862, 0x0882, 0x10A2, 0x0041, 0x0041, 0x2206, 0x2A87, 0x2A47, 0x2A88, 0x2A88, 0x32C8, 0x2246, 0x2246, 0x2206, 0x2A88,
 0x2A68, 0x42EB, 0x3248, 0x42AB, 0x5B4D, 0x5B6D, 0x638E, 0x6B6D, 0x5B4C, 0x630B, 0x6B4C, 0x632B, 0x5B2B, 0x634C, 0x632B, 0x630B,
 0x632B, 0x6B4C, 0x632B, 0x62EA, 0x6AEB, 0x6AEB, 0x6ACB, 0x6AEB, 0x6ACA, 0x6269, 0x6269, 0x4124, 0x40E4, 0x38A3, 0x3883, 0x2821,
 0xD5F5, 0xD5F5, 0xD616, 0xD616, 0xDE16, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xD636, 0xDE36, 0xDE36, 0xDE36,
 0xD616, 0xD636, 0xBDB5, 0x9D34, 0x9D35, 0xADB7, 0xC6BA, 0xB65A, 0xB679, 0xB67A, 0xADF8, 0x9535, 0x9D75, 0x8CD3, 0x8CD3, 0x8492,
 0x9D76, 0xB638, 0xB639, 0xB5F7, 0xADD6, 0xA554, 0x8450, 0x6B8D, 0x528A, 0x4207, 0x3985, 0x3165, 0x39A6, 0x4207, 0x4A28, 0x52AA,
 0x73CE, 0x5B0B, 0x5AEB, 0x634D, 0x6B6D, 0x634D, 0x6B6D, 0x634C, 0x5B0B, 0x52CB, 0x6B4D, 0x634C, 0x4A69, 0x9492, 0x18C4, 0x18A3,
 0x0001, 0x39E8, 0x10C3, 0x1924, 0x18E3, 0x1082, 0x0821, 0x0821, 0x0020, 0x0841, 0x0841, 0x0041, 0x1062, 0x0021, 0x1965, 0x1964,
 0x2A67, 0x2A87, 0x1A46, 0x2267, 0x1225, 0x2A67, 0x2984, 0x2144, 0x4A8A, 0x3A69, 0x528A, 0x7AAC, 0x832C, 0x41E7, 0x5269, 0x736D,
 0x630C, 0x6B4C, 0x734C, 0x6B2C, 0x7B2C, 0x730C, 0x7B2C, 0x730C, 0x7ACB, 0x728A, 0x6208, 0x59C7, 0x4945, 0x38C3, 0x3082, 0x3082,
 0x2862, 0x3082, 0x3062, 0x3042, 0x2841, 0x2862, 0x2021, 0x2041, 0xD5F5, 0xD5F5, 0xD5F5, 0xD616, 0xDE16, 0xDE16, 0xDE16, 0xDE16,
 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xD636, 0xDE36, 0xD636, 0xD616, 0xDE36, 0xCE16, 0xAD55, 0xAD96, 0xBE59, 0xBE7A, 0xBE9A,
 0xC6DB, 0xA5F8, 0x9535, 0x84B3, 0x8492, 0x8CD3, 0x9514, 0xA5D7, 0xDF3C, 0xCEBA, 0xBE38, 0xAD95, 0x9CF3, 0x7BEF, 0x6B6D, 0x528A,
 0x4A69, 0x4207, 0x41C6, 0x41E6, 0x4A07, 0x4A48, 0x4228, 0x5289, 0x52AA, 0x5ACA, 0x632C, 0x634C, 0x6B6D, 0x6B6D, 0x6B8E, 0x6B6D,
 0x632C, 0x6B8D, 0x52AA, 0x4A69, 0x3A08, 0x2966, 0x10A3, 0x1082, 0x0841, 0x08A2, 0x1903, 0x2124, 0x2965, 0x1904, 0x1082, 0x0821,
 0x0021, 0x0020, 0x0000, 0x0000, 0x0000, 0x0020, 0x0020, 0x31C7, 0x2A07, 0x2A27, 0x2207, 0x19E6, 0x2A27, 0x2A27, 0x39C6, 0x29E6,
 0x3AEB, 0x39C7, 0x2882, 0x3083, 0x3925, 0x1082, 0x1062, 0x1062, 0x0841, 0x1041, 0x1820, 0x48A3, 0x3062, 0x3882, 0x3082, 0x3041,
 0x3062, 0x2842, 0x2862, 0x2862, 0x2841, 0x2061, 0x2062, 0x2062, 0x2041, 0x2082, 0x1861, 0x20A2, 0x2924, 0x3144, 0x62EB, 0x738D,
 0xD5F5, 0xD615, 0xD616, 0xDE16, 0xDE16, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE16,
 0xD616, 0xD636, 0xD616, 0xCDF6, 0xBE17, 0xBE9A, 0xB659, 0xAE39, 0xA5D7, 0x9535, 0x7C31, 0x9514, 0x9D35, 0xA5B6, 0xCEDB, 0xD6FB,
 0xC659, 0xB618, 0xADB6, 0x94B2, 0x7BEF, 0x6B6D, 0x528A, 0x4229, 0x4248, 0x5269, 0x4A48, 0x4A48, 0x4A48, 0x528A, 0x52AA, 0x4A48,
 0x52AA, 0x5B0B, 0x6B4D, 0x6B8E, 0x738E, 0x6B8E, 0x6B6D, 0x632C, 0x6B8E, 0x52AA, 0x52EB, 0x52AA, 0x3A49, 0x1925, 0x2125, 0x0862,
 0x10C3, 0x2144, 0x2144, 0x2144, 0x2124, 0x1924, 0x2124, 0x2145, 0x10E3, 0x0021, 0x0000, 0x0040, 0x0000, 0x0000, 0x0000, 0x08A2,
 0x0081, 0x1104, 0x1104, 0x1103, 0x6BAE, 0xA555, 0x2144, 0x1A06, 0x2A07, 0x30C3, 0x50E5, 0x4105, 0x1082, 0x0861, 0x0861, 0x1041,
 0x1061, 0x0820, 0x1841, 0x2862, 0x2021, 0x2842, 0x2061, 0x2061, 0x2062, 0x2041, 0x2082, 0x28E3, 0x3986, 0x4A08, 0x62EB, 0x5AAA,
 0x62EB, 0x5ACA, 0x5ACA, 0x5ACA, 0x5AAA, 0x5ACA, 0x6B2C, 0x632C, 0xD615, 0xD615, 0xD5F5, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36,
 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xD636, 0xD636, 0xD636, 0xCE37, 0xBE38, 0xBE9B, 0xB639, 0xB659,
 0x9D55, 0x8472, 0xBE59, 0xA596, 0xC679, 0xBE38, 0xBE38, 0xADD7, 0xA576, 0xA576, 0xA595, 0x8471, 0x7C30, 0x6B6D, 0x4A49, 0x4228,
 0x4A69, 0x4A68, 0x4A68, 0x5AAA, 0x5AAA, 0x52AA, 0x52AA, 0x5289, 0x52AA, 0x630C, 0x6B6D, 0x6B6D, 0x6B8D, 0x632C, 0x5AEB, 0x6B6D,
 0x52EB, 0x52CB, 0x634D, 0x31A7, 0x1925, 0x10E4, 0x0882, 0x1082, 0x2145, 0x2985, 0x2165, 0x2124, 0x1904, 0x1944, 0x1944, 0x2165,
 0x2965, 0x1965, 0x29E6, 0x3288, 0x3AEA, 0x0020, 0x0000, 0x10E4, 0x2186, 0x2A47, 0x2206, 0x2A67, 0x2A88, 0x2206, 0x1102, 0x21A4,
 0x29C6, 0x39C7, 0x5186, 0x3925, 0x1061, 0x1081, 0x1061, 0x1882, 0x18A2, 0x0840, 0x0000, 0x6B4C, 0x632C, 0x6B4C, 0x630B, 0x6B6D,
 0x632C, 0x630B, 0x630B, 0x62CB, 0x632B, 0x632B, 0x630B, 0x632B, 0x738D, 0x5ACA, 0x5ACA, 0x5ACA, 0x5AAA, 0x5ACA, 0x630B, 0x6B4C,
 0xD615, 0xD615, 0xD616, 0xDE16, 0xDE16, 0xDE36, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xDE36, 0xDE36, 0xDE36,
 0xD636, 0xD616, 0xD636, 0xCE37, 0xC679, 0xB65A, 0xB619, 0xBE59, 0xC699, 0x9D34, 0xAD75, 0xA554, 0x9D14, 0x8451, 0xAD96, 0xA555,
 0xA576, 0x9D55, 0xD6FB, 0xADD7, 0x94D3, 0x6B8E, 0x4208, 0x4248, 0x5289, 0x4A48, 0x4A48, 0x5289, 0x52AA, 0x52CA, 0x52CA, 0x52AA,
 0x5ACB, 0x5B0C, 0x632C, 0x5B0B, 0x6B6D, 0x632C, 0x5B0C, 0x52CA, 0x52EB, 0x6B6E, 0x3A49, 0x2105, 0x18E4, 0x10C3, 0x0861, 0x31C7,
 0x3A07, 0x31C6, 0x31A6, 0x2145, 0x1904, 0x1924, 0x1945, 0x2166, 0x2986, 0x3AC9, 0x2247, 0x0923, 0x430A, 0x4269, 0x0001, 0x0884,
 0x10A4, 0x0062, 0x0882, 0x2165, 0x21E6, 0x19C5, 0x2247, 0x19E6, 0x1164, 0x3268, 0x332B, 0x2207, 0x3A29, 0x0041, 0x31A6, 0x0862,
 0x1041, 0x0820, 0x6B2C, 0x73AD, 0x630B, 0x6B2B, 0x62EB, 0x6B6D, 0x6B2C, 0x5ACA, 0x62EB, 0x6B0B, 0x736D, 0x62EB, 0x630C, 0x6B2C,
 0x630B, 0x5ACA, 0x630B, 0x62EB, 0x5ACA, 0x5ACA, 0x5ACA, 0x6B6C, 0xD615, 0xD615, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36,
 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xDE36, 0xDE36, 0xDE36, 0xD616, 0xD636, 0xD617, 0xD638, 0xC679, 0xB659, 0xB5F8, 0xDF1B,
 0x8CB2, 0x94B2, 0xAD95, 0x8450, 0x9D14, 0x8451, 0x8C92, 0x94D3, 0x94F4, 0xADB6, 0xBE18, 0xA555, 0x94F3, 0x62EC, 0x39E7, 0x4249,
 0x4A69, 0x4A48, 0x4A48, 0x5289, 0x52AA, 0x5AEA, 0x5ACA, 0x5ACB, 0x5ACB, 0x634C, 0x634C, 0x6B6D, 0x634C, 0x6B4D, 0x5AEB, 0x52CB,
 0x8C92, 0x4249, 0x1944, 0x1924, 0x10A3, 0x18E3, 0x3A07, 0x31E7, 0x3A08, 0x31C6, 0x31C6, 0x2165, 0x2125, 0x1924, 0x2145, 0x2986,
 0x3A69, 0x3AE9, 0x2267, 0x29A6, 0x00C3, 0x1164, 0x1184, 0x0903, 0x08A3, 0x0863, 0x0022, 0x0041, 0x0021, 0x0841, 0x0861, 0x2965,
 0x2166, 0x432C, 0x32EA, 0x42EB, 0x4AEB, 0x6B8E, 0x6B6D, 0x634D, 0x638E, 0x632C, 0x5AEB, 0x5B0B, 0x632C, 0x6B2C, 0x632C, 0x6B4C,
 0x6B4C, 0x632B, 0x632B, 0x630B, 0x62EA, 0x5ACA, 0x5AEB, 0x634C, 0x6B4C, 0x5ACA, 0x62AA, 0x62CB, 0x5289, 0x5AAA, 0x6B2C, 0x5AEA,
 0xDE16, 0xD615, 0xDE16, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36,
 0xD636, 0xD616, 0xCE16, 0xCE38, 0xC679, 0xE77D, 0xCE79, 0xD6B9, 0xBE18, 0xB5D7, 0x7C30, 0x94B2, 0x8C51, 0x7C10, 0x73CF, 0x73EF,
 0x8492, 0xADD7, 0xA575, 0x7C0F, 0x632C, 0x528A, 0x4208, 0x4228, 0x4248, 0x5289, 0x5289, 0x52AA, 0x5ACA, 0x52AA, 0x5AEB, 0x632C,
 0x632C, 0x636D, 0x6B8D, 0x6B6D, 0x632C, 0x52CB, 0x530C, 0x9D35, 0x52CC, 0x10E4, 0x1925, 0x1904, 0x1904, 0x4208, 0x4249, 0x4248,
 0x3A07, 0x31E7, 0x29A6, 0x2986, 0x2145, 0x2124, 0x2145, 0x3A28, 0x638D, 0x4288, 0x3208, 0x0102, 0x32EA, 0x2A88, 0x2A88, 0x2246,
 0x2226, 0x19C6, 0x00C2, 0x0061, 0x0040, 0x0041, 0x0021, 0x0041, 0x0841, 0x0021, 0x11A5, 0x32EA, 0x4ACA, 0x6B8D, 0x634C, 0x6B8E,
 0x634C, 0x5B0C, 0x6B8D, 0x6B4C, 0x6B6D, 0x630B, 0x632C, 0x632B, 0x62EB, 0x5AEB, 0x632B, 0x62CB, 0x630B, 0x630B, 0x62EB, 0x630B,
 0x6B2C, 0x5ACA, 0x5AAA, 0x5ACA, 0x5ACA, 0x5ACA, 0x630B, 0x5268, 0xDE15, 0xD615, 0xDE16, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36,
 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE56, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xCE17, 0xC618, 0xC67A, 0x9514, 0x94D3, 0xBDF7, 0x9CD3,
 0xA554, 0x94B2, 0x9D14, 0x8430, 0x636D, 0x94F3, 0x8471, 0x73AF, 0xA576, 0xA596, 0xA554, 0x7BEF, 0x52AA, 0x4A49, 0x4228, 0x4208,
 0x4A48, 0x52AA, 0x528A, 0x52AA, 0x5ACA, 0x52CB, 0x632C, 0x73AE, 0x634D, 0x634D, 0x7C10, 0x73CF, 0x6BEF, 0x5B2D, 0xC65A, 0x7C11,
 0x2145, 0x10E3, 0x18E4, 0x2124, 0x3A28, 0x4249, 0x4A69, 0x4269, 0x4248, 0x3A08, 0x31C6, 0x2986, 0x2165, 0x2145, 0x2145, 0xD6B9,
 0xC657, 0x5AEA, 0x10A3, 0x0081, 0x2A89, 0x32A9, 0x2AA8, 0x2266, 0x1A46, 0x2288, 0x11E5, 0x2AA8, 0x19E5, 0x19A5, 0x00C2, 0x0061,
 0x0021, 0x0062, 0x00E2, 0x3B0B, 0x638D, 0x6B4D, 0x632C, 0x6B8E, 0x6B4D, 0x634C, 0x632C, 0x6B4D, 0x6B4C, 0x6B2C, 0x6B4C, 0x630B,
 0x6B4C, 0x6B4C, 0x62EB, 0x62CB, 0x5ACB, 0x6B2C, 0x632B, 0x632B, 0x630B, 0x62CA, 0x62EA, 0x5AA9, 0x62EA, 0x62EA, 0x630B, 0x5289,
 0xDE15, 0xDE16, 0xDE16, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xD637,
 0xCE17, 0xC658, 0xB618, 0x9D76, 0x9D34, 0x6B6E, 0xC638, 0x8471, 0x6B6D, 0x8430, 0x7BEF, 0x73AE, 0x8450, 0x73CF, 0x7C30, 0x73CF,
 0x8CB3, 0x94F3, 0x8451, 0x632C, 0x52AA, 0x5289, 0x4A49, 0x4229, 0x4A69, 0x528A, 0x52AA, 0x528A, 0x52CB, 0x5B0C, 0x632C, 0x5B2C,
 0x634D, 0x5B0C, 0x636D, 0x6B8E, 0x6BAF, 0xCEDC, 0x634E, 0x2146, 0x18E4, 0x18E4, 0x2124, 0x4208, 0x4269, 0x4249, 0x4269, 0x428A,
 0x4289, 0x4248, 0x39E7, 0x2986, 0x2165, 0x2165, 0x5B0B, 0x8C90, 0xCE78, 0x2904, 0x0020, 0x32A8, 0x32A9, 0x2AA8, 0x2287, 0x2267,
 0x2267, 0x2288, 0x2A88, 0x1A26, 0x32C8, 0x1A25, 0x2246, 0x2A88, 0x1A27, 0x2AA9, 0x32A8, 0x3AC9, 0x5B2C, 0x6B6D, 0x636D, 0x73CF,
 0x6B4D, 0x634C, 0x6B6D, 0x632C, 0x6B4C, 0x630B, 0x632C, 0x632B, 0x6B2C, 0x5AAA, 0x630B, 0x62EC, 0x5ACA, 0x62EB, 0x630B, 0x630B,
 0x630B, 0x5ACA, 0x62EB, 0x630B, 0x6B4C, 0x5AA9, 0x62EB, 0x5ACA, 0xDE15, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE16, 0xDE16, 0xDE36,
 0xDE36, 0xDE16, 0xDE36, 0xDE36, 0xD617, 0xDE36, 0xD637, 0xCE38, 0xC679, 0xB618, 0x9D35, 0x8CB2, 0x84B3, 0x73CF, 0x73AE, 0x4ACA,
 0x73CF, 0x8C92, 0x8430, 0x6B8D, 0x73CF, 0x6B8E, 0x6B8E, 0x7C31, 0x73CF, 0x7C30, 0x6BAE, 0x6B6D, 0x5AEB, 0x52AA, 0x4A69, 0x4A49,
 0x4A49, 0x5289, 0x5289, 0x52CA, 0x52AA, 0x52CB, 0x4AAA, 0x5B0C, 0x6BAE, 0x6BAE, 0x7410, 0x8471, 0x73F0, 0x636E, 0x2146, 0x1925,
 0x10C3, 0x2945, 0x3A28, 0x4269, 0x4269, 0x4269, 0x4269, 0x52EB, 0x4AAA, 0x4269, 0x3A07, 0x29A6, 0x29A5, 0x2986, 0x636D, 0xD6DA,
 0xC5B5, 0x0841, 0x2207, 0x32E9, 0x2A67, 0x2A87, 0x2287, 0x2267, 0x1225, 0x2266, 0x1A26, 0x2287, 0x1A47, 0x2266, 0x2226, 0x2205,
 0x19E6, 0x2268, 0x2207, 0x432C, 0x42AA, 0x632C, 0x6B8E, 0x634D, 0x632C, 0x634C, 0x6B4D, 0x634C, 0x6B4D, 0x630B, 0x6B4C, 0x630B,
 0x6B2C, 0x6B2C, 0x630B, 0x62EB, 0x6B4C, 0x62EB, 0x5ACA, 0x5ACA, 0x632C, 0x632C, 0x5ACA, 0x5ACA, 0x62EB, 0x62EA, 0x5269, 0x630B,
 0xD615, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xD637, 0xC638, 0xBE38, 0xA576,
 0x73CF, 0x73AF, 0x6B6D, 0x6BAE, 0x73AE, 0x6B8E, 0x52EB, 0x8C71, 0x7C30, 0x632C, 0x630C, 0x528A, 0x528A, 0x52AA, 0x634D, 0x6B8E,
 0x73CF, 0x6B6E, 0x634D, 0x634D, 0x636E, 0x73AE, 0x4A69, 0x4228, 0x4A49, 0x4A69, 0x4A69, 0x4A69, 0x52AA, 0x4AAA, 0x632D, 0x73EF,
 0x7C31, 0x73CF, 0x7BF0, 0x6B6E, 0x52EC, 0x2187, 0x1946, 0x18E4, 0x2986, 0x4228, 0x4269, 0x4A89, 0x4A8A, 0x428A, 0x530C, 0x4AAA,
 0x4AAA, 0x4249, 0x3A08, 0x31C7, 0x31A6, 0x29A6, 0x73F0, 0xEF1B, 0x1082, 0x29C8, 0x2A68, 0x2267, 0x2AA8, 0x2226, 0x32C8, 0x2246,
 0x2267, 0x2267, 0x2267, 0x1A26, 0x2246, 0x1A26, 0x11E4, 0x2246, 0x1185, 0x3289, 0x11C6, 0x3ACA, 0x4ACB, 0x6B6D, 0x6B6D, 0x634D,
 0x634C, 0x636D, 0x634C, 0x6B4C, 0x632C, 0x6B4C, 0x5AAA, 0x630C, 0x6B4C, 0x6B2C, 0x632C, 0x5AAA, 0x5ACA, 0x630B, 0x62EB, 0x62EB,
 0x6B4C, 0x5ACA, 0x632B, 0x62EA, 0x62EB, 0x62EB, 0x5ACB, 0x5B0B, 0xDE16, 0xDE16, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36,
 0xDE36, 0xDE36, 0xD637, 0xC618, 0xBE18, 0xA575, 0x8C71, 0x6B8E, 0x630C, 0x5AAA, 0x5AAA, 0x5269, 0x5269, 0x528A, 0x4A48, 0x3145,
 0x5AEC, 0x5ACC, 0x39E8, 0x4228, 0x4A49, 0x5ACB, 0x632C, 0x6B6D, 0x52AB, 0x4249, 0x5B2C, 0x52EB, 0x6BAF, 0x73CF, 0x4A69, 0x4229,
 0x4208, 0x39E7, 0x4249, 0x4269, 0x4A69, 0x4249, 0x6B8E, 0x73AF, 0x6BAF, 0x6B6D, 0x6B4E, 0x2126, 0x10C3, 0x2166, 0x1904, 0x2986,
 0x4228, 0x4249, 0x4269, 0x4269, 0x4A69, 0x4ACB, 0x530C, 0x530C, 0x4A8A, 0x4228, 0x3A08, 0x31E7, 0x31C6, 0xB5D6, 0x73AF, 0x1000,
 0x10C4, 0x534E, 0x32C9, 0x32E9, 0x2A67, 0x32C8, 0x2267, 0x2267, 0x2267, 0x22A8, 0x2288, 0x2A88, 0x2247, 0x2A88, 0x09A3, 0x2A88,
 0x1185, 0x1A48, 0x1A07, 0x3A8A, 0x5B2C, 0x6B4D, 0x632C, 0x634D, 0x6B6D, 0x632C, 0x632C, 0x634C, 0x632C, 0x736D, 0x6B4D, 0x6B2C,
 0x630B, 0x738D, 0x630B, 0x62EA, 0x630B, 0x6B2C, 0x5ACA, 0x630B, 0x630B, 0x5ACA, 0x5ACA, 0x62EA, 0x62EB, 0x62EB, 0x52AA, 0x738D,
 0xD615, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE16, 0xDE36, 0xD616, 0xD637, 0xC638, 0xADB6, 0x7BEF, 0x6B2C, 0x5249, 0x5A8A,
 0x41C8, 0x3986, 0x3986, 0x3986, 0x3986, 0x39A7, 0x4A49, 0x3145, 0x39E8, 0x4229, 0x39C7, 0x3A08, 0x39E7, 0x4A69, 0x52AA, 0x52AA,
 0x4249, 0x4A8A, 0x4A8A, 0x630C, 0x73CF, 0x8C71, 0x630C, 0x4A69, 0x4A6A, 0x4208, 0x4229, 0x528A, 0x4A6A, 0x3A6A, 0x4B0D, 0x4B0C,
 0x6B8F, 0x4209, 0x2106, 0x1063, 0x0862, 0x1904, 0x2987, 0x4229, 0x4249, 0x4A69, 0x4249, 0x4A69, 0x4249, 0x4AAA, 0x52EB, 0x4249,
 0x4289, 0x3A07, 0x31E7, 0x3A08, 0x31C6, 0xEF3B, 0x18C3, 0x0821, 0xADB7, 0x4B2D, 0x3AEA, 0x3B0A, 0x2226, 0x32E9, 0x2247, 0x1A26,
 0x2267, 0x1A67, 0x1A26, 0x2267, 0x32E9, 0x2267, 0x2266, 0x11E5, 0x11C6, 0x5C92, 0x1A07, 0x3ACB, 0x5B4D, 0x73AE, 0x636D, 0x6B8E,
 0x6B6D, 0x6B6D, 0x632C, 0x634C, 0x630B, 0x62EB, 0x6B2C, 0x630B, 0x630B, 0x630B, 0x630B, 0x630B, 0x630B, 0x630B, 0x630B, 0x5ACA,
 0x5AEA, 0x6B2B, 0x5ACA, 0x5AAA, 0x630B, 0x5ACA, 0x632B, 0x73AD, 0xDE16, 0xDE15, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36,
 0xCE37, 0xBDD7, 0x8431, 0x734D, 0x5248, 0x49C6, 0x3945, 0x3985, 0x3985, 0x3965, 0x2923, 0x3164, 0x3965, 0x3186, 0x3186, 0x39C8,
 0x3A08, 0x4208, 0x4A69, 0x4228, 0x4228, 0x4228, 0x4228, 0x4A69, 0x422A, 0x3A29, 0x322A, 0x324A, 0x4AAB, 0x634E, 0x4A6A, 0x4229,
 0x4229, 0x4228, 0x4228, 0x4A6A, 0x426A, 0x6BF1, 0x1967, 0x5ACC, 0x2126, 0x18A4, 0x1063, 0x0862, 0x10C3, 0x31C7, 0x3A08, 0x4249,
 0x4228, 0x4A69, 0x4A6A, 0x4269, 0x3A49, 0x4269, 0x4248, 0x3A08, 0x3A08, 0x3A08, 0x3A08, 0x3207, 0xA4F3, 0x1000, 0x0861, 0xE79D,
 0xA555, 0x5B4E, 0x430A, 0x330A, 0x2A67, 0x2267, 0x2A87, 0x2246, 0x2267, 0x2267, 0x2287, 0x2AC8, 0x2267, 0x2267, 0x1A46, 0x19E5,
 0x2A67, 0x1A68, 0x21E6, 0x3289, 0x4B0B, 0x73CF, 0x632C, 0x636D, 0x6B6D, 0x6B4C, 0x632C, 0x634C, 0x73AD, 0x6B4C, 0x630B, 0x632B,
 0x630C, 0x630B, 0x632C, 0x6B4D, 0x62EA, 0x630B, 0x630B, 0x632B, 0x62EA, 0x62EA, 0x5ACA, 0x5AAA, 0x5ACA, 0x62CA, 0x62EB, 0x62EA,
 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xD657, 0xCE17, 0x736D, 0x6B0C, 0x5A69, 0x49E6, 0x4165, 0x3944, 0x3164, 0x3986,
 0x3965, 0x3964, 0x3144, 0x2924, 0x3165, 0x39E7, 0x3A09, 0x4249, 0x4229, 0x4A49, 0x3985, 0x3145, 0x3165, 0x3185, 0x3986, 0x39A6,
 0x39C6, 0x3A4A, 0x39C9, 0x31C8, 0x31C8, 0x4A8A, 0x424A, 0x3187, 0x39C8, 0x420A, 0x420A, 0x31A8, 0x31C9, 0x1905, 0x1945, 0x3A29,
 0x52EC, 0x10A4, 0x0822, 0x08A2, 0x31A7, 0x3A08, 0x4229, 0x3A08, 0x4269, 0x4249, 0x4269, 0x4269, 0x4269, 0x52EB, 0x4229, 0x3A08,
 0x3A08, 0x3A08, 0x4228, 0x39E7, 0x0841, 0x0882, 0x5B4E, 0xCED9, 0x9D14, 0x5B6E, 0x432B, 0x3AEA, 0x32C9, 0x2287, 0x32E9, 0x2267,
 0x2247, 0x1A46, 0x2247, 0x2AA8, 0x2247, 0x1A06, 0x2206, 0x19E5, 0x2A68, 0x2A88, 0x2A48, 0x3289, 0x4ACB, 0x6B6D, 0x636D, 0x632D,
 0x6B6D, 0x6B8D, 0x6B6D, 0x634C, 0x6B4C, 0x630B, 0x5AEA, 0x630B, 0x632C, 0x632C, 0x736D, 0x5AEB, 0x62EB, 0x630C, 0x62EB, 0x7BAD,
 0x630B, 0x62EB, 0x5289, 0x62EA, 0x5AAA, 0x62EB, 0x62EB, 0x5AEA, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xD616, 0x8BEE,
 0x5A48, 0x49E7, 0x49E7, 0x4185, 0x3965, 0x3985, 0x3985, 0x3965, 0x3145, 0x3965, 0x3165, 0x3165, 0x3186, 0x4229, 0x4A6A, 0x52AA,
 0x630D, 0x41E7, 0x2903, 0x28E3, 0x20E3, 0x28C3, 0x20C3, 0x20C2, 0x20E4, 0x31C9, 0x6B0E, 0x39C8, 0x2925, 0x10A2, 0x4229, 0x18A3,
 0x2105, 0x2947, 0x2948, 0x2948, 0x2968, 0x3188, 0x10A3, 0x2966, 0x636E, 0x4AED, 0x1926, 0x1924, 0x2986, 0x3A08, 0x4229, 0x3A08,
 0x3A08, 0x4228, 0x3A08, 0x39E8, 0x4269, 0x4269, 0x4229, 0x4249, 0x3A48, 0x3A28, 0x4228, 0x1041, 0x1082, 0xE75C, 0x73F0, 0xD6DA,
 0x94F4, 0x4B0D, 0x3B0A, 0x32C9, 0x32C8, 0x2287, 0x32E9, 0x2267, 0x2287, 0x2AA8, 0x32C9, 0x2AA8, 0x2AA8, 0x2287, 0x2246, 0x2246,
 0x32A8, 0x19C5, 0x2207, 0x3A8A, 0x5B6D, 0x634D, 0x52EB, 0x634D, 0x634D, 0x632C, 0x6B4C, 0x632C, 0x6B4C, 0x6B4C, 0x5AEB, 0x630B,
 0x6B4C, 0x6B2C, 0x5AAA, 0x62EB, 0x6B2C, 0x6B2B, 0x6B2C, 0x630B, 0x62EB, 0x630B, 0x5AA9, 0x62EA, 0x630B, 0x5ACA, 0x62EB, 0x6B2C,
 0xD615, 0xDE16, 0xDE36, 0xDE36, 0xDE16, 0xDE36, 0xDE16, 0xDE37, 0x72EB, 0x5248, 0x4A07, 0x41C7, 0x41C7, 0x41C7, 0x3986, 0x3986,
 0x39A7, 0x39C7, 0x41E8, 0x4A49, 0x4A8A, 0x52CC, 0x634E, 0x632D, 0x4A09, 0x3125, 0x3104, 0x28E3, 0x20C3, 0x28E3, 0x20C3, 0x18A3,
 0x20E4, 0x39E9, 0x3188, 0x3126, 0x1882, 0x0862, 0x1905, 0x1082, 0x18C5, 0x2927, 0x2127, 0x3189, 0x2968, 0x2947, 0x18E4, 0x2966,
 0x29E9, 0x6BD0, 0x1105, 0x08A2, 0x2166, 0x21A7, 0x426A, 0x2146, 0x2124, 0x39C7, 0x3A07, 0x39E8, 0x3A28, 0x3A28, 0x3A28, 0x3208,
 0x3A08, 0x2965, 0x2924, 0x1062, 0xF7BE, 0xEF9D, 0x6B8F, 0xD6DA, 0x8472, 0x534D, 0x3AE9, 0x32E9, 0x2AA8, 0x2287, 0x22A7, 0x2A88,
 0x2AA8, 0x2AC8, 0x2267, 0x2226, 0x2A88, 0x2247, 0x11C5, 0x2A67, 0x2205, 0x1164, 0x3268, 0x3289, 0x532C, 0x5B4D, 0x5B4C, 0x5B2C,
 0x6B6D, 0x634D, 0x632C, 0x6B2C, 0x7BEF, 0x8C50, 0x6B6C, 0x6B6C, 0x6B2C, 0x630B, 0x62EB, 0x6B0C, 0x630B, 0x62EA, 0x62EA, 0x630B,
 0x5ACA, 0x62EA, 0x630B, 0x5AAA, 0x5A89, 0x62EB, 0x62EB, 0x630B, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE57,
 0xDDF5, 0xDE57, 0xCDF6, 0x8BCD, 0x62CA, 0x62CA, 0x62CB, 0x62EB, 0x6B2C, 0x7B6D, 0x8410, 0x9CB2, 0x8CB2, 0x8493, 0x7C52, 0x94F5,
 0x52CB, 0x31C7, 0x2945, 0x2905, 0x2104, 0x28E4, 0x20E4, 0x20E4, 0x2104, 0x2126, 0x29A7, 0x39C8, 0x18E4, 0x0883, 0x3A2A, 0x1082,
 0x2966, 0x31A7, 0x31C8, 0x31C7, 0x31C8, 0x2966, 0x2125, 0x2146, 0x1947, 0x63AF, 0x31E8, 0x2187, 0x29A7, 0x2166, 0x08A3, 0x2926,
 0x1062, 0x0842, 0x0841, 0x1082, 0x2124, 0x31A6, 0x39E7, 0x39E8, 0x3165, 0x0800, 0x1082, 0x636E, 0xEFBD, 0xEF9E, 0x636F, 0xD6D9,
 0x8C93, 0x534D, 0x3B0A, 0x2AA8, 0x2AA7, 0x2AA7, 0x2287, 0x2267, 0x2AC9, 0x2267, 0x2A88, 0x2A87, 0x2226, 0x1A06, 0x2226, 0x2246,
 0x19E5, 0x19C5, 0x2A47, 0x2A48, 0x42EB, 0x5B4D, 0x532C, 0x634C, 0x632C, 0x738E, 0x6B6D, 0x6B4C, 0x632C, 0x630B, 0x632C, 0x6B6C,
 0x6B2C, 0x630B, 0x62EB, 0x630B, 0x62EB, 0x630B, 0x62EA, 0x6B4C, 0x62EA, 0x5ACA, 0x62CB, 0x5ACB, 0x5AAA, 0x630B, 0x5ACA, 0x6B4C,
 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xDE37, 0xD636, 0xDE36, 0xD636, 0xDE36, 0xD636,
 0xDE57, 0xD636, 0xD637, 0xD616, 0xA555, 0x84B4, 0x6BF0, 0x6BB0, 0x6BD0, 0x9D56, 0xADB7, 0x4249, 0x52AB, 0x528A, 0x4A6A, 0x4A6A,
 0x4A6A, 0x3A08, 0x3A09, 0x3A08, 0x29A7, 0x31C7, 0x29A7, 0x2986, 0x31A7, 0x39E8, 0x4249, 0x4A69, 0x4A6A, 0x4A6A, 0x4A8A, 0x3A29,
 0x3A08, 0x39E8, 0x3A08, 0x4228, 0x3A08, 0x29A7, 0x10E4, 0x18A4, 0x0822, 0x0842, 0x0822, 0x1042, 0x1062, 0x0862, 0x18A3, 0x3185,
 0x1062, 0x0061, 0xEF9D, 0x73EF, 0xF7DE, 0xE75D, 0x6BAE, 0xD6FA, 0x84B3, 0x536D, 0x3B0A, 0x32E9, 0x2267, 0x2AA8, 0x2AC8, 0x2287,
 0x2267, 0x2AC8, 0x2AA8, 0x2226, 0x2246, 0x2266, 0x1A06, 0x2A67, 0x2226, 0x2207, 0x3268, 0x3249, 0x4AEB, 0x4AEC, 0x52EC, 0x6BCF,
 0x5B2D, 0x6B8D, 0x6B6D, 0x6B4C, 0x6B4C, 0x632C, 0x6B6D, 0x6B4C, 0x6B4C, 0x62EB, 0x630B, 0x62EB, 0x630B, 0x630B, 0x6B2B, 0x62EA,
 0x5AAA, 0x5ACA, 0x5AAA, 0x5AAA, 0x5ACA, 0x62AA, 0x6B0B, 0x5AC9, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36,
 0xDE36, 0xDE37, 0xDE16, 0xD636, 0xDE36, 0xDE57, 0xDE37, 0xDE57, 0xD637, 0xD637, 0xDE37, 0xDE37, 0xCE17, 0x94D3, 0x6BAF, 0x52ED,
 0x5B4E, 0xBE59, 0x636D, 0x73AE, 0x52AB, 0x52CB, 0x5ACB, 0x52AA, 0x4A69, 0x52AA, 0x4A8A, 0x31C7, 0x3166, 0x39C8, 0x3A08, 0x3A08,
 0x4229, 0x39E8, 0x4229, 0x4A6A, 0x4249, 0x4A8A, 0x4A6A, 0x4A8A, 0x4229, 0x4229, 0x4229, 0x31C7, 0x3A08, 0x3A29, 0x08A3, 0x10A4,
 0x0862, 0x0842, 0x0842, 0x0822, 0x0842, 0x0862, 0x18C4, 0x2124, 0x4A8A, 0x8472, 0xE73C, 0x73F0, 0xEFDD, 0xDEFC, 0x6BCF, 0xD6DA,
 0x7411, 0x536D, 0x2AA9, 0x32C9, 0x2AC8, 0x2287, 0x2287, 0x22A8, 0x2AA8, 0x2267, 0x2246, 0x2246, 0x2267, 0x1A27, 0x11E6, 0x1A47,
 0x19E6, 0x3289, 0x32AA, 0x4B4C, 0x42EB, 0x4AEB, 0x634D, 0x634D, 0x52EC, 0x6B6D, 0x6B6D, 0x6B4C, 0x6B4C, 0x6B6D, 0x6B4C, 0x630B,
 0x6B2C, 0x630B, 0x630B, 0x6B2B, 0x6B2C, 0x6B2C, 0x62EB, 0x630B, 0x62EB, 0x62EA, 0x62EB, 0x5AAA, 0x5ACA, 0x62EB, 0x62CA, 0x630A,
 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xDE36, 0xDE37, 0xDE37, 0xDE37, 0xDE36, 0xDE36, 0xDE36, 0xD636,
 0xDE37, 0xDE37, 0xD637, 0xD637, 0xD616, 0xBDD6, 0x7C31, 0x530D, 0x52EC, 0xB619, 0xA5B7, 0x8CB3, 0x52AB, 0x52CB, 0x528A, 0x5ACB,
 0x528A, 0x528A, 0x528A, 0x4A8A, 0x4208, 0x39C7, 0x3186, 0x4229, 0x4249, 0x4269, 0x426A, 0x52CB, 0x3A29, 0x4A8A, 0x52CB, 0x4A49,
 0x4A8A, 0x4249, 0x424A, 0x4229, 0x3A28, 0x3A08, 0x3A09, 0x3A09, 0x3A08, 0x3A29, 0x31E8, 0x2145, 0x10C3, 0x2145, 0x2966, 0xE75B,
 0x6B8E, 0x94D3, 0xDF1B, 0x73D0, 0xEFBD, 0xCE9A, 0x636E, 0xD6BA, 0x636E, 0x4B4C, 0x2AA8, 0x3B0A, 0x2AC8, 0x2288, 0x32E9, 0x2AC8,
 0x2267, 0x1A46, 0x2267, 0x2A87, 0x2226, 0x1A26, 0x438C, 0x330A, 0x19A5, 0x3288, 0x432C, 0x4B2C, 0x4AEC, 0x52EC, 0x5AEB, 0x5B4D,
 0x5B0C, 0x6B6D, 0x634C, 0x6B4C, 0x632C, 0x632C, 0x6B4C, 0x630B, 0x6B4C, 0x6B2C, 0x634C, 0x6B2C, 0x6B2B, 0x630B, 0x630B, 0x630B,
 0x6B4C, 0x62EB, 0x5ACA, 0x5ACA, 0x630B, 0x6B2B, 0x5ACA, 0x5ACA, 0xD616, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36,
 0xDE36, 0xDE37, 0xDE37, 0xDE37, 0xDE36, 0xDE36, 0xDE36, 0xD636, 0xDE37, 0xDE37, 0xD637, 0xD637, 0xD637, 0xCE37, 0xA597, 0x6BAF,
 0x5B0D, 0xA597, 0x8CD4, 0x73F1, 0x6B8E, 0x528A, 0x5AAA, 0x5269, 0x4A29, 0x528A, 0x4A8A, 0x4A8A, 0x4248, 0x39C7, 0x39E7, 0x31A7,
 0x31E7, 0x4249, 0x4269, 0x4A8A, 0x4A8A, 0x3A28, 0x4A6A, 0x426A, 0x4249, 0x424A, 0x3A49, 0x4249, 0x426A, 0x4249, 0x3A09, 0x4229,
 0x3A29, 0x4229, 0x31A7, 0x31A7, 0x31C7, 0x2987, 0x2986, 0xDF3B, 0x73AF, 0xA575, 0xE73C, 0x73AF, 0xE77C, 0xBE38, 0x638E, 0xD6FA,
 0x638F, 0x4B4C, 0x2AA8, 0x3B0A, 0x2287, 0x2288, 0x32E9, 0x2AA8, 0x2AC8, 0x1A46, 0x1A46, 0x2AA7, 0x2226, 0x1A05, 0x2A88, 0x1A26,
 0x1A06, 0x32A8, 0x2AEB, 0x2A89, 0x4B2C, 0x52EB, 0x634C, 0x532D, 0x6B8E, 0x6B6D, 0x634D, 0x736D, 0x6B2C, 0x6B4C, 0x6B6D, 0x632C,
 0x5ACA, 0x6B2C, 0x632C, 0x6B2C, 0x630B, 0x62EB, 0x62EB, 0x630B, 0x6B6D, 0x630B, 0x5ACA, 0x5ACA, 0x5AAA, 0x62EA, 0x630A, 0x5ACA,
 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE57,
 0xDE57, 0xDE37, 0xD637, 0xD637, 0xD617, 0xD638, 0xCEBB, 0x8CF5, 0x6BB0, 0x9515, 0xA597, 0x8CF4, 0x8CD3, 0x52CB, 0x5289, 0x5289,
 0x5269, 0x4A28, 0x528A, 0x4A6A, 0x4A49, 0x4208, 0x31A6, 0x39E8, 0x31A6, 0x31A6, 0x31E7, 0x3A29, 0x4269, 0x4269, 0x4249, 0x426A,
 0x3A09, 0x3A09, 0x3A09, 0x3209, 0x31C8, 0x3A08, 0x3A08, 0x3A08, 0x31C7, 0x2165, 0x2966, 0x2986, 0x2986, 0x2187, 0x4269, 0xDF1B,
 0x73D0, 0xB5D7, 0xE73C, 0x6BB0, 0xDF3C, 0xB618, 0x6B8F, 0xD6FA, 0x530D, 0x4B4C, 0x2AA8, 0x434A, 0x2AA8, 0x2287, 0x2267, 0x2AC9,
 0x2AA8, 0x1A46, 0x2267, 0x2A88, 0x2247, 0x2247, 0x2A67, 0x1A26, 0x3289, 0x1A07, 0x434C, 0x2207, 0x3248, 0x4269, 0x6B8E, 0x52EB,
 0x5B2C, 0x634C, 0x630B, 0x6B2C, 0x630B, 0x630B, 0x6B2C, 0x62EB, 0x630B, 0x5AEA, 0x6B2C, 0x6B4C, 0x630B, 0x632B, 0x630B, 0x62EB,
 0x62CA, 0x6B2B, 0x5AA9, 0x5AA9, 0x5ACA, 0x5ACA, 0x632B, 0x6B2B, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36,
 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE57, 0xDE57, 0xDE37, 0xD637, 0xD637, 0xD637, 0xCE38, 0xC67A, 0xA5D8,
 0x84B4, 0x8493, 0xB639, 0x9515, 0x9D35, 0x6B8E, 0x5ACA, 0x5AAA, 0x528A, 0x4A49, 0x528A, 0x4A49, 0x4A49, 0x4249, 0x4249, 0x4209,
 0x31A6, 0x2965, 0x2965, 0x31C7, 0x3A28, 0x4249, 0x4269, 0x4249, 0x4249, 0x3A29, 0x29A7, 0x29A7, 0x2986, 0x31A7, 0x29A6, 0x2986,
 0x2986, 0x2966, 0x2165, 0x2145, 0x2166, 0x29C8, 0x634D, 0xE73B, 0x73F0, 0xC679, 0xEF9D, 0x73D0, 0xDF1B, 0xB5D8, 0x6BAF, 0xD71A,
 0x532D, 0x3AEB, 0x32C9, 0x432A, 0x2AA7, 0x2287, 0x32C8, 0x2288, 0x32E9, 0x2267, 0x2A88, 0x2267, 0x1A05, 0x2226, 0x1A26, 0x1A46,
 0x2A68, 0x19C6, 0x2A48, 0x2A88, 0x1965, 0x3A89, 0x5B2C, 0x6B6E, 0x634D, 0x636D, 0x6B4C, 0x632B, 0x630B, 0x6B2C, 0x6B2C, 0x62EB,
 0x630B, 0x630B, 0x630B, 0x62EB, 0x6B4C, 0x630B, 0x630B, 0x630B, 0x62EB, 0x6B2B, 0x5ACA, 0x62EB, 0x5ACA, 0x630B, 0x62EB, 0x736C,
 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37,
 0xDE57, 0xDE37, 0xD637, 0xD637, 0xD637, 0xC637, 0xCE9A, 0xA5F9, 0x8D16, 0x8D15, 0xBE7A, 0x9535, 0x9D56, 0x7C31, 0x6B8E, 0x630B,
 0x5AAA, 0x5269, 0x5269, 0x4228, 0x4A69, 0x4A69, 0x4228, 0x4229, 0x39C7, 0x2965, 0x2145, 0x2966, 0x31E8, 0x3A08, 0x4229, 0x4249,
 0x4269, 0x4A8A, 0x428A, 0x3A29, 0x3A08, 0x31C7, 0x29A7, 0x2986, 0x2166, 0x2166, 0x2166, 0x2165, 0x2146, 0x426A, 0x8CD3, 0xDEFA,
 0x8CD2, 0xD6FB, 0xEF9D, 0x7410, 0xDF1B, 0xAD96, 0x6B8E, 0xD6D9, 0x4AEC, 0x430B, 0x330A, 0x3B0A, 0x32E8, 0x2AA8, 0x2A67, 0x22A7,
 0x32C9, 0x32C8, 0x2267, 0x1A06, 0x1A26, 0x2247, 0x2A88, 0x32E9, 0x2247, 0x2207, 0x3289, 0x3289, 0x21C6, 0x5B8E, 0x5B4D, 0x634D,
 0x7BEF, 0x6BAE, 0x6B4C, 0x6B4C, 0x6B4C, 0x632C, 0x6B4C, 0x736D, 0x5ACA, 0x7BAE, 0x62EB, 0x632B, 0x6B2B, 0x630B, 0x62EA, 0x62EB,
 0x5AA9, 0x5ACA, 0x6B4C, 0x62EB, 0x5ACA, 0x62EB, 0x6B2B, 0x630B, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36,
 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE57, 0xDE57, 0xD637, 0xD637, 0xD637, 0xC638, 0xBE19, 0x9D97,
 0x84D4, 0x8CF5, 0xB639, 0xADD8, 0x8CF4, 0x7C51, 0x8C92, 0x632C, 0x5AEB, 0x52AA, 0x528A, 0x4A69, 0x4A69, 0x4A69, 0x4228, 0x3A07,
 0x31A7, 0x2986, 0x2965, 0x2145, 0x29A6, 0x31C7, 0x4229, 0x4A6A, 0x4A6A, 0x4A6A, 0x4A8A, 0x4A49, 0x4249, 0x39E8, 0x29A7, 0x2966,
 0x2125, 0x2125, 0x2145, 0x2165, 0x2986, 0x29A7, 0x8451, 0xCE98, 0xDEDA, 0xEF7D, 0xF79C, 0xEF5C, 0xDF1A, 0xD71A, 0xD6DA, 0xDF1A,
 0x8CB2, 0x6C4F, 0x32E9, 0x432B, 0x2AA7, 0x2A67, 0x32C9, 0x2287, 0x2AA8, 0x2287, 0x2266, 0x2226, 0x1A25, 0x2246, 0x1A26, 0x2288,
 0x2A48, 0x2A68, 0x2ACA, 0x1AAB, 0x2207, 0x3A49, 0x6B8E, 0x6B8E, 0x634C, 0x634D, 0x738D, 0x630C, 0x6B2C, 0x738D, 0x630B, 0x6B2C,
 0x62EB, 0x62EB, 0x632B, 0x6B2B, 0x5ACA, 0x6B4B, 0x630B, 0x62EB, 0x62EA, 0x5AEA, 0x5AEA, 0x5AA9, 0x6B4C, 0x5AAA, 0x630B, 0x630B,
 0xDE16, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE57, 0xDE36, 0xDE37, 0xDE37, 0xDE57, 0xDE37,
 0xDE57, 0xD637, 0xDE37, 0xD637, 0xD637, 0xCE37, 0xBDF7, 0xA5D8, 0x84F5, 0x84B4, 0x9556, 0x9D97, 0x8CF4, 0x8CB3, 0x9D14, 0x7BCF,
 0x630C, 0x52AA, 0x528A, 0x4A49, 0x4A69, 0x4A69, 0x4249, 0x4207, 0x39E7, 0x31A6, 0x2965, 0x2945, 0x2966, 0x2986, 0x31C7, 0x4249,
 0x4A8A, 0x4AAA, 0x4A69, 0x4A69, 0x4249, 0x39E7, 0x31C7, 0x2966, 0x1925, 0x1104, 0x1924, 0x2145, 0x29A6, 0x29A8, 0xADB6, 0xDF1C,
 0x7C31, 0xEFBD, 0xCEBB, 0x6BCF, 0xDF1B, 0x7C11, 0x5AEB, 0xD6FA, 0x4AAA, 0x3AC9, 0x32A8, 0x3B2A, 0x2267, 0x2267, 0x2AC8, 0x2AC9,
 0x2267, 0x1A66, 0x2267, 0x2A87, 0x1A05, 0x2246, 0x1A26, 0x2A88, 0x2267, 0x2A26, 0x2A89, 0x2A89, 0x2A47, 0x3269, 0x636D, 0x636D,
 0x6B6D, 0x632C, 0x6B4C, 0x6B2C, 0x738D, 0x6B4C, 0x6B4C, 0x6B4D, 0x630C, 0x5AEB, 0x62EB, 0x630B, 0x630B, 0x632B, 0x630B, 0x5AAA,
 0x62EB, 0x62EB, 0x62CA, 0x630B, 0x62EB, 0x5ACA, 0x630B, 0x5AEA, 0xDE16, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36,
 0xDE37, 0xDE36, 0xDE36, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE57, 0xDE57, 0xDE57, 0xD637, 0xC5F7, 0xC638, 0x9D97,
 0x84F5, 0x84D5, 0x9556, 0xB65A, 0x8CF4, 0x8CF4, 0x73CF, 0x8C71, 0x630C, 0x632C, 0x5AAA, 0x5269, 0x4A69, 0x4A69, 0x4A49, 0x4228,
 0x39E7, 0x31A6, 0x2986, 0x2965, 0x2165, 0x2165, 0x2986, 0x3A08, 0x4A69, 0x4A69, 0x4A89, 0x4A69, 0x4A6A, 0x4228, 0x4228, 0x31C7,
 0x2986, 0x1924, 0x10E3, 0x1924, 0x29A6, 0x2146, 0xBE38, 0xDF3D, 0x6BD0, 0xEF9D, 0xADD7, 0x73F0, 0xD6FA, 0x7411, 0x530C, 0xD6FB,
 0x42AA, 0x432B, 0x2AA8, 0x32E9, 0x2A87, 0x2AA8, 0x1A26, 0x22A8, 0x2267, 0x2266, 0x2246, 0x2246, 0x2266, 0x2247, 0x1A26, 0x2247,
 0x2227, 0x2228, 0x3AAB, 0x3B0B, 0x2A28, 0x3A29, 0x636D, 0x636D, 0x636D, 0x6B4D, 0x632C, 0x6B6D, 0x6B6D, 0x630B, 0x7BAE, 0x6B2C,
 0x630B, 0x630B, 0x630B, 0x62EB, 0x5ACA, 0x62EA, 0x6B2B, 0x5ACA, 0x630B, 0x5AAA, 0x5AA9, 0x5ACA, 0x5AEA, 0x5ACA, 0x62EB, 0x630B,
 0xDE16, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xDE36, 0xDE37, 0xDE36, 0xDE37, 0xDE37, 0xDE37, 0xDE37,
 0xDE37, 0xDE57, 0xD637, 0xDE37, 0xD637, 0xCE38, 0xBE18, 0xAE19, 0x84F5, 0x8D16, 0x84D4, 0x9535, 0x8CF4, 0x8493, 0x73F0, 0x8430,
 0x6B2C, 0x5ACA, 0x5AAA, 0x528A, 0x528A, 0x4A8A, 0x528A, 0x3A07, 0x39C7, 0x31A6, 0x2965, 0x2986, 0x2985, 0x2965, 0x2965, 0x31A6,
 0x39E7, 0x39E6, 0x4228, 0x4228, 0x4A69, 0x52AA, 0x4A69, 0x3A08, 0x31C6, 0x29A6, 0x2145, 0x1904, 0x2145, 0x2146, 0xC658, 0xDF3D,
 0x6BD0, 0xE77C, 0x9514, 0x6BAF, 0xCEDA, 0x6BB0, 0x532D, 0xD6DA, 0x4ACB, 0x432B, 0x32A8, 0x3B0A, 0x32C9, 0x2AC8, 0x2267, 0x2AC8,
 0x32C9, 0x2246, 0x2287, 0x2266, 0x2246, 0x1A26, 0x1A47, 0x22A8, 0x1A07, 0x12AB, 0x328B, 0x42AA, 0x534D, 0x4AAA, 0x73AE, 0x73AE,
 0x634D, 0x634C, 0x6B8D, 0x6B6D, 0x632B, 0x6B4C, 0x6B4C, 0x632B, 0x73AD, 0x5ACA, 0x630B, 0x6B4D, 0x6B4C, 0x630B, 0x630B, 0x6B2C,
 0x630B, 0x5AA9, 0x630B, 0x734C, 0x630B, 0x62EA, 0x62EB, 0x630B, 0xDE16, 0xDE16, 0xDE36, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE37,
 0xDE37, 0xDE36, 0xDE37, 0xDE36, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE57, 0xDE57, 0xDE37, 0xDE37, 0xD637, 0xC638, 0xBE18, 0xAE18,
 0x9577, 0x9DB8, 0x84B4, 0x9D97, 0xBE7A, 0x9D76, 0x8472, 0x8C91, 0x83EF, 0x62EB, 0x5AAA, 0x528A, 0x5289, 0x4A89, 0x4A69, 0x4248,
 0x39C7, 0x31A6, 0x2986, 0x2986, 0x2966, 0x2145, 0x2945, 0x2985, 0x31A6, 0x31A6, 0x39E7, 0x4208, 0x4228, 0x4A48, 0x52AA, 0x4A69,
 0x3A07, 0x31C7, 0x2965, 0x2144, 0x1924, 0x2125, 0x9D34, 0xDF3C, 0x7411, 0xE73C, 0x8492, 0x6BF0, 0xD6FA, 0x638F, 0x4ACB, 0xD6FA,
 0x4AEB, 0x3B0A, 0x2AA8, 0x3B0A, 0x2AA8, 0x2AA8, 0x2AA8, 0x3B0A, 0x2AA8, 0x2267, 0x2287, 0x1A46, 0x2246, 0x2267, 0x1A46, 0x2AA8,
 0x1A05, 0x1AAA, 0x19A6, 0x22CA, 0x42CC, 0x638E, 0x634C, 0x636D, 0x6B8E, 0x632C, 0x632C, 0x6B6D, 0x632C, 0x73AE, 0x6B2C, 0x5AAA,
 0x6B2C, 0x6B4C, 0x6B2C, 0x630B, 0x738D, 0x630B, 0x630B, 0x630B, 0x630B, 0x62EA, 0x632B, 0x62EB, 0x5ACA, 0x5ACA, 0x5ACA, 0x6B4C,
 0xDE16, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xD637,
 0xDE37, 0xDE57, 0xDE37, 0xDE37, 0xD637, 0xCE38, 0xBE18, 0xB618, 0x9557, 0x84F4, 0x8493, 0xA5B7, 0x9D76, 0x84B3, 0x9D35, 0x8451,
 0x8410, 0x630C, 0x5AEB, 0x528A, 0x4A69, 0x4A69, 0x4228, 0x4228, 0x3A07, 0x39C7, 0x31A6, 0x2986, 0x29A6, 0x2965, 0x2965, 0x2986,
 0x29A6, 0x31C7, 0x39E7, 0x39E7, 0x4208, 0x4207, 0x4A48, 0x4A49, 0x4A69, 0x4228, 0x31A6, 0x2986, 0x2145, 0x2145, 0x2144, 0xEFFF,
 0x6BF1, 0xDEFA, 0x73F1, 0x6BD0, 0xCED9, 0x6390, 0x42AA, 0xD6FA, 0x428B, 0x3B0A, 0x2AA8, 0x3B0A, 0x3B2A, 0x2A87, 0x2267, 0x2AA8,
 0x2AA8, 0x2A87, 0x2267, 0x1A26, 0x2246, 0x2246, 0x2AA8, 0x32EA, 0x19E6, 0x3248, 0x3AC9, 0x1208, 0x19E8, 0x63AE, 0x6B8E, 0x634D,
 0x6BAE, 0x6B6D, 0x6B6D, 0x6B4C, 0x6B6D, 0x630B, 0x736D, 0x632C, 0x736D, 0x630B, 0x6B2B, 0x6B4C, 0x6B2B, 0x5B0A, 0x6B6C, 0x6B2B,
 0x5AA9, 0x5A89, 0x62EA, 0x5ACA, 0x5ACA, 0x630B, 0x632B, 0x62CA, 0xDE36, 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE37,
 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xD637, 0xDE37, 0xDE57, 0xDE37, 0xDE57, 0xDE37, 0xCE38, 0xBDF7, 0xB5F8,
 0xA5D8, 0x5BB0, 0x8494, 0x8CF5, 0x9515, 0x7C93, 0x8493, 0x94D3, 0x8C51, 0x7BCF, 0x5AEB, 0x52AA, 0x4A49, 0x528A, 0x4228, 0x4228,
 0x3A08, 0x39E7, 0x31A6, 0x31A6, 0x2986, 0x2986, 0x2985, 0x2986, 0x2986, 0x2985, 0x2986, 0x31A6, 0x31C7, 0x4228, 0x4228, 0x4A69,
 0x5289, 0x4A89, 0x3A08, 0x31C7, 0x2966, 0x2125, 0x2965, 0x1105, 0x7C94, 0xDF1B, 0x6BF1, 0x6BD0, 0xD6FA, 0x532E, 0x42AA, 0xD6FA,
 0x3A6A, 0x3AEA, 0x3B09, 0x32C9, 0x3B0A, 0x2AC8, 0x2287, 0x2287, 0x2AC8, 0x1A46, 0x2266, 0x2266, 0x2267, 0x1A25, 0x2267, 0x2267,
 0x11C5, 0x3AEB, 0x2226, 0x2247, 0x2A48, 0x42AA, 0x6BAE, 0x636D, 0x636D, 0x73CE, 0x6B6D, 0x6B4C, 0x6B4C, 0x6B4C, 0x6B6D, 0x5ACA,
 0x6B4C, 0x6B2B, 0x62EA, 0x630B, 0x6B4C, 0x630B, 0x6B4C, 0x630B, 0x5ACA, 0x62EA, 0x62CA, 0x630B, 0x5ACA, 0x5ACA, 0x5AEA, 0x62CA,
 0xDE16, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37,
 0xD637, 0xDE37, 0xDE37, 0xDE37, 0xD637, 0xD658, 0xBE18, 0xB5F8, 0xA5D8, 0x84F5, 0x8494, 0x7C73, 0x7C73, 0x9536, 0x9D56, 0x9515,
 0x7C10, 0x7BCF, 0x6B6D, 0x5ACA, 0x5269, 0x4A69, 0x4A49, 0x4208, 0x3A07, 0x31C6, 0x31C6, 0x31A6, 0x2986, 0x2965, 0x2965, 0x2965,
 0x2986, 0x2986, 0x31A7, 0x29A6, 0x31A6, 0x39C6, 0x4228, 0x4A49, 0x4A69, 0x4A89, 0x4228, 0x3A07, 0x31A6, 0x2966, 0x2124, 0x1925,
 0x8473, 0xDF1A, 0x7412, 0x6BD0, 0xD6DA, 0x5B6F, 0x3A8A, 0xD6DA, 0x4ACB, 0x3B0A, 0x2AA8, 0x32C9, 0x32E9, 0x32E8, 0x2AC8, 0x2287,
 0x2267, 0x1A05, 0x2246, 0x2AA8, 0x1A25, 0x2245, 0x2246, 0x2267, 0x11A6, 0x2A69, 0x2A27, 0x21E6, 0x3AAA, 0x29E7, 0x636D, 0x632C,
 0x6B6D, 0x73CE, 0x634C, 0x632C, 0x6B4C, 0x6B2C, 0x632C, 0x6B2C, 0x630B, 0x6B2C, 0x6B2C, 0x632C, 0x632B, 0x6B4C, 0x6B4C, 0x62EB,
 0x632B, 0x5ACA, 0x5ACA, 0x6B2B, 0x62EB, 0x62EA, 0x62EA, 0x5ACA, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE37,
 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xD657, 0xD658, 0xCE7A, 0xA596,
 0xA5B8, 0x8D16, 0x6C12, 0x6BF1, 0x6BD0, 0x7C72, 0xB618, 0xA576, 0x8C72, 0x7C10, 0x8430, 0x6B4C, 0x52AA, 0x4A89, 0x5289, 0x4A48,
 0x4207, 0x39C6, 0x31A6, 0x3186, 0x2986, 0x2965, 0x2965, 0x2986, 0x2965, 0x31A6, 0x2986, 0x29A5, 0x2986, 0x31A5, 0x31C6, 0x3A08,
 0x4A48, 0x4A88, 0x4248, 0x4228, 0x39E7, 0x2986, 0x2144, 0x1924, 0x2145, 0xDEFA, 0x63B0, 0x63AF, 0xD6DA, 0x532E, 0x29E8, 0xD6DA,
 0x4AEB, 0x3B0A, 0x32C8, 0x32E9, 0x32E9, 0x2267, 0x2AA7, 0x1A66, 0x2AA8, 0x2247, 0x2267, 0x2267, 0x11E4, 0x1A25, 0x2267, 0x11E6,
 0x3AEB, 0x2A88, 0x3ACA, 0x1A07, 0x3AAA, 0x3208, 0x52CB, 0x634C, 0x8430, 0x632C, 0x6B6D, 0x6B4C, 0x630B, 0x632C, 0x6B4C, 0x632C,
 0x738D, 0x630B, 0x632B, 0x632C, 0x6B4B, 0x630A, 0x632B, 0x630B, 0x6B4C, 0x6B2C, 0x5ACA, 0x62EA, 0x6B0B, 0x62C9, 0x5AA9, 0x62CB,
 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xD637,
 0xDE37, 0xDE37, 0xDE57, 0xDE57, 0xD637, 0xCE38, 0xC618, 0xC69A, 0x8D36, 0x8D57, 0x8D16, 0x7412, 0x7411, 0x7C73, 0x7C52, 0xADB7,
 0x8C92, 0x7BF0, 0x8410, 0x73AE, 0x5AEB, 0x52A9, 0x5289, 0x4A69, 0x4228, 0x39C6, 0x39C7, 0x3186, 0x29A6, 0x2985, 0x2986, 0x2986,
 0x2986, 0x2986, 0x2986, 0x31A5, 0x2985, 0x2985, 0x3186, 0x31C6, 0x4208, 0x4A28, 0x4228, 0x4228, 0x3A08, 0x39E7, 0x2965, 0x2104,
 0x2124, 0x10A3, 0x63D0, 0x5B4E, 0xD6DA, 0x532F, 0x31E7, 0xD6FA, 0x532C, 0x3B2A, 0x2AA8, 0x32A9, 0x2288, 0x2A87, 0x32A8, 0x32C8,
 0x2A87, 0x2246, 0x2246, 0x2287, 0x1A05, 0x11C4, 0x2A67, 0x1A06, 0x2A68, 0x2A67, 0x19A5, 0x430C, 0x42CB, 0x534D, 0x4269, 0x6B6E,
 0x6B6E, 0x6B6D, 0x6B4D, 0x632C, 0x5ACA, 0x6B4C, 0x632C, 0x630B, 0x7BEE, 0x5ACA, 0x630B, 0x630C, 0x630B, 0x6B2C, 0x630B, 0x630B,
 0x6B2C, 0x6B0B, 0x630B, 0x6B2B, 0x62EA, 0x5AA9, 0x630B, 0x52A9, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xDE37,
 0xDE37, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xDE37, 0xDE37, 0xD637, 0xDE37, 0xDE37, 0xD637, 0xD637, 0xD637, 0xCE37, 0xDEBA, 0xBE59,
 0xB67A, 0x7CD5, 0x8D16, 0x8CF5, 0x9D56, 0x9515, 0x8CD4, 0x9D35, 0x8493, 0x94B3, 0x7BEF, 0x7BEF, 0x7BEF, 0x630B, 0x5289, 0x4A69,
 0x4228, 0x4207, 0x31C6, 0x31C7, 0x31A7, 0x31A6, 0x2986, 0x29A6, 0x3186, 0x2986, 0x2986, 0x2985, 0x2965, 0x2965, 0x2165, 0x2985,
 0x31A6, 0x39C6, 0x4A28, 0x4A28, 0x4248, 0x3A07, 0x31A6, 0x2945, 0x2144, 0x2124, 0x3229, 0x5B4E, 0xD6DA, 0x532F, 0x29A6, 0xCEDA,
 0x532C, 0x32C8, 0x32E9, 0x32C9, 0x3AEA, 0x2267, 0x2247, 0x2AA8, 0x2267, 0x2246, 0x2A67, 0x1A26, 0x11C4, 0x2246, 0x2246, 0x2247,
 0x19E5, 0x32C9, 0x1185, 0x2A69, 0x538E, 0x3A8A, 0x428A, 0x6B8D, 0x6B6D, 0x6B8D, 0x6B4D, 0x632C, 0x7BEF, 0x632C, 0x6B4C, 0x6B4C,
 0x73AE, 0x5AEB, 0x738D, 0x630B, 0x52AA, 0x5ACA, 0x62EA, 0x6B6C, 0x630B, 0x5AAA, 0x6B4C, 0x630B, 0x5AAA, 0x5ACA, 0x5AA9, 0x5ACA,
 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE57, 0xDE36, 0xDE37, 0xDE37, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xDE37, 0xDE37, 0xD637,
 0xD637, 0xD637, 0xD637, 0xD637, 0xD637, 0xD637, 0xC5D6, 0xBE59, 0xADF9, 0x9557, 0x84F6, 0x6390, 0x6BD0, 0x7C73, 0x8CD4, 0x8CD4,
 0x9D35, 0x8CB3, 0x8451, 0x73CF, 0x73AE, 0x6B4D, 0x52AA, 0x52AA, 0x4A69, 0x4228, 0x3A08, 0x39C7, 0x31C7, 0x31C7, 0x31A6, 0x31A6,
 0x31A6, 0x31A6, 0x2966, 0x2986, 0x2985, 0x2145, 0x2965, 0x2986, 0x31A6, 0x31A6, 0x39E7, 0x4228, 0x4228, 0x4228, 0x39C6, 0x3186,
 0x2145, 0x1924, 0x2125, 0x4AAB, 0xDF1B, 0x532E, 0x3A48, 0xCEFA, 0x4AEB, 0x3B09, 0x2AA8, 0x434B, 0x32E9, 0x1A45, 0x2AC8, 0x2266,
 0x1A05, 0x2226, 0x2246, 0x2AA8, 0x1A06, 0x2246, 0x2226, 0x2226, 0x2226, 0x2206, 0x19C6, 0x32CA, 0x42EB, 0x534C, 0x636D, 0x6BAE,
 0x73AE, 0x6B6D, 0x6B8D, 0x6B4D, 0x632C, 0x6B2C, 0x6B6D, 0x6B4C, 0x62EB, 0x630B, 0x630B, 0x6B2C, 0x5ACA, 0x7BAE, 0x62EA, 0x632B,
 0x6B4C, 0x6B2C, 0x736D, 0x630B, 0x736C, 0x62CA, 0x62EA, 0x5ACA, 0xDE16, 0xDE36, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xDE37,
 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xDE37, 0xD637, 0xD637, 0xDE37, 0xD637, 0xD637, 0xD637, 0xD637, 0xC5F7, 0xAD96,
 0x9D76, 0x8D36, 0x8D16, 0x84B5, 0x7432, 0x63B0, 0x8493, 0x8CD4, 0xA597, 0x8492, 0x8C92, 0x8C92, 0x7C10, 0x7BEF, 0x6B2C, 0x52A9,
 0x4A69, 0x4A48, 0x4228, 0x4228, 0x3A07, 0x39E7, 0x31C7, 0x31A7, 0x31C6, 0x31A6, 0x31A6, 0x2986, 0x2986, 0x2966, 0x2966, 0x2986,
 0x2986, 0x2985, 0x2986, 0x3186, 0x39E7, 0x4207, 0x39E7, 0x31A6, 0x2985, 0x2145, 0x20E4, 0x1904, 0xEFBE, 0x532F, 0x4ACB, 0xD6FA,
 0x534C, 0x32E9, 0x3B0A, 0x32C9, 0x2A88, 0x2287, 0x2287, 0x2287, 0x2245, 0x1A05, 0x2226, 0x2246, 0x2247, 0x1A25, 0x2A87, 0x2246,
 0x1A06, 0x2A47, 0x21E6, 0x2289, 0x2A48, 0x4B0C, 0x632C, 0x6BAE, 0x634D, 0x6B6D, 0x632C, 0x6B8E, 0x634C, 0x6B6D, 0x632B, 0x632B,
 0x630B, 0x6B6C, 0x6B2C, 0x6B0C, 0x5ACA, 0x630B, 0x6B4C, 0x5AEA, 0x6B2C, 0x62EA, 0x630B, 0x6B0C, 0x6B4C, 0x5A89, 0x62CA, 0x5AA9,
 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE56, 0xDE17, 0xDE36, 0xD637, 0xDE37, 0xD5F6, 0xDE58,
 0xDE57, 0xD637, 0xD637, 0xDE37, 0xDE37, 0xD637, 0xC5D6, 0xBDF7, 0xA597, 0x9D98, 0x7453, 0x7452, 0x8494, 0x9D77, 0x84D4, 0x9535,
 0x94F4, 0x9D34, 0x7C52, 0x8C92, 0x73EF, 0x73CF, 0x6B6D, 0x632C, 0x52CB, 0x4A89, 0x4228, 0x4228, 0x3A08, 0x39E7, 0x31E7, 0x31E7,
 0x31A6, 0x31A6, 0x31A6, 0x29A6, 0x2986, 0x2986, 0x2985, 0x2986, 0x2985, 0x2965, 0x2945, 0x2965, 0x3165, 0x39C7, 0x39C7, 0x31A6,
 0x3186, 0x2965, 0x2145, 0x2104, 0x2104, 0x5B4E, 0x532D, 0xD6DA, 0x42EB, 0x3309, 0x2AA8, 0x2AA8, 0x3AE9, 0x2247, 0x1A46, 0x1A46,
 0x2266, 0x2287, 0x2246, 0x2286, 0x1A05, 0x2246, 0x2266, 0x2266, 0x2A88, 0x2247, 0x2226, 0x0985, 0x21E7, 0x534D, 0x6BAE, 0x634C,
 0x634C, 0x5B0C, 0x6B4D, 0x6B4D, 0x6B4C, 0x632C, 0x630B, 0x5AEA, 0x6B2C, 0x632B, 0x630B, 0x6B2C, 0x630B, 0x62EB, 0x630B, 0x62EB,
 0x630B, 0x62CA, 0x62EA, 0x62EA, 0x5ACA, 0x5A89, 0x62EB, 0x630B, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36,
 0xDE37, 0xD637, 0xDE37, 0xD637, 0xD637, 0xDE37, 0xDE78, 0x5A68, 0xDE57, 0xD637, 0xD617, 0xD617, 0xD637, 0xD637, 0xCE17, 0xBDD6,
 0xA5B7, 0x9557, 0x7494, 0x7CB4, 0xA5D9, 0x63B0, 0x7C72, 0x8CF4, 0x94F4, 0xA555, 0x8472, 0x8471, 0x8C71, 0x73CF, 0x632C, 0x5ACB,
 0x52AA, 0x4A69, 0x4A69, 0x4228, 0x4228, 0x4228, 0x39E7, 0x31C7, 0x31C7, 0x3186, 0x31A6, 0x31A6, 0x31A6, 0x29A5, 0x2985, 0x2985,
 0x2965, 0x2966, 0x2945, 0x2945, 0x2945, 0x2965, 0x31A6, 0x3186, 0x31A6, 0x3185, 0x2945, 0x2124, 0x1924, 0x2125, 0x8471, 0xD6FA,
 0x4B0C, 0x3B0A, 0x3B09, 0x2AA7, 0x32E9, 0x2A87, 0x2287, 0x2A87, 0x2AA7, 0x32A8, 0x2247, 0x1A05, 0x2226, 0x2A67, 0x2266, 0x2267,
 0x2247, 0x2247, 0x2A47, 0x2228, 0x3AAA, 0x536E, 0x42CB, 0x6B6D, 0x6B6D, 0x634D, 0x6B6D, 0x632C, 0x6B4D, 0x632C, 0x62EB, 0x632C,
 0x736D, 0x632B, 0x6B2C, 0x6B4C, 0x632C, 0x6B2C, 0x632C, 0x5AEB, 0x6B2C, 0x62EA, 0x6B2B, 0x62EA, 0x6B4C, 0x62EB, 0x5AAA, 0x5269,
 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xD616, 0xDE78, 0xD616, 0xD616, 0xD637, 0x9430, 0xC617, 0xC5F7,
 0xCE17, 0xDE78, 0xD657, 0xBD54, 0xD637, 0xD637, 0xCE17, 0xCE17, 0xB5F8, 0x9D97, 0x8D16, 0x7CB4, 0x8CD5, 0x7452, 0x7C73, 0x84B3,
 0x8CB3, 0x8C92, 0x8CB3, 0x8C72, 0x7C10, 0x73CF, 0x73CE, 0x630C, 0x5B0C, 0x52CA, 0x4A69, 0x4248, 0x4228, 0x4208, 0x3A08, 0x39E7,
 0x31C7, 0x31A7, 0x31A6, 0x31C7, 0x31A6, 0x31A6, 0x31A6, 0x2965, 0x3186, 0x2965, 0x2965, 0x2965, 0x2945, 0x2945, 0x2145, 0x2965,
 0x31A6, 0x3185, 0x2965, 0x2945, 0x2124, 0x2104, 0x18E3, 0xD6DA, 0x4B0C, 0x3B09, 0x32A8, 0x2AA7, 0x2AA8, 0x2AA8, 0x32E8, 0x2226,
 0x32E8, 0x2247, 0x2227, 0x2246, 0x2247, 0x2246, 0x2246, 0x1A26, 0x2A88, 0x2A89, 0x11C5, 0x2AA9, 0x3B0B, 0x32AB, 0x2249, 0x6B8E,
 0x6B8E, 0x632C, 0x73CE, 0x6B6D, 0x6B4D, 0x6B4C, 0x632C, 0x6B4C, 0x632C, 0x632B, 0x62EB, 0x62EB, 0x6B4C, 0x632C, 0x5AEB, 0x6B6D,
 0x6B2C, 0x62EA, 0x5ACA, 0x62CA, 0x630B, 0x5AAA, 0x5AAA, 0x5AAA, 0xDE16, 0xDE16, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xDE36,
 0xD637, 0xBD54, 0xDE57, 0xD637, 0xC617, 0xB554, 0x636D, 0x7BEF, 0x9CB2, 0xA4F2, 0xB533, 0xD5F7, 0xD637, 0xD617, 0xCE58, 0xCE38,
 0xC618, 0x9D97, 0x84F6, 0x84B5, 0x8D15, 0x63D1, 0x8493, 0x8472, 0x8472, 0x8471, 0x7C51, 0x7C30, 0x73CF, 0x6B8E, 0x6B8D, 0x5B0B,
 0x5B0B, 0x5269, 0x4A49, 0x4A49, 0x4248, 0x4228, 0x4228, 0x3A08, 0x4208, 0x3A08, 0x39E7, 0x31E6, 0x31A6, 0x31C6, 0x31A6, 0x31C7,
 0x31A6, 0x31A6, 0x2985, 0x2965, 0x2144, 0x2144, 0x2144, 0x2144, 0x31A6, 0x2965, 0x2124, 0x2965, 0x2145, 0x1904, 0x1904, 0x2965,
 0x42EB, 0x3AE9, 0x2A87, 0x2A87, 0x2AA7, 0x2AA8, 0x32E9, 0x32C8, 0x2266, 0x32C8, 0x32A8, 0x1A45, 0x1A06, 0x2246, 0x2246, 0x2246,
 0x2A48, 0x32CA, 0x1A07, 0x2ACA, 0x2A48, 0x32CB, 0x5451, 0x5ACB, 0x73AE, 0x634C, 0x634C, 0x634D, 0x738E, 0x6B4C, 0x632C, 0x6B4C,
 0x6B4C, 0x6B4C, 0x6B2C, 0x630C, 0x6B4C, 0x6B4C, 0x630B, 0x6B6D, 0x6B4C, 0x62EA, 0x6B2C, 0x5AAA, 0x6AEB, 0x62CA, 0x5289, 0x5ACA,
 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xDE37, 0xDE57, 0xD637, 0xD658, 0xCDF6, 0xD5D5, 0xC637, 0x9491, 0x8BEF, 0xAD74, 0xA491,
 0xA4D2, 0xD658, 0xCDD5, 0xC5D5, 0xD616, 0xCE37, 0xCE38, 0xDF3D, 0xBE59, 0xB619, 0x9D97, 0x9DB8, 0x8D36, 0xB63A, 0x8CD4, 0x8CD3,
 0x8C93, 0x7C10, 0x8431, 0x7C10, 0x7C0F, 0x73CE, 0x632C, 0x5AEB, 0x5AEB, 0x5AEB, 0x4A69, 0x52AA, 0x4A89, 0x4A69, 0x4249, 0x3A28,
 0x3A08, 0x39E7, 0x39C7, 0x31A6, 0x31A6, 0x31A6, 0x31A6, 0x4208, 0x31C6, 0x31C6, 0x2985, 0x2965, 0x2965, 0x2965, 0x2144, 0x2124,
 0x2124, 0x2964, 0x2985, 0x2965, 0x2145, 0x2124, 0x1904, 0x1904, 0x29E7, 0x3AC9, 0x2A88, 0x32A8, 0x2A88, 0x2AA7, 0x2A87, 0x2A87,
 0x2267, 0x2267, 0x2AA8, 0x2A67, 0x1A06, 0x2A67, 0x2AA7, 0x2226, 0x1A06, 0x2206, 0x32A9, 0x334D, 0x330B, 0x1A08, 0x2A08, 0x636C,
 0x632C, 0x6B6D, 0x6B6D, 0x632C, 0x632C, 0x632C, 0x6B2C, 0x6B4C, 0x6B6D, 0x6B4D, 0x736D, 0x630B, 0x738D, 0x630B, 0x630B, 0x632C,
 0x6B2C, 0x5AAA, 0x5AC9, 0x62CA, 0x6B0B, 0x62EA, 0x62CA, 0x62EA, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE37, 0xD617, 0xB554,
 0xD637, 0x8C0E, 0xD5F6, 0xBDB5, 0x9430, 0x8430, 0xA4F2, 0xACD2, 0x9C91, 0xC594, 0xDE57, 0xACD2, 0xD617, 0xCE17, 0xC5B6, 0xBDD7,
 0xBE59, 0x9D76, 0x9D97, 0x8D36, 0x63D0, 0x7C72, 0x8472, 0x636E, 0x8C93, 0x8430, 0x73CF, 0x73F0, 0x73F0, 0x8451, 0x73AE, 0x6B4D,
 0x5AEB, 0x5ACB, 0x52AA, 0x528A, 0x52AA, 0x4A89, 0x4A49, 0x4249, 0x4248, 0x4208, 0x39E7, 0x31C6, 0x39C6, 0x31A6, 0x31A6, 0x31A6,
 0x31A6, 0x2986, 0x31A6, 0x2986, 0x2985, 0x2964, 0x2145, 0x2144, 0x2124, 0x2123, 0x2144, 0x2965, 0x2944, 0x2144, 0x2124, 0x1903,
 0x1904, 0x3248, 0x32A8, 0x3B09, 0x2A88, 0x2AC8, 0x2AA7, 0x2AA8, 0x32A8, 0x32C9, 0x2A67, 0x2246, 0x2226, 0x2246, 0x2A87, 0x19E5,
 0x2267, 0x2AA9, 0x42E9, 0x19A5, 0x436B, 0x0166, 0x428B, 0x530B, 0x634C, 0x6B6D, 0x6B4D, 0x634D, 0x6B6D, 0x6B6D, 0x6B6D, 0x6B4C,
 0x5AEB, 0x630C, 0x6B2C, 0x630B, 0x6B4C, 0x632B, 0x630B, 0x632C, 0x630B, 0x5AA9, 0x630A, 0x5A89, 0x62CA, 0x630B, 0x5AA9, 0x5A89,
 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE57, 0xDE78, 0x838D, 0x940E, 0xB512, 0xCDF6, 0xBD54, 0x7B8D, 0xCDD6, 0xB4F2,
 0xBD74, 0xB533, 0xC594, 0xD658, 0xC5F7, 0xCE17, 0xC5D6, 0xC5D6, 0xA596, 0x9D77, 0xA5D9, 0x7C93, 0x7432, 0x5B2E, 0x6BCF, 0x6BAF,
 0x8452, 0x73F0, 0x7C10, 0x7C0F, 0x94B2, 0x7C10, 0x632C, 0x528A, 0x5ACB, 0x5B0B, 0x630C, 0x5B0C, 0x4A89, 0x52AA, 0x5289, 0x4A69,
 0x4249, 0x4248, 0x4228, 0x39E7, 0x39E7, 0x3A08, 0x39C7, 0x31A6, 0x31A6, 0x31A6, 0x31A6, 0x2985, 0x3185, 0x2965, 0x2965, 0x2945,
 0x2124, 0x2124, 0x2985, 0x2144, 0x2945, 0x2144, 0x2124, 0x1903, 0x2103, 0x2124, 0x3A88, 0x32A8, 0x32C8, 0x2AC8, 0x2AA7, 0x32C8,
 0x32A8, 0x32C9, 0x2247, 0x2246, 0x1A06, 0x2A67, 0x1A25, 0x19E5, 0x2225, 0x2A68, 0x32C9, 0x3AAA, 0x3268, 0x224A, 0x32AA, 0x3A49,
 0x636D, 0x73AE, 0x632C, 0x634C, 0x6B6D, 0x6B4D, 0x6B4C, 0x632C, 0x632C, 0x6B2C, 0x630B, 0x630B, 0x6B6C, 0x6B4C, 0x5ACB, 0x630C,
 0x6B0C, 0x6B0B, 0x62EA, 0x5AAA, 0x6B0B, 0x62CA, 0x5AAA, 0x49E7, 0xDE36, 0xDE36, 0xDE36, 0xDE36, 0xDE78, 0xD616, 0xDE78, 0xC5B5,
 0x9430, 0xDE78, 0xC5D5, 0x8BCE, 0xCDF5, 0xCE17, 0xDE78, 0xACF2, 0x5A89, 0xDE57, 0xCDF6, 0xD617, 0xA514, 0xC617, 0xBDB6, 0xC5F6,
 0xA575, 0x9D56, 0x8D36, 0x84F5, 0x7CD4, 0x84B4, 0x9515, 0x52EC, 0x7411, 0x7410, 0x73AF, 0x8410, 0x73AE, 0x7C10, 0x634C, 0x634C,
 0x6B6D, 0x738E, 0x632C, 0x5B0B, 0x52CA, 0x5AEB, 0x52AA, 0x528A, 0x4228, 0x4228, 0x4228, 0x4228, 0x3A07, 0x39E7, 0x39E7, 0x31E7,
 0x31C6, 0x31C6, 0x31C6, 0x31A6, 0x31A6, 0x3185, 0x2965, 0x2945, 0x2145, 0x2144, 0x2124, 0x2124, 0x2945, 0x2124, 0x2124, 0x2124,
 0x1923, 0x20E3, 0x2144, 0x3268, 0x2A87, 0x2AA7, 0x32C7, 0x2A87, 0x2A86, 0x1A26, 0x2246, 0x2266, 0x2A48, 0x2A67, 0x1A25, 0x2226,
 0x2247, 0x2A67, 0x2A88, 0x328A, 0x430C, 0x4C12, 0x4B6E, 0x1A8C, 0x5B2C, 0x6B8E, 0x6B6D, 0x5B0C, 0x6B4C, 0x6B4D, 0x738D, 0x632C,
 0x632B, 0x6B4C, 0x62EB, 0x630B, 0x632B, 0x62EB, 0x5AEB, 0x6B8E, 0x630B, 0x5ACA, 0x5AEA, 0x5AAA, 0x6B0B, 0x5AC9, 0x62EA, 0x5AAA,
 0xDE36, 0xD636, 0xDE36, 0xDE36, 0xACD1, 0x942F, 0x9CB2, 0x834C, 0xC5D6, 0xD616, 0xDE16, 0x9C71, 0xD616, 0x83CE, 0x7BAE, 0xA512,
 0x7BEF, 0xDE57, 0x9CB0, 0xA4F3, 0x632C, 0x94B3, 0xAD55, 0xBDD6, 0xAD96, 0xA596, 0x8D15, 0xA5D8, 0xA598, 0x7411, 0x530D, 0x5B2E,
 0x8472, 0x8472, 0x7C51, 0x7C31, 0x73CF, 0x73CF, 0x6B8E, 0x6B8E, 0x5B0B, 0x5B0B, 0x5AEB, 0x634C, 0x634C, 0x632C, 0x52AA, 0x528A,
 0x4A69, 0x4A8A, 0x4228, 0x4228, 0x4228, 0x3A08, 0x39E7, 0x39E7, 0x39E7, 0x39E6, 0x39E7, 0x39E7, 0x31A6, 0x31A5, 0x3185, 0x2965,
 0x2965, 0x2964, 0x2124, 0x2104, 0x2124, 0x2104, 0x2104, 0x2124, 0x1903, 0x1903, 0x1903, 0x2144, 0x3267, 0x434A, 0x2A87, 0x2A87,
 0x2246, 0x1A05, 0x2A87, 0x2226, 0x19E5, 0x2A67, 0x1A25, 0x2226, 0x2A88, 0x2247, 0x2A48, 0x4B2C, 0x3289, 0x3A8A, 0x63CF, 0x1965,
 0x5B0C, 0x6B8D, 0x6B8D, 0x634C, 0x73AD, 0x6B6D, 0x738E, 0x630B, 0x630B, 0x630B, 0x630B, 0x6B4C, 0x6B2B, 0x630B, 0x5B0B, 0x632C,
 0x630B, 0x62EA, 0x630B, 0x62EA, 0x62CA, 0x5AA9, 0x62EA, 0x6B0B, 0xDE16, 0xDE36, 0xD636, 0xDE37, 0xAD12, 0x9C50, 0xA534, 0xAC91,
 0xB513, 0xC595, 0xC5B5, 0x6B2C, 0xC5D6, 0xB554, 0xD638, 0x52AA, 0x7C30, 0xC5B5, 0xD637, 0xA4F3, 0x94D3, 0x8CF3, 0xB5D6, 0xCE18,
 0x9D34, 0x9514, 0x84D4, 0x7C93, 0x6C12, 0x6BD0, 0x7411, 0x7411, 0x7C52, 0x9D56, 0x7C52, 0x7C11, 0x8451, 0x73F0, 0x638E, 0x73F0,
 0x6B8D, 0x6B6D, 0x634C, 0x52EB, 0x52EB, 0x5ACB, 0x5AEB, 0x52AA, 0x52AA, 0x52AA, 0x4A69, 0x4248, 0x4249, 0x4228, 0x4228, 0x4208,
 0x4207, 0x4207, 0x39E7, 0x39E7, 0x31C6, 0x31A5, 0x3185, 0x3186, 0x2965, 0x2144, 0x2144, 0x2124, 0x2124, 0x2124, 0x2104, 0x2103,
 0x1903, 0x1903, 0x2124, 0x2124, 0x2165, 0x3288, 0x2AC8, 0x2AA7, 0x2A67, 0x2287, 0x2A87, 0x2A67, 0x1A06, 0x2246, 0x2226, 0x2226,
 0x2A88, 0x2A68, 0x1185, 0x32AA, 0x3ACA, 0x52CB, 0x6B6D, 0x4249, 0x6B8D, 0x636D, 0x6B6D, 0x636D, 0x6B6D, 0x6B6D, 0x738D, 0x6B4C,
 0x8C50, 0x6B4C, 0x630B, 0x632B, 0x6B2C, 0x630B, 0x630B, 0x6B4D, 0x6B2C, 0x630B, 0x6B0B, 0x5AAA, 0x5AAA, 0x5AA9, 0x5AC9, 0x62EA,
 0xDE16, 0xDE16, 0xD616, 0xC5B5, 0xC5B5, 0xCDF6, 0xC658, 0xACF2, 0xCDB5, 0xBD54, 0xD616, 0xA4F3, 0x7BAF, 0xBE79, 0xCE79, 0x94D3,
 0x8451, 0xC595, 0xDE57, 0xDE56, 0x6BCF, 0x6C31, 0x9D14, 0x9492, 0xA534, 0xA576, 0xA5B7, 0x9D77, 0x7C73, 0x63B0, 0x8493, 0x84B3,
 0x52EC, 0x84B3, 0x7C52, 0x8CB3, 0x8472, 0x8473, 0x7C11, 0x8CB3, 0x7BF0, 0x6B8E, 0x634D, 0x5B0C, 0x5AEB, 0x5AEB, 0x5B2C, 0x52AA,
 0x52AA, 0x52CB, 0x4A89, 0x4248, 0x4228, 0x4228, 0x4228, 0x4228, 0x4248, 0x4228, 0x4207, 0x3A07, 0x39E7, 0x31A6, 0x3185, 0x3186,
 0x3185, 0x2965, 0x2945, 0x2124, 0x2124, 0x2104, 0x2104, 0x2103, 0x1903, 0x2103, 0x2124, 0x2124, 0x2124, 0x21A5, 0x3AE9, 0x2AA7,
 0x2A67, 0x2267, 0x2226, 0x2246, 0x2247, 0x2246, 0x1A26, 0x1A06, 0x2A88, 0x2247, 0x11A5, 0x3289, 0x2A48, 0x4AEB, 0x6BCF, 0x636D,
 0x73CE, 0x634D, 0x6B8D, 0x636D, 0x6B4D, 0x6B4D, 0x630B, 0x6B4C, 0x6B2C, 0x6B2C, 0x630B, 0x5AEB, 0x632C, 0x736D, 0x630B, 0x634C,
 0x630B, 0x62EB, 0x630B, 0x5A89, 0x62EB, 0x62EB, 0x5AA9, 0x62EA, 0xD616, 0xDE37, 0xD616, 0xD616, 0xADD6, 0x9CF3, 0x73CF, 0xC596,
 0xD5F6, 0xCDD6, 0xCDF6, 0xCE38, 0x7BEF, 0x7BAE, 0x8BCD, 0xBDF7, 0xA4B1, 0xDE79, 0x94B2, 0xC5F7, 0x634C, 0x8451, 0x83CE, 0xCE17,
 0xA4F3, 0x94F4, 0x8D15, 0x84F4, 0x84B3, 0x638F, 0x5B4E, 0x636E, 0x5B2D, 0x4ACC, 0x8472, 0x7C10, 0x94F4, 0x73F0, 0x7C31, 0x8472,
 0x7C11, 0x73F0, 0x6B8E, 0x634D, 0x632C, 0x5B0C, 0x5B0C, 0x5B2C, 0x5B0B, 0x52AA, 0x4A8A, 0x4A69, 0x4248, 0x3A08, 0x4228, 0x4248,
 0x4228, 0x4228, 0x4207, 0x4227, 0x3A07, 0x39C6, 0x39C6, 0x3186, 0x3186, 0x2965, 0x2985, 0x2965, 0x2124, 0x2124, 0x2104, 0x2124,
 0x2104, 0x2104, 0x2123, 0x2123, 0x2165, 0x2124, 0x29C5, 0x2246, 0x2A87, 0x2287, 0x2247, 0x2267, 0x2A67, 0x2247, 0x2247, 0x2267,
 0x2266, 0x1A46, 0x2A68, 0x42AA, 0x534C, 0x532C, 0x4ACA, 0x6B6E, 0x632C, 0x636D, 0x632C, 0x73CF, 0x634D, 0x634C, 0x630B, 0x738D,
 0x630B, 0x738D, 0x5ACB, 0x6B4D, 0x634C, 0x6B4C, 0x632C, 0x634D, 0x632B, 0x630B, 0x5AA9, 0x5AAA, 0x62CA, 0x5AA9, 0x62CA, 0x62EA,
 0x5AA9, 0xC594, 0xB512, 0x7BAE, 0xC5D7, 0xD71C, 0x634D, 0x8BAD, 0xEED9, 0xD658, 0xB554, 0xD679, 0xA513, 0x8CF3, 0x7C51, 0xACD1,
 0xA4D2, 0x9492, 0xAD13, 0x6B6D, 0xC659, 0x7B8D, 0xCE16, 0xD617, 0xC5D6, 0x94F3, 0x8492, 0x7C52, 0x7411, 0x638F, 0x5B6F, 0x52ED,
 0x4ACC, 0x84B3, 0x636E, 0x7BEF, 0x8C92, 0x8492, 0x8452, 0x8452, 0x7410, 0x73F0, 0x7C10, 0x636D, 0x634D, 0x632C, 0x5AEB, 0x52CA,
 0x5B0C, 0x52CA, 0x5AEB, 0x632C, 0x5AEB, 0x4A69, 0x4248, 0x4228, 0x4A28, 0x4248, 0x4228, 0x4207, 0x4208, 0x4207, 0x39E7, 0x31C6,
 0x3185, 0x3185, 0x3185, 0x2965, 0x2944, 0x2144, 0x2124, 0x2103, 0x1904, 0x2103, 0x2103, 0x2124, 0x2124, 0x2123, 0x2123, 0x29E6,
 0x2247, 0x2267, 0x1A26, 0x2247, 0x2226, 0x2267, 0x2266, 0x2247, 0x1A06, 0x11E5, 0x2A68, 0x3A69, 0x432C, 0x536D, 0x4AEB, 0x636D,
 0x634D, 0x6B8D, 0x6B8E, 0x634D, 0x6B8E, 0x6B6D, 0x6B6D, 0x634C, 0x6B6D, 0x62EB, 0x630B, 0x630B, 0x6B4D, 0x62EB, 0x630B, 0x634D,
 0x6B2C, 0x62EA, 0x6B2C, 0x62EB, 0x5AA9, 0x5AA9, 0x62CA, 0x5AA9, 0x8BCE, 0xBD32, 0xD637, 0x9CD1, 0x3A48, 0x9514, 0x9CF3, 0x7BCE,
 0xAD12, 0x9CB2, 0x6B4D, 0x9D54, 0x5ACA, 0x83EF, 0x6B4D, 0xBD74, 0xDE79, 0x7BEF, 0xCE17, 0xBD54, 0x636D, 0xC5B6, 0xCE16, 0xCDF6,
 0xB5B5, 0x9D14, 0xA534, 0x9514, 0x8CF4, 0x6BF0, 0x532D, 0x4AEC, 0x52ED, 0x6BF0, 0x7431, 0x7C31, 0x7C10, 0x8CD3, 0x8C93, 0x8452,
 0x8451, 0x73AF, 0x636D, 0x8430, 0x6B8E, 0x6B6D, 0x52CB, 0x5ACB, 0x52CB, 0x52CA, 0x5B0B, 0x632C, 0x52CB, 0x4A89, 0x528A, 0x4A49,
 0x4A28, 0x4228, 0x4A48, 0x4228, 0x39E7, 0x4207, 0x39E7, 0x39C6, 0x31A6, 0x31A6, 0x31A6, 0x3185, 0x2965, 0x2944, 0x2124, 0x2124,
 0x1904, 0x1904, 0x1904, 0x2104, 0x1903, 0x2103, 0x20E3, 0x2103, 0x3247, 0x2247, 0x1A46, 0x2247, 0x2247, 0x2246, 0x2226, 0x2267,
 0x2227, 0x1A06, 0x2A68, 0x3ACA, 0x2A89, 0x42CB, 0x634D, 0x636D, 0x634D, 0x6B6D, 0x6B6E, 0x7BEF, 0x6B8D, 0x6B4D, 0x6B4C, 0x632C,
 0x6B6D, 0x6B4C, 0x630B, 0x734D, 0x6B4C, 0x630B, 0x62EB, 0x630B, 0x5ACA, 0x630B, 0x630B, 0x62CA, 0x62CA, 0x5A89, 0x62CA, 0x5AC9,
 0xA490, 0xD636, 0xBDB5, 0x94F2, 0x636E, 0x634D, 0x73CE, 0xD618, 0xDE38, 0x5ACB, 0x5B2D, 0x63EF, 0x73AE, 0x9D13, 0x8450, 0xC5D6,
 0x83EF, 0xA534, 0xCE17, 0xC594, 0x9C71, 0xAD34, 0xCE16, 0xC5D6, 0xB595, 0x9492, 0x9CF3, 0x8CD3, 0x7C52, 0x63B0, 0x5B6F, 0x638F,
 0x530D, 0x63AF, 0x5B6E, 0x7C72, 0x7C31, 0x7C11, 0x8431, 0x8432, 0x7410, 0x73AF, 0x634D, 0x6B8E, 0x52CB, 0x4AAA, 0x630C, 0x630C,
 0x5AEB, 0x5B0B, 0x5B0B, 0x5AEB, 0x634C, 0x5AEB, 0x632C, 0x528A, 0x4228, 0x4228, 0x4248, 0x4228, 0x4228, 0x4228, 0x4207, 0x39C6,
 0x39C6, 0x39C7, 0x39C7, 0x31A5, 0x3185, 0x2985, 0x2965, 0x2945, 0x2986, 0x1904, 0x2104, 0x2104, 0x1903, 0x2103, 0x20E3, 0x20E3,
 0x2144, 0x3247, 0x2246, 0x2A67, 0x32C9, 0x2247, 0x2246, 0x2266, 0x32A9, 0x1A26, 0x2226, 0x2227, 0x2228, 0x4AEB, 0x5B2C, 0x6B4D,
 0x6B8D, 0x634D, 0x6B6E, 0x6B6D, 0x6B8E, 0x630C, 0x738D, 0x6B4C, 0x73CE, 0x6B2C, 0x632C, 0x6B2C, 0x6B2C, 0x62EB, 0x630B, 0x630B,
 0x6B2C, 0x5ACA, 0x62EA, 0x62CA, 0x62EB, 0x5A89, 0x62CA, 0x62CA, 0xBD73, 0xD678, 0x8C71, 0x9514, 0x5BAE, 0x6B2C, 0x94B1, 0xAD34,
 0xE73C, 0x6C10, 0x8472, 0x636D, 0x6B6D, 0xB5D6, 0x4AEB, 0x6B8D, 0x6B0B, 0xDE58, 0xA4B3, 0xAD12, 0xA513, 0x740F, 0xCE17, 0xACD2,
 0xBD74, 0xBDD7, 0x94D3, 0x7C73, 0x7432, 0x638F, 0x530D, 0x42AC, 0x42AC, 0x638F, 0x6BD0, 0x7431, 0x8CD4, 0x7C31, 0x8451, 0x7C31,
 0x73F0, 0x7BF0, 0x634D, 0x6B6D, 0x73AE, 0x634C, 0x632C, 0x52A9, 0x4A69, 0x52CA, 0x5B2C, 0x5B0C, 0x6B4D, 0x634D, 0x5AEB, 0x52AA,
 0x5289, 0x4248, 0x4248, 0x4248, 0x4248, 0x4228, 0x4A48, 0x4228, 0x39E7, 0x39E7, 0x39A6, 0x39C6, 0x31A5, 0x2985, 0x2965, 0x2945,
 0x3186, 0x2124, 0x2103, 0x2103, 0x20E3, 0x1903, 0x20E3, 0x20E3, 0x20E3, 0x2164, 0x2A46, 0x2226, 0x2206, 0x2247, 0x2267, 0x1A05,
 0x32A9, 0x2A67, 0x1A06, 0x21E6, 0x2A89, 0x32CA, 0x3A89, 0x636D, 0x73AE, 0x6B8D, 0x634D, 0x52AA, 0x634C, 0x634D, 0x6B6D, 0x7BAE,
 0x6B4C, 0x630B, 0x634C, 0x630B, 0x630B, 0x630B, 0x630B, 0x630B, 0x6B4C, 0x6B2C, 0x62EB, 0x62CA, 0x630A, 0x630A, 0x6B0B, 0x6B0B,
 0xBD53, 0xCE16, 0x9D13, 0x6B8D, 0x8C71, 0xA534, 0x6BAE, 0x7BEF, 0x94B2, 0x5B0B, 0xA555, 0x534D, 0x7C93, 0x73AE, 0x7BCE, 0x9D14,
 0x4A48, 0xA4B1, 0x6B0B, 0xDE58, 0x8410, 0x7C51, 0x8C0E, 0xBD75, 0x9CB2, 0xCE17, 0xB596, 0x7C31, 0x7411, 0x5B8F, 0x5B4E, 0x42EC,
 0x428B, 0x5B4E, 0x7C72, 0x8472, 0x73F0, 0x8431, 0x7BF0, 0x8451, 0x73F0, 0x6BAE, 0x632D, 0x632D, 0x5B0C, 0x6B8E, 0x5AEB, 0x4AAA,
 0x52CB, 0x4AAA, 0x5AEB, 0x632C, 0x634D, 0x632C, 0x5AEB, 0x5B0B, 0x632C, 0x5ACA, 0x4A69, 0x4248, 0x4A48, 0x4A48, 0x4A48, 0x41E7,
 0x41E7, 0x39C6, 0x31A5, 0x31C6, 0x31A6, 0x3186, 0x3185, 0x3185, 0x2964, 0x2124, 0x2123, 0x2103, 0x2103, 0x2104, 0x2924, 0x2924,
 0x2103, 0x2903, 0x2143, 0x3247, 0x2A46, 0x2226, 0x32A8, 0x2247, 0x32A9, 0x2A87, 0x2247, 0x2227, 0x2228, 0x3AEB, 0x21C6, 0x636D,
 0x636D, 0x636E, 0x5B2C, 0x634D, 0x73AE, 0x73AE, 0x632C, 0x6B4C, 0x5AEB, 0x630B, 0x6B4C, 0x62EB, 0x62EB, 0x6B4C, 0x630B, 0x630B,
 0x630B, 0x630B, 0x62CA, 0x62CA, 0x6B0B, 0x5AA9, 0x5AA9, 0x62CA, 0x632C, 0xA4F3, 0x73CF, 0x4AEC, 0x8451, 0x8C51, 0x7410, 0x5B6D,
 0x630C, 0x7C10, 0x7C30, 0x7C30, 0x53AF, 0x732C, 0xCE79, 0x632C, 0x9471, 0x6B0B, 0x41C6, 0x9C91, 0x8471, 0x52CB, 0xC5D6, 0xAD75,
 0x9CB2, 0xC5B5, 0x9430, 0x9514, 0x8472, 0x84B4, 0x7412, 0x4AED, 0x4ACC, 0x428B, 0x4AEC, 0x7411, 0x7C10, 0x7C10, 0x73CF, 0x73CF,
 0x7C10, 0x73CF, 0x7C10, 0x6BAF, 0x632C, 0x632C, 0x5B2C, 0x52CB, 0x5B0C, 0x5B2C, 0x5AEB, 0x52CB, 0x5B2C, 0x5B0C, 0x5AEB, 0x5B0C,
 0x5B0B, 0x5AEB, 0x5AEB, 0x4A68, 0x4A68, 0x4A48, 0x4A48, 0x39E6, 0x4A28, 0x4207, 0x39E7, 0x31A6, 0x39C6, 0x3185, 0x3185, 0x3185,
 0x3165, 0x2965, 0x2924, 0x2104, 0x1903, 0x2104, 0x2104, 0x2904, 0x2904, 0x2924, 0x2924, 0x2965, 0x3206, 0x2226, 0x2247, 0x2247,
 0x2A88, 0x2247, 0x1A27, 0x2207, 0x1A27, 0x432C, 0x3228, 0x6BAE, 0x636E, 0x638E, 0x632C, 0x6B8F, 0x5B0C, 0x6B4C, 0x632C, 0x6B4C,
 0x632C, 0x632C, 0x6B4C, 0x5AEB, 0x6B2C, 0x630B, 0x736D, 0x6B0B, 0x6B2C, 0x630B, 0x62EA, 0x5ACA, 0x5ACA, 0x630B, 0x5ACA, 0x5AAA,
 0xCE17, 0xB534, 0x9CD2, 0x326A, 0x8CB2, 0x8C2F, 0x4A8A, 0xA554, 0x7B8E, 0x7C10, 0xA4D2, 0xA512, 0x5B6D, 0x8C51, 0x9D14, 0x8C31,
 0x94B2, 0x7BCF, 0x41E6, 0x9CB2, 0xAD54, 0xAD75, 0x630B, 0xAD13, 0x9CB1, 0xDE78, 0xD637, 0xA514, 0x9D55, 0xA5B8, 0x6BF1, 0x4AED,
 0x3A4A, 0x426A, 0x4AAC, 0x73F1, 0x8493, 0x8452, 0x8452, 0x7C11, 0x8451, 0x7C10, 0x73CF, 0x73AF, 0x6B6D, 0x632C, 0x5AEB, 0x52CB,
 0x632C, 0x5B2C, 0x632C, 0x634D, 0x6B8E, 0x632C, 0x632C, 0x634C, 0x634D, 0x632C, 0x632C, 0x5B0B, 0x5289, 0x4A69, 0x4A48, 0x4A48,
 0x4A48, 0x41E7, 0x4207, 0x39E7, 0x31A6, 0x31A6, 0x3185, 0x3165, 0x31A6, 0x3185, 0x2924, 0x2924, 0x2104, 0x2124, 0x2944, 0x2924,
 0x2124, 0x2124, 0x2944, 0x2965, 0x3986, 0x3A27, 0x2A47, 0x2A88, 0x2A88, 0x2AA8, 0x2247, 0x3269, 0x2248, 0x1185, 0x4AEB, 0x634D,
 0x6BAF, 0x5B2D, 0x634C, 0x6BAF, 0x73AE, 0x632C, 0x6B6D, 0x632B, 0x630B, 0x5AEB, 0x632B, 0x632C, 0x736D, 0x5AA9, 0x630B, 0x630B,
 0x630B, 0x630B, 0x62EA, 0x6B2B, 0x5AA9, 0x734C, 0x62CA, 0x6B2B, 0x4269, 0x9514, 0x6BCE, 0x84B4, 0x73AF, 0x9CB2, 0x5AEB, 0x736D,
 0x62EB, 0x73CF, 0x73CD, 0xD5F5, 0x94D2, 0xC5F6, 0x5249, 0x73CF, 0x9D14, 0x4A69, 0x49E7, 0x630C, 0x62EB, 0x4A48, 0x634C, 0xC5D6,
 0xC5D6, 0xAD12, 0x7B6C, 0xB554, 0xB5F8, 0x84D4, 0x6390, 0x532E, 0x3A4A, 0x426B, 0x4AAC, 0x6BD1, 0x7411, 0x7C52, 0x7C52, 0x7C32,
 0x94B3, 0x7BF0, 0x7BF0, 0x7BF0, 0x6B6E, 0x632C, 0x52EB, 0x5AEB, 0x632C, 0x6B8E, 0x5AEB, 0x634D, 0x634D, 0x5B0B, 0x632C, 0x634D,
 0x634D, 0x634D, 0x634C, 0x634C, 0x632C, 0x5289, 0x4A49, 0x4A28, 0x4A48, 0x4228, 0x4208, 0x39E7, 0x39E6, 0x31A6, 0x31A6, 0x3185,
 0x31A5, 0x3185, 0x3165, 0x3165, 0x2925, 0x2944, 0x2144, 0x2944, 0x2944, 0x2964, 0x2944, 0x3145, 0x3185, 0x3185, 0x3A06, 0x4288,
 0x2A47, 0x1A06, 0x2A67, 0x2A47, 0x32AA, 0x2227, 0x21C6, 0x530C, 0x5B2D, 0x6B6E, 0x6B4D, 0x6B8E, 0x6B6D, 0x6B8D, 0x630B, 0x73AD,
 0x736D, 0x5ACA, 0x632B, 0x632C, 0x630B, 0x630B, 0x6B2C, 0x6B6C, 0x62EA, 0x6B0B, 0x62EA, 0x62EA, 0x62CA, 0x5A88, 0x62EA, 0x62EA,
 0x73EE, 0x9C91, 0xAD54, 0x736D, 0x62CB, 0xA575, 0x7BAE, 0x73CF, 0x6B4D, 0x6B4C, 0xB554, 0x62AA, 0xC595, 0x5ACA, 0x5AAA, 0x4A28,
 0x8430, 0x8C0F, 0xDE78, 0x73AF, 0x7BAD, 0xC658, 0xADD7, 0x83EE, 0xD637, 0x83CE, 0x62CA, 0xAD13, 0xB5D7, 0x7C52, 0x6BD0, 0x7411,
 0x3A2A, 0x31E9, 0x3A29, 0x4ACB, 0x8493, 0x7C53, 0x7411, 0x7C31, 0x8472, 0x8C72, 0x6B8E, 0x73CF, 0x6B6D, 0x632C, 0x5AEB, 0x52AA,
 0x5AEB, 0x5AEB, 0x5AEB, 0x6B8E, 0x634D, 0x6B6D, 0x6B4D, 0x634C, 0x634D, 0x632C, 0x632C, 0x632C, 0x632C, 0x630C, 0x4A49, 0x4A28,
 0x4A48, 0x4208, 0x4207, 0x41E7, 0x39E6, 0x39A6, 0x39C6, 0x31A5, 0x3185, 0x31A6, 0x39A6, 0x3186, 0x2965, 0x3165, 0x3165, 0x3165,
 0x3185, 0x4207, 0x4A48, 0x31A6, 0x39A6, 0x31A5, 0x39C6, 0x39C6, 0x4A48, 0x4248, 0x3248, 0x3269, 0x42EB, 0x1A28, 0x3A8A, 0x638E,
 0x4269, 0x8C70, 0x6B6D, 0x6B4C, 0x73AE, 0x632C, 0x632C, 0x6B6D, 0x6B2C, 0x632B, 0x6B2C, 0x630B, 0x630B, 0x5AAA, 0x738D, 0x6B2C,
 0x6B2C, 0x62EA, 0x6AEB, 0x630A, 0x6B0B, 0x5289, 0x62CA, 0x6B0B, 0x52AA, 0x9470, 0x7B6C, 0x7B6D, 0xA450, 0xD617, 0x83CE, 0x4A69,
 0xB575, 0x8C0F, 0x8C50, 0x734C, 0x7B4C, 0x630B, 0xA4B2, 0xBD75, 0x94B3, 0x6B2C, 0xD638, 0xAD35, 0xBD95, 0x6BCE, 0x84D3, 0xB513,
 0x83CE, 0xAD13, 0xA4F3, 0x9470, 0xAD35, 0x8472, 0x7411, 0x8CF5, 0x31E9, 0x29A8, 0x3A09, 0x426A, 0x428B, 0x6BD0, 0x7C52, 0x8472,
 0x7C11, 0x8C72, 0x73CF, 0x7BF0, 0x6B8E, 0x636D, 0x5B0C, 0x6B6D, 0x6B6D, 0x6B6D, 0x634D, 0x630C, 0x634D, 0x634D, 0x6B6D, 0x6B6D,
 0x6B4D, 0x634D, 0x6B6D, 0x6B4D, 0x6B4D, 0x6B4D, 0x632C, 0x4A69, 0x4A48, 0x4228, 0x4207, 0x41E7, 0x39C6, 0x39E6, 0x39E7, 0x39E6,
 0x39A5, 0x39A5, 0x31A5, 0x39A6, 0x39A6, 0x39A6, 0x39A5, 0x3164, 0x39E7, 0x4A69, 0x6B4C, 0x6B6D, 0x5AEB, 0x4207, 0x39C6, 0x39E7,
 0x41E7, 0x41E7, 0x4228, 0x4A69, 0x3A69, 0x32AA, 0x21E8, 0x636D, 0x530C, 0x632C, 0x6B8E, 0x6B6D, 0x632C, 0x6B4C, 0x6B4C, 0x632C,
 0x6B4D, 0x632C, 0x632B, 0x7BAE, 0x630B, 0x632C, 0x6B4C, 0x632B, 0x5AEB, 0x6B4C, 0x6B0B, 0x5ACA, 0x5A89, 0x5ACA, 0x5AA9, 0x62EB,
 0x62AA, 0x8BEE, 0xD617, 0x5228, 0xACD1, 0xE6B9, 0xB513, 0x62CA, 0x6AEA, 0xD637, 0x6AEA, 0xB4F2, 0x8BAD, 0x7B4C, 0xC658, 0xE6DB,
 0x7C10, 0xA4D3, 0xA4D2, 0x9CF3, 0xBDB5, 0xBD95, 0x7BAE, 0xCE16, 0xD658, 0xCE17, 0x62CA, 0xD637, 0xA513, 0x9D15, 0x7410, 0x73F1,
 0x4AEC, 0x2987, 0x2146, 0x3208, 0x3A4A, 0x530D, 0x7C31, 0x8CB3, 0x7C31, 0x7BCF, 0x8451, 0x73CF, 0x6BAE, 0x73CE, 0x6B6E, 0x5ACB,
 0x632D, 0x6B6D, 0x6B6D, 0x634D, 0x632C, 0x632D, 0x6BAE, 0x6B8E, 0x6B6D, 0x6BAE, 0x738E, 0x738E, 0x73AE, 0x6B8D, 0x6B6D, 0x6B4D,
 0x4A48, 0x4A48, 0x41E7, 0x41E7, 0x39C6, 0x39C6, 0x4207, 0x39E6, 0x39A6, 0x39C6, 0x41E7, 0x41E6, 0x41E6, 0x39C6, 0x39C6, 0x39C6,
 0x4A48, 0x5B0B, 0x6B8D, 0x7BCE, 0x73AE, 0x8430, 0x738D, 0x5289, 0x4228, 0x39E7, 0x39E7, 0x39E6, 0x41E7, 0x4A48, 0x5AEB, 0x430A,
 0x5B0C, 0x6B8E, 0x634D, 0x634C, 0x6B6D, 0x632C, 0x632C, 0x632C, 0x6B4C, 0x6B6D, 0x6B4C, 0x6B2B, 0x6B2C, 0x62EB, 0x5ACA, 0x52A9,
 0x634D, 0x634C, 0x6B2B, 0x630B, 0x62CA, 0x5ACA, 0x5ACA, 0x6B2B, 0x6B0B, 0x840E, 0xBD54, 0x6268, 0xDE37, 0xC5B5, 0x738E, 0x9CD2,
 0x83AE, 0x9C91, 0x738D, 0x736D, 0xD636, 0x41E6, 0xAD34, 0xA513, 0x9471, 0x736D, 0xC5B6, 0x52AA, 0xCE38, 0x8C0F, 0xB575, 0x6AEA,
 0xBD54, 0xCE38, 0xC5D6, 0xB512, 0xAD13, 0x5B2D, 0x9514, 0x73D0, 0x638F, 0x4ACC, 0x29A7, 0x29C7, 0x3209, 0x3A6A, 0x530D, 0x7411,
 0x8CB3, 0x8C92, 0x7BF0, 0x73CF, 0x8451, 0x7C10, 0x73AE, 0x632D, 0x6B4D, 0x632C, 0x5B2C, 0x6B6D, 0x6B8E, 0x6BAF, 0x8451, 0x8451,
 0x7BEF, 0x6BAE, 0x738E, 0x738E, 0x6B6D, 0x6B6D, 0x634C, 0x632C, 0x52AA, 0x4A48, 0x4A28, 0x4208, 0x4207, 0x4207, 0x4207, 0x4207,
 0x41E7, 0x41E7, 0x4207, 0x4207, 0x41C6, 0x39C6, 0x4208, 0x4A49, 0x5AEA, 0x6B8D, 0x73AE, 0x7BAE, 0x7BEF, 0x738D, 0x73AD, 0x73EF,
 0x7BEF, 0x738E, 0x62EB, 0x3A06, 0x41C7, 0x31E6, 0x39E7, 0x526A, 0x52CA, 0x6B4C, 0x6B6E, 0x632C, 0x6B6D, 0x6B4D, 0x6B6D, 0x6B4C,
 0x6B2C, 0x632C, 0x632C, 0x6B2C, 0x6B2C, 0x5AA9, 0x630B, 0x6B2C, 0x630B, 0x6B4C, 0x62CA, 0x630A, 0x6B2B, 0x62EA, 0x5ACA, 0x5AAA,
 0xDE58, 0x7B4C, 0x838E, 0xCDF6, 0x7B2C, 0xEEB9, 0x6289, 0xCDF6, 0x9450, 0xCDF5, 0xE6DA, 0x5289, 0xA491, 0xBD74, 0x9C91, 0x736D,
 0xBD74, 0x736D, 0xC5B7, 0xA4D2, 0x8451, 0x638E, 0x6B0B, 0xCE16, 0x8C0F, 0xCE37, 0xCDF6, 0xBD74, 0x7BCF, 0x638E, 0x4B0C, 0x52EC,
 0x8472, 0x7432, 0x7493, 0x52ED, 0x29E9, 0x3209, 0x4ACC, 0x638F, 0x8451, 0x7C31, 0x8451, 0x7C10, 0x73CF, 0x6B6D, 0x6BAE, 0x6BAE,
 0x6B8E, 0x6B6D, 0x6B6D, 0x6B8E, 0x73CE, 0x73CF, 0x73CF, 0x73AE, 0x73CF, 0x73CE, 0x73AE, 0x73AE, 0x6B8D, 0x6B6D, 0x6B4D, 0x632C,
 0x632C, 0x632C, 0x52AA, 0x4A48, 0x4207, 0x4A28, 0x4208, 0x4207, 0x4A28, 0x4207, 0x4207, 0x4207, 0x4A48, 0x5269, 0x52AA, 0x5B0B,
 0x6B4C, 0x738D, 0x73CE, 0x7C0F, 0x8C51, 0x7BCF, 0x8C71, 0x8451, 0x8430, 0x7BEF, 0x73AE, 0x738D, 0x7BEF, 0x5AAA, 0x4207, 0x4227,
 0x4A28, 0x4A28, 0x4207, 0x41E6, 0x5AEB, 0x6B4C, 0x632C, 0x738D, 0x6B6D, 0x634C, 0x6B6D, 0x738D, 0x6B4C, 0x62EB, 0x5AEA, 0x6B4C,
 0x6B4C, 0x632B, 0x62EB, 0x5ACA, 0x62EA, 0x52A9, 0x5ACA, 0x5AAA, 0x8C0F, 0x942F, 0x7B4C, 0x736C, 0xBD33, 0xB513, 0xA491, 0xC5B5,
 0x9C70, 0xACB0, 0x732B, 0xB533, 0xC595, 0x72EA, 0xA490, 0x83AD, 0x83EE, 0x7B8D, 0xA4D3, 0xBD74, 0x9CD2, 0xA4F4, 0xB575, 0x9C70,
 0xDEB9, 0xB554, 0xBD34, 0xCE16, 0x7BCE, 0x530C, 0x42AB, 0x426A, 0x8CB3, 0x8493, 0x8D56, 0x9DD8, 0x9536, 0x638F, 0x532D, 0x4ACB,
 0x5B2D, 0x6BAF, 0x6BAE, 0x7BF0, 0x73EF, 0x7C10, 0x73AF, 0x73AE, 0x5B0C, 0x634D, 0x634D, 0x73AE, 0x73CF, 0x73AE, 0x7BCF, 0x738E,
 0x73AE, 0x73CF, 0x7BCF, 0x73CE, 0x73AE, 0x6B8D, 0x6B6D, 0x6B6D, 0x634D, 0x630C, 0x632C, 0x528A, 0x4A28, 0x4A28, 0x4A28, 0x4A48,
 0x52AA, 0x52AA, 0x5AEB, 0x632C, 0x738D, 0x73AE, 0x73CE, 0x73AD, 0x7BCE, 0x7C0F, 0x840F, 0x8C50, 0x7BEF, 0x8C71, 0x7BEF, 0x8C71,
 0x8430, 0x7BEF, 0x7BEF, 0x7BCE, 0x73AE, 0x8C50, 0x7BEF, 0x634C, 0x4A28, 0x41E7, 0x39C6, 0x41C6, 0x4207, 0x39A6, 0x6B4C, 0x6B4C,
 0x634C, 0x634C, 0x632C, 0x6B6D, 0x632C, 0x62EB, 0x630B, 0x630B, 0x632C, 0x632C, 0x5AEB, 0x62EB, 0x62EA, 0x5A89, 0x62EA, 0x62CA,
 0x6B2B, 0xB554, 0x5249, 0xBD95, 0xBD54, 0x6AEA, 0x7B4C, 0xD5F5, 0xACD1, 0xBD12, 0xACF2, 0xDE78, 0xB533, 0xBD74, 0x3964, 0xD637,
 0xB554, 0x9C91, 0x9C92, 0x3985, 0x5289, 0x8C0F, 0x8BEF, 0xE6DA, 0xA4F3, 0xCE37, 0xCDF6, 0xC5D5, 0x9491, 0x73EF, 0x4AEC, 0x4A8A,
 0x636E, 0x4ACC, 0xB639, 0x8493, 0x7C93, 0x532E, 0x6C11, 0x530D, 0x4ACC, 0x73F0, 0x7C51, 0x7C10, 0x8C72, 0x8C92, 0x8C72, 0x7C10,
 0x6B8D, 0x73AE, 0x73EF, 0x73CF, 0x7BF0, 0x7C10, 0x8410, 0x7C10, 0x8430, 0x7C10, 0x7C10, 0x8410, 0x73CE, 0x73CF, 0x8C71, 0x738E,
 0x6B6D, 0x6B6D, 0x634C, 0x6B6D, 0x5AEB, 0x4A68, 0x4A69, 0x52CA, 0x6B6D, 0x73AE, 0x7BEF, 0x7BEF, 0x7BEF, 0x8430, 0x8430, 0x842F,
 0x8430, 0x8C50, 0x8430, 0x7BEF, 0x7BEF, 0x8450, 0x8C50, 0x7BEF, 0x9491, 0x7BEF, 0x840F, 0x73CF, 0x7BEF, 0x7BEF, 0x7BEF, 0x73EF,
 0x7C0F, 0x6B4D, 0x39C7, 0x39A6, 0x39A6, 0x39A6, 0x3165, 0x4A27, 0x630B, 0x632C, 0x630B, 0x632C, 0x5AEB, 0x6B2C, 0x736D, 0x632B,
 0x630B, 0x5AEB, 0x6B4C, 0x5ACA, 0x630B, 0x5AA9, 0x62CA, 0x62CA, 0xD617, 0x7BCE, 0x6B0C, 0xDE99, 0xE678, 0x940F, 0x7B4C, 0xCDD5,
 0x9CB1, 0xDE37, 0xD617, 0xD5F6, 0xA450, 0xACB2, 0x7B6D, 0x5247, 0xDE99, 0x7B8C, 0xE6B9, 0x940F, 0xCDD7, 0xA4F2, 0xDE57, 0x5A89,
 0x8C10, 0xCDF6, 0xCDB5, 0xCE17, 0xBDB5, 0x636D, 0x52EC, 0x4AAB, 0x424A, 0x8473, 0xB67A, 0xAE5A, 0x7C72, 0x42CC, 0x42AC, 0x4AEC,
 0x42AB, 0x5B2D, 0x73F0, 0x7BF0, 0x73EF, 0x73CF, 0x73CF, 0x7C10, 0x6B8D, 0x6B6D, 0x634D, 0x73AF, 0x73CF, 0x8430, 0x7BEF, 0x7C10,
 0x8C71, 0x8450, 0x7BEF, 0x7BEF, 0x7BEF, 0x73CE, 0x634D, 0x6B4D, 0x6B6D, 0x738E, 0x73AE, 0x73AE, 0x6B8D, 0x6B4C, 0x5AAA, 0x6B4C,
 0x840F, 0x840F, 0x8C50, 0x8430, 0x8430, 0x8C51, 0x8C51, 0x8C30, 0x8C50, 0x8C71, 0x8C71, 0x8430, 0x7C0F, 0x8C70, 0x94B1, 0x8C71,
 0x94B2, 0x8430, 0x8450, 0x8430, 0x8C71, 0x8C91, 0x8410, 0x8C92, 0x8C91, 0x7C10, 0x6B6D, 0x4A69, 0x31A6, 0x41E7, 0x3185, 0x3164,
 0x2965, 0x6B8D, 0x630B, 0x630B, 0x5AEB, 0x62EB, 0x6B4C, 0x6B4C, 0x630B, 0x630C, 0x6B4C, 0x5ACA, 0x62EA, 0x5AA9, 0x5AA9, 0x5269,
 0x940F, 0xD637, 0xD638, 0x62AA, 0x6ACA, 0x93EE, 0x5248, 0xACD2, 0x9C91, 0xDE36, 0xE678, 0xD616, 0xAD13, 0x7B8D, 0x838D, 0xBD95,
 0xCE16, 0xA512, 0xCDB5, 0xD637, 0x62CB, 0xBDB5, 0xCDF5, 0x732B, 0x3966, 0xC5D6, 0xCDD5, 0x734C, 0x8C50, 0x530C, 0x52CC, 0x4AAB,
 0x4AAB, 0x4AAB, 0x7C52, 0xAE19, 0x9D77, 0x84B3, 0x5B6E, 0x42CC, 0x4ACC, 0x3A6A, 0x5B2D, 0x6BD0, 0x8451, 0x7C10, 0x7C10, 0x7C10,
 0x7BCF, 0x73CE, 0x8451, 0x73AE, 0x8430, 0x94D3, 0x8C92, 0x94B3, 0x9D14, 0x8451, 0x8430, 0x7BEF, 0x7BEF, 0x73AE, 0x738E, 0x738D,
 0x738E, 0x738E, 0x73AE, 0x73CF, 0x7BCF, 0x8430, 0x8C50, 0x7BCE, 0x8C50, 0x94D2, 0x9471, 0x9491, 0x73AE, 0x8C51, 0x8C50, 0x8C51,
 0x9491, 0x9491, 0x8C71, 0x8C71, 0x8C71, 0x8C71, 0x8C71, 0x8C71, 0x8C71, 0x8C50, 0x8C70, 0x8450, 0x8C92, 0x8451, 0x9CF4, 0x94B3,
 0x8C92, 0x8471, 0x73EF, 0x6B6D, 0x6B2C, 0x39A6, 0x3185, 0x4A28, 0x3165, 0x2924, 0x6B4C, 0x632C, 0x6B4C, 0x630B, 0x6B4C, 0x5ACA,
 0x630B, 0x62EB, 0x6B4C, 0x6B2C, 0x62EA, 0x630B, 0x5268, 0x62CA, 0x5AA9, 0x730B, 0x834D, 0x732B, 0xCDD5, 0x5207, 0x6B0B, 0xB512,
 0x5A69, 0xBD32, 0xD636, 0xD616, 0x528A, 0xA4B1, 0xD5F6, 0x940F, 0xD5F6, 0xA4B1, 0xD5F6, 0xCDD5, 0xC5D6, 0x5AAA, 0xC5B6, 0xA4D2,
 0xD637, 0x49E6, 0xB533, 0xCDF5, 0x9CF3, 0x530C, 0x52CB, 0x52AB, 0x5B0C, 0x52EC, 0x636E, 0x9D97, 0x7CB4, 0x63D0, 0x4AEC, 0x428A,
 0x4ACC, 0x530C, 0x636F, 0x5B2D, 0x73D0, 0x8452, 0x8C93, 0x8CB3, 0x7C10, 0x73CF, 0x7BEF, 0x8430, 0x8C92, 0x8C92, 0x94B2, 0x9492,
 0x8C92, 0x8C91, 0x8C71, 0x8C71, 0x8430, 0x7C10, 0x8430, 0x7BCF, 0x8430, 0x8C70, 0x8450, 0x8430, 0x8430, 0x8C71, 0x9491, 0x94B2,
 0x94B2, 0x94B2, 0x94B2, 0x8C71, 0x8C70, 0x9491, 0x9491, 0x8C71, 0x8C71, 0x8C71, 0x8430, 0x8C91, 0x94B2, 0x9CD2, 0x94B2, 0x9491,
 0x9491, 0x8C50, 0x9491, 0x8430, 0xA534, 0xA535, 0xA555, 0x9D14, 0x8C92, 0x8451, 0x8430, 0x73AE, 0x6B4C, 0x630B, 0x5AAA, 0x39C7,
 0x3185, 0x4207, 0x3165, 0x736D, 0x6B4C, 0x632B, 0x6B2C, 0x5AEA, 0x630C, 0x62EB, 0x62EA, 0x6B4B, 0x5ACA, 0x5AA9, 0x630B, 0x5289,
 0x6B4C, 0x5AA9, 0x5249, 0x7B6C, 0xC594, 0x7B8D, 0x6B2B, 0xB575, 0xBD54, 0xDE16, 0xA491, 0xCD95, 0x9C71, 0xACB1, 0xE658, 0xD616,
 0xD5F6, 0xD616, 0xBD53, 0xDE78, 0xD5F5, 0xC5D7, 0x5249, 0x8C30, 0x734C, 0xD639, 0xB596, 0x83CF, 0x4AAB, 0x4AEC, 0x4A8A, 0x52EB,
 0x52CB, 0x52EC, 0x426A, 0x84D4, 0xADF9, 0x9D97, 0x6BF1, 0x4AEC, 0x4AEC, 0x426A, 0x5ACC, 0x6B4E, 0x6B8E, 0x636E, 0x7C10, 0x8472,
 0x7BF0, 0x7BF0, 0x8430, 0x8430, 0x8471, 0x8471, 0x8C71, 0x8C92, 0x8C92, 0x94D3, 0x94B2, 0x8C71, 0x8430, 0x8450, 0x8C71, 0x8450,
 0x8451, 0x8C71, 0x8C91, 0x8C71, 0x8C71, 0x9CF3, 0xA534, 0xAD55, 0xB5B6, 0xAD95, 0xA513, 0x9CF3, 0xA513, 0x9CF2, 0x9CF2, 0x94B1,
 0x94B1, 0x9491, 0x94D2, 0x94B1, 0x9CD2, 0x9CF3, 0x9CD2, 0x9CD2, 0x9CB2, 0x9CD2, 0xA534, 0x9CF3, 0xAD96, 0xADB6, 0xADB6, 0x9D14,
 0x8C91, 0x8451, 0x7C10, 0x73CF, 0x6B6D, 0x632C, 0x5ACA, 0x52AA, 0x630B, 0x4A28, 0x41E7, 0x4207, 0x62EB, 0x632B, 0x5ACA, 0x6B4D,
 0x738E, 0x62EB, 0x6B4C, 0x62EB, 0x62EA, 0x5ACA, 0x62CA, 0x5289, 0xBD33, 0x5AA9, 0x9C91, 0xD616, 0xB512, 0x49C6, 0x5A48, 0x4A4A,
 0x8C0F, 0xD636, 0x942F, 0x83AE, 0xACB1, 0xACD2, 0x940F, 0xD616, 0xD616, 0xCDD5, 0xA490, 0xCDD5, 0xCDF7, 0x9CD2, 0xC5D6, 0xC5D6,
 0x5A8A, 0x4A06, 0x3166, 0x5AEB, 0x52EC, 0x4ACB, 0x4A6A, 0x4A8A, 0x52EC, 0x4AAB, 0x52CB, 0x42AB, 0xAE19, 0x84F5, 0x63D0, 0x5B6E,
 0x532E, 0x52EC, 0x4ACB, 0x52EC, 0x634D, 0x73CF, 0x73D0, 0x7BF0, 0x94D4, 0x94D3, 0x7C10, 0x94D2, 0x8C92, 0x9D14, 0xA555, 0x9D34,
 0xB5B6, 0xA555, 0x94B2, 0x8C91, 0x8430, 0x8C91, 0x8C92, 0x94B2, 0x94B2, 0x8C91, 0x9492, 0x94B3, 0x94D2, 0x9D13, 0xA534, 0x9492,
 0x9D13, 0xA554, 0xAD75, 0xAD54, 0xAD54, 0xAD54, 0xA534, 0x9CB2, 0x94D2, 0x9CF2, 0x94D2, 0x9CF2, 0x9CD2, 0x9CD2, 0x9CF3, 0x9492,
 0x9CF2, 0x9CB2, 0x9CF3, 0xA555, 0xB596, 0xB5B7, 0xAD96, 0xA514, 0x8C72, 0x73AE, 0x73CF, 0x6BCE, 0x6B8E, 0x6B8D, 0x5B0B, 0x5269,
 0x4A48, 0x5269, 0x41C7, 0x2944, 0x630B, 0x630B, 0x630B, 0x6B4D, 0x634C, 0x6B4C, 0x6B8D, 0x5AAA, 0x62EA, 0x5AA9, 0x5A89, 0x6B2C,
 0x5A8A, 0x6B4C, 0xAD34, 0x7B6D, 0xCD94, 0x9C70, 0x4A07, 0x9471, 0x6B4D, 0xBD54, 0xDE17, 0x9430, 0x836C, 0x6B2C, 0x6AEA, 0xDE37,
 0xD616, 0xD616, 0xD637, 0xC573, 0xC574, 0xA491, 0xA4F2, 0xCDF6, 0x9C70, 0xD637, 0x8C50, 0x31A7, 0x4249, 0x3A29, 0x4AAB, 0x5B6D,
 0x5B2D, 0x4AAB, 0x426A, 0x6390, 0xC6BB, 0x9536, 0x6BF1, 0x4ACC, 0x530C, 0x530C, 0x52EC, 0x52CB, 0x5B0C, 0x632D, 0x6B2D, 0x8410,
 0x738E, 0x7BF0, 0x8CB3, 0xA556, 0xAD97, 0xADB6, 0xADB7, 0xADB7, 0xAD96, 0xA576, 0xB5D7, 0xB5D7, 0xB5B7, 0x9D14, 0xA535, 0x9CD3,
 0x8C71, 0x8C92, 0xA534, 0x9CF3, 0xA514, 0x9D13, 0xA554, 0xA554, 0xA534, 0xAD75, 0xB5D6, 0xB5B6, 0xB5B6, 0xAD54, 0xAD54, 0xA534,
 0x9CF3, 0x9CF3, 0x94B1, 0x9CD3, 0x9CD2, 0x94B2, 0x9CB2, 0x9492, 0x8C71, 0x94B2, 0x9CD3, 0x9CF3, 0xAD96, 0xB5B6, 0xAD75, 0x94F3,
 0x8471, 0x6BAE, 0x73AE, 0x73CF, 0x6B8D, 0x636D, 0x5B2C, 0x4A69, 0x31A6, 0x3185, 0x39C6, 0x3165, 0x2924, 0x5289, 0x62EB, 0x7BAE,
 0x6B4C, 0x5B0B, 0x6B4C, 0x62EB, 0x630B, 0x62EA, 0x5A89, 0x632C, 0x6B8D, 0x7BAE, 0x6B0B, 0x732C, 0x6AA9, 0x9C92, 0x9472, 0x5269,
 0x8C0F, 0x6AA9, 0xD5D5, 0xE678, 0xDEBA, 0x4A28, 0xDE58, 0x942E, 0xD616, 0xD616, 0xBD54, 0xCDF6, 0xCDF6, 0xA4B2, 0x6BAE, 0x83AE,
 0xC5F7, 0x8C30, 0x8C51, 0x4A69, 0x3A08, 0x4A8A, 0x5B2D, 0x4ACB, 0x4ACB, 0x428A, 0x4A69, 0x5B2D, 0xC6DB, 0x9556, 0x7411, 0x638F,
 0x52EC, 0x530C, 0x5B0C, 0x632D, 0x5B0C, 0x634D, 0x73AF, 0x632D, 0x634D, 0x8C93, 0x94D3, 0xAD76, 0xA575, 0xAD76, 0xB5F8, 0xB5D8,
 0xB5D8, 0xB5F8, 0xBDF8, 0xB5D7, 0xB5D7, 0xAD96, 0xAD75, 0xA534, 0x9CF3, 0x9D14, 0xB5D7, 0xB5D6, 0xAD96, 0xAD75, 0xB5D7, 0xB5B7,
 0xBE17, 0xC659, 0xCE79, 0xB5D6, 0xB595, 0xA554, 0xA534, 0xA534, 0xA555, 0x9CF3, 0x9CD3, 0x9492, 0x8C71, 0x8C51, 0x8C50, 0x840F,
 0x9CB2, 0x9CD3, 0x8451, 0xA555, 0xA534, 0xA555, 0x9D14, 0x8C92, 0x7BEF, 0x634D, 0x632C, 0x6B8E, 0x6B8E, 0x6B6D, 0x632C, 0x528A,
 0x4207, 0x2944, 0x3165, 0x2924, 0x20E3, 0x41E7, 0x4207, 0x5268, 0x630B, 0x5AEA, 0x6B2C, 0x62EA, 0x5AEA, 0x5AAA, 0x5ACA, 0x6B4C,
 0x6AAA, 0x7B4C, 0x7B6C, 0x9CB2, 0xBD75, 0xD658, 0x4A69, 0x9C71, 0xCDD6, 0xA4D2, 0xD658, 0xDE99, 0x7BCF, 0xCE18, 0xD616, 0xD616,
 0xDE36, 0xCDB5, 0xACF3, 0xD637, 0xD616, 0xC658, 0xACF2, 0xB512, 0x7BCE, 0x8C51, 0x8C71, 0x73AE, 0x52AB, 0x4ACB, 0x52EC, 0x4AEB,
 0x532D, 0x4A8A, 0x4249, 0x4AAC, 0x9D76, 0x9D76, 0x8493, 0x6BCF, 0x532D, 0x5B4D, 0x6B8E, 0x636E, 0x94D4, 0x6BAF, 0x6B6E, 0x7BCF,
 0x8C51, 0x8C72, 0x94B3, 0x8C52, 0xB5B7, 0xB5D8, 0xBE19, 0xB5D7, 0xBDF8, 0xAD96, 0xAD76, 0xA555, 0xA535, 0xAD76, 0xA534, 0x94B2,
 0x9CF3, 0xAD75, 0xAD96, 0xB5D7, 0xC659, 0xC67A, 0xC65A, 0xCE9B, 0xBDF7, 0xAD95, 0xB5B6, 0xAD95, 0xAD54, 0xA534, 0x94B2, 0x9CF3,
 0x9D14, 0xB5B6, 0xA555, 0xA534, 0x9492, 0x8C51, 0x8430, 0x8C30, 0x8C31, 0x9CF4, 0xA555, 0xA535, 0xA534, 0x9D14, 0x9CF3, 0x8431,
 0x73AF, 0x632D, 0x5AEB, 0x632C, 0x634D, 0x632D, 0x5B0C, 0x4A69, 0x4A49, 0x3165, 0x2103, 0x20E3, 0x2103, 0x20E3, 0x2944, 0x3164,
 0x3985, 0x39C6, 0x4A27, 0x5289, 0x5AAA, 0x7BAE, 0x52A9, 0x62EB, 0xBDD6, 0xB5B6, 0xA534, 0x730B, 0x83AE, 0xDE36, 0x840E, 0x83AE,
 0x7B0B, 0x628A, 0x7BAF, 0x52AA, 0x738E, 0xEEB9, 0xD616, 0xC594, 0xB4F1, 0xD637, 0xC5D6, 0xD637, 0xD5F6, 0xAD54, 0x7C50, 0xD617,
 0xACF3, 0x8C30, 0x7BEF, 0x8C51, 0x4249, 0x2966, 0x4AAB, 0x530C, 0x42CB, 0x3A49, 0x4A8A, 0x52CC, 0xB619, 0x9D35, 0x7C31, 0x5B6E,
 0x638E, 0x6B6E, 0x6B6E, 0x6B6E, 0x7BF0, 0x8451, 0x7BF0, 0x6B6E, 0x6B2D, 0x94D3, 0xA576, 0xBDF8, 0xB5D7, 0xAD76, 0xA576, 0xA575,
 0xA555, 0xA576, 0xAD76, 0xAD76, 0xAD96, 0xADB7, 0xB5B7, 0xAD75, 0xA534, 0xA534, 0xA554, 0xBE18, 0xCEBB, 0xCE9A, 0xC67A, 0xBE39,
 0xC659, 0xBE17, 0xAD96, 0xAD75, 0xA534, 0xA534, 0x94D2, 0xA534, 0x9D14, 0xAD96, 0xAD96, 0x94B2, 0x8C51, 0x8430, 0x8C71, 0x94D3,
 0x9CF4, 0xA555, 0xA555, 0xAD55, 0xA555, 0x94D3, 0x8C72, 0x7BF0, 0x6B8E, 0x5B0C, 0x5B0C, 0x5B0C, 0x5B0C, 0x5B0C, 0x52AB, 0x4A49,
 0x5ACB, 0x39A6, 0x2944, 0x20E3, 0x2944, 0x18C3, 0x20E3, 0x20E2, 0x20E3, 0x2923, 0x2964, 0x3186, 0x39C6, 0x39C6, 0x4A28, 0x5289,
 0x632C, 0x736C, 0xDE37, 0x734C, 0x9430, 0x738D, 0x62EB, 0x62CA, 0xC574, 0xB512, 0x7B4D, 0x426A, 0x5B4D, 0x9C50, 0xD5F5, 0xD5B5,
 0xDE36, 0xD617, 0xC616, 0x83AE, 0xCDF6, 0xB533, 0xCE37, 0x7B6C, 0xBD54, 0xA4F3, 0x7C10, 0x6B4D, 0x2986, 0x2165, 0x5B2C, 0x4ACB,
 0x4AEC, 0x4A8A, 0x52CB, 0x4AAB, 0xA596, 0x6BAF, 0x7C72, 0x636F, 0x636E, 0x634D, 0x6B8E, 0x6B8E, 0x73D0, 0x7C31, 0x9CF4, 0x94D4,
 0x8431, 0x73AE, 0x8C71, 0x9D14, 0xA514, 0xA514, 0xA535, 0xAD76, 0xAD96, 0xAD96, 0xAD76, 0xB5B7, 0xB5B7, 0xB5F8, 0xBE18, 0xC639,
 0xBDF8, 0xB5D7, 0xB5B6, 0xBE39, 0xC659, 0xC659, 0xC639, 0xBE39, 0xBE18, 0xAD75, 0x9CF3, 0x94D2, 0x9491, 0x83EF, 0x8C71, 0x94D3,
 0xAD96, 0xAD96, 0xAD75, 0xA575, 0x9D14, 0x94D3, 0x9D14, 0x9D14, 0xA575, 0xAD76, 0xADB6, 0xAD96, 0xA555, 0x94B3, 0x8451, 0x73CF,
 0x634D, 0x634D, 0x5AEC, 0x52CB, 0x52EB, 0x5B0C, 0x4A69, 0x4A69, 0x4A49, 0x4208, 0x2965, 0x2944, 0x18E3, 0x6B2C, 0x18E3, 0x18A2,
 0x18A2, 0x18C2, 0x2103, 0x2103, 0x2123, 0x2103, 0x2124, 0x2944, 0x8BCE, 0xAD13, 0xB533, 0x7BCE, 0x6AEA, 0x8C71, 0x8C50, 0xCDD5,
 0x5A69, 0xC594, 0xACB1, 0x5AEB, 0x632D, 0x6B2C, 0xDE79, 0xD636, 0xD5F6, 0xBD74, 0xDE77, 0xCDF6, 0xA491, 0xA4D2, 0xA4F3, 0xB533,
 0x9C50, 0xA4D3, 0x630C, 0x4249, 0x3A28, 0x2145, 0x52EC, 0x530C, 0x52EC, 0x4A8A, 0x4A49, 0x4A8A, 0x8492, 0x52EC, 0x9535, 0x8493,
 0x5B2D, 0x8451, 0x6B6E, 0x8431, 0x73CF, 0x73D0, 0x8C92, 0x9D14, 0xA536, 0x9D35, 0xA534, 0xAD96, 0xA534, 0xA534, 0x9CF3, 0xAD95,
 0xAD76, 0xAD76, 0xB5D8, 0xB5D8, 0xBE19, 0xC65A, 0xBE39, 0xBE39, 0xBDF8, 0xBDF8, 0xBDF8, 0xBDF8, 0xB5F7, 0xBE18, 0xAD96, 0xB5D8,
 0xAD96, 0x94B2, 0x8C71, 0x8C92, 0x9CD3, 0x9CF3, 0x94D3, 0xB5D7, 0xB5D7, 0xADB6, 0xB5D7, 0xAD96, 0xA556, 0xA556, 0xAD76, 0xA535,
 0xA555, 0x9D14, 0x9CF3, 0xA534, 0x9CF4, 0x8C71, 0x73CF, 0x6B4D, 0x634D, 0x632C, 0x5AEC, 0x5AEC, 0x5ACB, 0x52AA, 0x4A6A, 0x4228,
 0x39C7, 0x4207, 0x31A6, 0x2924, 0x2103, 0x18A2, 0x18C2, 0x18C2, 0x10A1, 0x18A2, 0x18E3, 0x20E3, 0x2103, 0x2904, 0x2103, 0x2944,
 0x6AE9, 0xBD54, 0xACB1, 0x9C50, 0x730B, 0x7B8E, 0xD658, 0x72EA, 0x62AA, 0xBD54, 0xEE98, 0xB573, 0xACF3, 0x732C, 0x9451, 0x62AA,
 0xBD76, 0xAD34, 0xD5F6, 0xB4D1, 0xE699, 0xC5D6, 0xA4F2, 0x6ACA, 0x730B, 0x5ACA, 0x52CB, 0x634D, 0x4AAB, 0x2966, 0x4AAB, 0x4AEB,
 0x52EC, 0x4A6A, 0x4A8A, 0x4A8A, 0x52AB, 0x5AEC, 0x636E, 0x73F1, 0x638F, 0x7C52, 0x9D35, 0x8C52, 0x73CF, 0x7BF0, 0x9CF4, 0x8C31,
 0xB5D8, 0xB5B7, 0xADB6, 0x9CD3, 0x9CD3, 0x94B2, 0x9CF3, 0xB576, 0xC659, 0xAD96, 0xC639, 0xC639, 0xC659, 0xB5D7, 0xBDF8, 0xAD76,
 0x94D2, 0x9CF3, 0xAD55, 0x9CD3, 0x9CF3, 0xA555, 0xAD97, 0xAD97, 0xAD96, 0x8430, 0x8C51, 0xAD96, 0xB5D7, 0xB5D7, 0xB5D8, 0xBE19,
 0xBDF8, 0xBDF8, 0xB5D7, 0xAD96, 0xA556, 0xA556, 0xA555, 0xA535, 0x9D14, 0x9CF3, 0x8430, 0x8430, 0x8C72, 0x7BEF, 0x738E, 0x6B6E,
 0x6B8E, 0x6B8E, 0x6B6E, 0x634D, 0x630C, 0x52AB, 0x4229, 0x39C7, 0x3186, 0x4208, 0x41E7, 0x2924, 0x20E3, 0x20E3, 0x18C2, 0x1902,
 0x18C2, 0x18C2, 0x20E3, 0x2104, 0x2924, 0x2123, 0x2103, 0x2923, 0xBD94, 0xC595, 0x5AEA, 0xA4D2, 0x6ACA, 0x9C71, 0xAD54, 0x8C51,
 0x9450, 0xCDD6, 0xD5B5, 0xCE16, 0x6B0C, 0xB4F3, 0xC5D6, 0xC5F7, 0xDE78, 0x528A, 0xCDF7, 0xB532, 0x7B8D, 0xBD95, 0x9C90, 0xAC90,
 0xA4D2, 0x5269, 0x31A6, 0x4A69, 0x426A, 0x4249, 0x52EC, 0x534D, 0x52EC, 0x4A8B, 0x4A8A, 0x4AAB, 0x532D, 0x4249, 0x5B6E, 0x8D15,
 0x9D56, 0x636E, 0x8CB4, 0xAD96, 0xA555, 0xAD76, 0x8C72, 0x9451, 0x9492, 0xA535, 0xBDF7, 0xA514, 0x94B2, 0x9491, 0xA513, 0xAD54,
 0xB5B6, 0xBDF7, 0xB5B6, 0xAD96, 0xAD75, 0xB5D7, 0xA534, 0xA534, 0x9CD3, 0x94B2, 0x9CB3, 0x9CB2, 0x9492, 0x8C72, 0x94B3, 0x94F5,
 0x9D35, 0x9CD4, 0x9D15, 0xA576, 0xADB7, 0xB5B7, 0xADB7, 0xAD97, 0xAD76, 0xAD76, 0xA535, 0x9D15, 0x9D15, 0x9CF4, 0x94D3, 0x94D3,
 0x94B3, 0x94B2, 0x8C92, 0x8431, 0x8410, 0x6B8E, 0x73AF, 0x6B4D, 0x73AE, 0x73AF, 0x6B8E, 0x632D, 0x630C, 0x4228, 0x4208, 0x31A6,
 0x3185, 0x41E7, 0x41E7, 0x2945, 0x2123, 0x20E3, 0x18A2, 0x18C1, 0x20E3, 0x2103, 0x2103, 0x20E3, 0x2103, 0x2103, 0x20E3, 0x18A2,
 0x5248, 0x73AD, 0x83EF, 0x6289, 0x9C71, 0xC617, 0x83EF, 0x9471, 0x732B, 0xBD12, 0xC574, 0xB512, 0x6B0B, 0xDE57, 0xDE36, 0x4A49,
 0xCDB5, 0xCE17, 0x6B0B, 0xCDD6, 0xC5B5, 0xD5F6, 0x9CD2, 0xCDF5, 0x5249, 0x2965, 0x31C7, 0x4ACB, 0x4AAB, 0x52CC, 0x4AAB, 0x532C,
 0x428A, 0x428A, 0x52EC, 0x4AAB, 0x4AAB, 0x426A, 0x426A, 0x63D0, 0x9556, 0x9D56, 0x7C52, 0x9D36, 0xA576, 0xADB7, 0xB5B7, 0x94B2,
 0x9492, 0x9D14, 0xC659, 0xCE9A, 0xB5B6, 0x9CD3, 0xB596, 0xAD75, 0xB5B6, 0xAD55, 0xAD75, 0xAD34, 0xA554, 0x9CF3, 0xA534, 0xB5B7,
 0xA534, 0x9CD3, 0xAD75, 0x8C92, 0x8C51, 0x8431, 0x8C93, 0x8C93, 0x94D4, 0x94F4, 0x9D35, 0x9D15, 0x9D15, 0x9CF4, 0x9D14, 0x9CF4,
 0x94D3, 0x94B3, 0x94B3, 0x94B3, 0x94B3, 0x94B3, 0x94D3, 0x94B3, 0x8C92, 0x8C72, 0x8C71, 0x8451, 0x7BF0, 0x7BEF, 0x73AE, 0x8431,
 0x8430, 0x73AE, 0x6BAE, 0x6B4D, 0x632C, 0x4A89, 0x39A6, 0x3186, 0x3165, 0x2965, 0x39C7, 0x3144, 0x2124, 0x20E3, 0x20E3, 0x18A2,
 0x18C3, 0x18C2, 0x18C2, 0x20E3, 0x20E3, 0x2103, 0x2103, 0x20E3, 0x734C, 0xB514, 0xD656, 0xACD1, 0x9CF3, 0x7B8D, 0xD637, 0x9C2F,
 0x5A48, 0xB4D1, 0xEED9, 0xACB0, 0x732B, 0x8BCE, 0xD5D5, 0xD5F6, 0x3145, 0xCDD6, 0xBDD6, 0xBDB5, 0xA490, 0xD616, 0xA4F2, 0xD638,
 0x5268, 0x630C, 0x4208, 0x4ACB, 0x42CB, 0x4A8A, 0x4A8A, 0x426A, 0x4AEB, 0x42AB, 0x428A, 0x428A, 0x3A49, 0x426A, 0x426A, 0x9D76,
 0x9D56, 0xADD8, 0xAD97, 0x7BF0, 0xA535, 0x73AF, 0x9CD4, 0xB596, 0x9CD3, 0xB596, 0xB5D7, 0xC659, 0xCE59, 0xB596, 0xA534, 0xAD75,
 0x8C51, 0xA4F3, 0xA513, 0xA514, 0x9CD2, 0x9CD2, 0xA514, 0xB596, 0xB5B7, 0xA535, 0x94F4, 0x8472, 0x9D14, 0x94B3, 0x9D35, 0x9D35,
 0x9D56, 0x9D15, 0x94F4, 0x94D4, 0x94B4, 0x94D4, 0x8C93, 0x8CB3, 0x8C92, 0x8452, 0x8C92, 0x94B3, 0x94B3, 0x94B3, 0x9492, 0x8C72,
 0x8431, 0x8C51, 0x8C51, 0x8C51, 0x8410, 0x7BEF, 0x8410, 0x9492, 0x73CF, 0x73AE, 0x738E, 0x6B4D, 0x632C, 0x5ACB, 0x2944, 0x2944,
 0x2945, 0x31A6, 0x4207, 0x3185, 0x2944, 0x20E3, 0x20E3, 0x18C2, 0x20C2, 0x1082, 0x1082, 0x10C2, 0x18C2, 0x18C2, 0x2103, 0x2103,
 0xA4D1, 0x4208, 0x94B2, 0x7BAE, 0x732B, 0x946F, 0x83CE, 0x83CE, 0xE678, 0xCDB5, 0xBD54, 0xCDB5, 0x93EE, 0xE699, 0xCDD5, 0xC593,
 0x9CB1, 0xD637, 0x49E7, 0x4A08, 0xD638, 0xBD74, 0xC5F6, 0x5AAB, 0xCDF6, 0x8C0F, 0x5B2C, 0x4B0C, 0x428A, 0x4AAB, 0x4A8A, 0x426A,
 0x3A29, 0x4ACB, 0x5B2D, 0x4AAB, 0x4ACB, 0x42CB, 0x7C51, 0x9D76, 0x8CD4, 0x532E, 0xB619, 0xB5B7, 0x9D14, 0x9D14, 0xA555, 0x9D14,
 0xB596, 0xA534, 0xAD75, 0xAD75, 0xB5B6, 0xB5B6, 0xAD54, 0xA4F3, 0xA513, 0x9491, 0x9471, 0x9491, 0x9492, 0xA4F3, 0x9CD3, 0x9CD3,
 0xAD96, 0xAD97, 0xB5B7, 0xB5F8, 0xB5F8, 0xBDF8, 0xADB7, 0xA556, 0xA576, 0x9D35, 0x94D4, 0x94D4, 0x94F4, 0x94D4, 0x94F4, 0x9D14,
 0x94F4, 0x94D3, 0x94D3, 0x94B3, 0x94D3, 0x94D3, 0x94B3, 0x8C72, 0x8C72, 0x8451, 0x7C10, 0x8430, 0x8430, 0x8410, 0x8C51, 0x8430,
 0x8410, 0x73CF, 0x6B6D, 0x6B6E, 0x632C, 0x5ACB, 0x3165, 0x2103, 0x2965, 0x4228, 0x4208, 0x5289, 0x4228, 0x2964, 0x2944, 0x2123,
 0x2103, 0x18C3, 0x18A2, 0x18C2, 0x10A2, 0x18C2, 0x18C2, 0x18C3, 0x49E6, 0x39A6, 0x7BAF, 0xB4B0, 0xC596, 0x838D, 0x7B6C, 0x6AC9,
 0x6ACA, 0x836C, 0xDE99, 0xDE78, 0x940F, 0x83EF, 0xACD2, 0xA450, 0xD5F5, 0xCDD5, 0xD5B3, 0xB574, 0x41A7, 0x41C8, 0x62CB, 0x31A7,
 0x9C91, 0x9CB2, 0x4A69, 0x636D, 0x52EC, 0x5AEC, 0x4229, 0x31C7, 0x31C7, 0x39C7, 0x31A7, 0x39E8, 0x52CB, 0x52EC, 0x8C92, 0x6BAF,
 0x8CF4, 0x4ACD, 0xBE3A, 0xBDF9, 0xADB7, 0xBE19, 0xCE7A, 0xBE19, 0xAD75, 0xA514, 0xB5B6, 0xB5B6, 0xC617, 0xA534, 0xA534, 0xAD75,
 0xA513, 0xA513, 0x9CB2, 0x9491, 0xAD75, 0xAD96, 0xBE18, 0xB5B7, 0xBDF8, 0xBE18, 0xBDF8, 0xC639, 0xBE18, 0xBDF8, 0xAD97, 0xA556,
 0x9D35, 0x94F5, 0x94D4, 0x8C92, 0x8CB3, 0x94D4, 0x9CF5, 0x94F4, 0x9CF4, 0x94D4, 0x8CB3, 0x94D3, 0x8C92, 0x8C92, 0x8451, 0x8471,
 0x8C72, 0x8451, 0x8471, 0x8451, 0x8C71, 0x8C71, 0x8C51, 0x8C30, 0x7BF0, 0x7BCF, 0x73AE, 0x6B4D, 0x630C, 0x4A49, 0x39A6, 0x2944,
 0x31A6, 0x4249, 0x4A69, 0x52AA, 0x634C, 0x632C, 0x632C, 0x6B4C, 0x4A28, 0x39A6, 0x20E3, 0x20C3, 0x18C3, 0x18C3, 0x18E3, 0x18E3,
 0xA4D2, 0x62CB, 0x51E7, 0xCDF6, 0xC594, 0xD637, 0xDE16, 0xCDD5, 0x93EE, 0xA4D1, 0xA4F1, 0xA490, 0xB4F1, 0xBD53, 0x83AD, 0xA4B1,
 0xB4F2, 0xD5F6, 0xBD53, 0xCDF5, 0xACF2, 0xB553, 0x6B2C, 0x3966, 0x39A7, 0x41E8, 0x4A49, 0x3A08, 0x31C7, 0x31A7, 0x3A29, 0x4ACC,
 0x426A, 0x31C8, 0x3A29, 0x4ACB, 0x3A69, 0x534D, 0x530D, 0x5B2D, 0xADF8, 0x5B6F, 0x530E, 0xBE7A, 0xB5D8, 0xC639, 0xBDF8, 0xC65A,
 0xC639, 0xAD76, 0xAD35, 0xAD75, 0xB5B6, 0xB5B6, 0xA535, 0xB5B6, 0xAD55, 0xA4F3, 0x9491, 0xA4F3, 0xA4D3, 0xB5B7, 0xBE19, 0xC639,
 0xB5B6, 0xA534, 0xB5D8, 0xB5F8, 0xA556, 0xB5D7, 0xB5B7, 0xA556, 0xA556, 0x9D35, 0x94D4, 0x94D4, 0x94D4, 0x94F4, 0x9D15, 0x9CD4,
 0x94D4, 0x8CB3, 0x8CB3, 0x8C93, 0x8C92, 0x8C72, 0x8451, 0x8471, 0x8431, 0x8451, 0x8431, 0x8C72, 0x8C92, 0x8C72, 0x8C72, 0x8C51,
 0x8410, 0x7BCF, 0x6B6D, 0x632C, 0x630B, 0x4A08, 0x39C6, 0x4A69, 0x41E7, 0x4A49, 0x5ACB, 0x5B0B, 0x5B0B, 0x636C, 0x6B6C, 0x840F,
 0x840F, 0x8C90, 0x7BCE, 0x2123, 0x2104, 0x2924, 0x2104, 0x2104, 0x5249, 0x83EF, 0x9C30, 0xD616, 0xF6FA, 0xA491, 0x732B, 0x8BCC,
 0x8BCD, 0xD5F6, 0xACB0, 0xC574, 0xD5D5, 0xD615, 0xD616, 0x6289, 0x628A, 0xBD54, 0xCDD5, 0xB512, 0xB553, 0xCDD6, 0x5A49, 0x944F,
 0x7BAE, 0x632C, 0x636D, 0x5AEC, 0x4AAA, 0x42AA, 0x428A, 0x29E8, 0x4229, 0x4249, 0x426A, 0x4ACB, 0x42EC, 0x532D, 0x534D, 0x4B0C,
 0x9D56, 0x9576, 0x4B0D, 0xADF9, 0xBE5A, 0xCE7A, 0xB5B7, 0xCE7A, 0xCE7A, 0xC659, 0xB596, 0xA534, 0x9D14, 0xCE7A, 0xCEBB, 0xCE9A,
 0xCE59, 0xA514, 0x9CD2, 0x8C50, 0x9CB2, 0xA555, 0xC659, 0xBE19, 0xB596, 0x9CD3, 0xA555, 0xBDD8, 0xB5D7, 0xB5B7, 0xAD97, 0xAD97,
 0xA556, 0xA555, 0x9D35, 0x94D4, 0x94D4, 0x94F4, 0x94F4, 0x94F4, 0x94B3, 0x8CB3, 0x8CB2, 0x94B3, 0x8C92, 0x8C92, 0x8452, 0x8431,
 0x8451, 0x8431, 0x7BEF, 0x7BCF, 0x8410, 0x8C71, 0x9492, 0x8431, 0x8431, 0x7BF0, 0x6B8E, 0x6B8D, 0x630C, 0x4A28, 0x41E7, 0x5289,
 0x630B, 0x4A69, 0x5AEB, 0x636D, 0x632C, 0x6B6D, 0x7BEE, 0x8C70, 0x8450, 0x8C70, 0x840F, 0x8430, 0x7BEE, 0x736D, 0x2924, 0x2945,
 0x6AEB, 0x41C6, 0x3103, 0xDE57, 0xC554, 0x49C6, 0xCDB6, 0x9C2F, 0x93EE, 0xDE16, 0xCDB4, 0xD5F5, 0xDE36, 0xDE16, 0xD616, 0xD616,
 0xBD32, 0xB513, 0x5A48, 0xA4F2, 0x6B0B, 0xA4D3, 0x49E6, 0x9C4F, 0x9430, 0x7BEE, 0x52AA, 0x6B2C, 0x52AA, 0x4ACB, 0x428A, 0x4B0C,
 0x4A6A, 0x4249, 0x426A, 0x4ACB, 0x4B2D, 0x42CB, 0x530D, 0x42AB, 0x530D, 0xADF8, 0x9556, 0x6BF1, 0xC67B, 0xCE7A, 0xCE9B, 0xD6BB,
 0xCE7A, 0xD6BB, 0xCE79, 0xB596, 0xB5D7, 0xD6DC, 0xD6DC, 0xCE7B, 0xCE7A, 0xBDF8, 0x9CB3, 0x9CB2, 0x9CD3, 0xB5D7, 0xBE39, 0xBE19,
 0xB5B6, 0xAD55, 0x9492, 0xA4F3, 0xA4F4, 0x9CD3, 0xB596, 0xAD76, 0xAD76, 0xA555, 0xA555, 0xA555, 0xA535, 0x9CF4, 0x94D4, 0x94D4,
 0x94F4, 0x8CD3, 0x94F4, 0x94B3, 0x94D3, 0x8C93, 0x8452, 0x8451, 0x8C72, 0x8451, 0x73AE, 0x738D, 0x6B4C, 0x6B4C, 0x6B4D, 0x7BCF,
 0x8430, 0x7BEF, 0x73CF, 0x6B6E, 0x6B6E, 0x5ACB, 0x4A69, 0x5289, 0x5289, 0x5289, 0x4A69, 0x632C, 0x6B4D, 0x632C, 0x7BCE, 0x8450,
 0x8C50, 0x73CE, 0x73AD, 0x7BAE, 0x73AE, 0x73AD, 0x6B8D, 0x632C, 0x41A5, 0x20C3, 0x28C3, 0xD616, 0xACD1, 0xB511, 0xD5D5, 0xBD53,
 0xD5F6, 0xCDD5, 0xCDD5, 0xDDD5, 0xE677, 0xD5D6, 0xB4D1, 0xAC90, 0xC554, 0xA4B0, 0xA4B1, 0x7B2B, 0xC5D6, 0x4A28, 0x9C4F, 0xCDD5,
 0x7BCE, 0x7BAE, 0x840F, 0x632C, 0x52CB, 0x4269, 0x426A, 0x4A8A, 0x4269, 0x4249, 0x4A6A, 0x3A29, 0x3A8A, 0x3AAB, 0x4AEC, 0x632D,
 0x52EC, 0xA5B8, 0x9516, 0xA5B7, 0x8CB4, 0xC67A, 0xCE9B, 0xD6DB, 0xD679, 0xC638, 0xCE59, 0xD679, 0xCE7A, 0xDEFC, 0xD6BB, 0xCE7A,
 0xC639, 0xBDF9, 0xBE19, 0xB5D7, 0xBDD8, 0xC65A, 0xBDF8, 0xBDF8, 0xAD75, 0x9CD2, 0x9CB2, 0x8C50, 0x840F, 0x8C30, 0x8C71, 0x9CF4,
 0xAD76, 0x9CF3, 0x9CB2, 0x94B2, 0x9472, 0x9D14, 0x9D14, 0xA535, 0xA515, 0x9CF4, 0x94D4, 0x8C93, 0x94D4, 0x94B4, 0x94B3, 0x94B2,
 0x8CB3, 0x8C92, 0x73AE, 0x6B4C, 0x6B2C, 0x6B2C, 0x630B, 0x62EB, 0x62EB, 0x73CE, 0x73CF, 0x6B6E, 0x6B8E, 0x634D, 0x6B6D, 0x4A69,
 0x4A49, 0x4A69, 0x528A, 0x52AB, 0x6BAE, 0x738D, 0x7BEF, 0x8C30, 0x840F, 0x73AE, 0x736D, 0x6B4D, 0x6B4C, 0x6B6C, 0x6B4C, 0x632C,
 0xBD53, 0x5ACA, 0x2904, 0x4A08, 0x732B, 0xC574, 0xDDF5, 0xBD33, 0xB513, 0x6AC9, 0xC574, 0xCD95, 0xB4D1, 0xD5F5, 0xD616, 0xACB0,
 0xA450, 0xBD53, 0xCDD5, 0xD5F5, 0x9C50, 0x2926, 0xB594, 0xA4D2, 0x6B2C, 0x634C, 0x52AA, 0x6B2C, 0x52AB, 0x4AAB, 0x4A8A, 0x4249,
 0x4249, 0x428A, 0x52AB, 0x52EB, 0x3249, 0x534D, 0x4B0C, 0x426A, 0x94D3, 0xA596, 0xA5B7, 0xA576, 0x8CD4, 0xADB8, 0xCE7A, 0xCE59,
 0xD69A, 0xC5F7, 0xBDD6, 0xBDD7, 0xBDF8, 0xDEFC, 0xD6DB, 0xCE59, 0xBDF8, 0xBDF8, 0xBDF9, 0xBDF8, 0xBDF8, 0xAD97, 0xAD76, 0xB5B6,
 0x9CB1, 0x9C91, 0x8C30, 0x8C70, 0x9470, 0x8C50, 0x840F, 0x8C30, 0xAD56, 0xA514, 0x9492, 0x9471, 0x9471, 0x8C30, 0x94B2, 0xA575,
 0xAD76, 0xA535, 0x9CF4, 0x94D4, 0x94D3, 0x94D3, 0x94B3, 0x8C92, 0x8C92, 0x94D3, 0x8C51, 0x6B8E, 0x6B2C, 0x5ACA, 0x5A89, 0x5AAA,
 0x5AAA, 0x632C, 0x73AE, 0x6B6D, 0x6B6D, 0x636D, 0x6B6E, 0x632C, 0x4A6A, 0x4A49, 0x52AA, 0x528A, 0x52CB, 0x73EF, 0x7C0F, 0x8430,
 0x8430, 0x73CE, 0x6B4C, 0x736D, 0x6B2C, 0x632C, 0x5B0B, 0x5AEB, 0x9C4F, 0x93EE, 0x4A48, 0x3103, 0xE699, 0xACD1, 0xCDB4, 0xCDF5,
 0x4165, 0x836C, 0xACB1, 0x6268, 0xCDD4, 0xCDB4, 0xCDB4, 0xCD94, 0xD5F5, 0xC574, 0xCDB5, 0xCDD6, 0xBD33, 0x41E8, 0x8C30, 0x9CB2,
 0x5B0B, 0x6B8D, 0x634D, 0x6B2C, 0x632D, 0x426A, 0x4A6A, 0x39E8, 0x4A6A, 0x426A, 0x4A8A, 0x426A, 0x3AAB, 0x3A6A, 0x4AEC, 0x5B6D,
 0x426A, 0x9D35, 0xADD7, 0xADD7, 0xB619, 0xC67A, 0xC65A, 0xCE9A, 0xD699, 0xB575, 0xBDD6, 0xBDD6, 0xC5F7, 0xC618, 0xCE7A, 0xCE9A,
 0xCE7A, 0xB5D8, 0xBDD8, 0xC619, 0xBDF8, 0xAD76, 0xAD76, 0xA534, 0x9491, 0x9450, 0x83EF, 0x8C50, 0x9471, 0x8C30, 0x8C50, 0x8430,
 0x8C71, 0xA514, 0x9CD3, 0x94B2, 0x840F, 0x8C0F, 0x8C30, 0x8C50, 0xA534, 0xA534, 0x9D14, 0x9CF3, 0x9CD4, 0x94B3, 0x94B3, 0x8C72,
 0x8451, 0x8431, 0x73CF, 0x6B8E, 0x630B, 0x5ACA, 0x5ACA, 0x62CA, 0x62CA, 0x52AA, 0x6B8E, 0x6B8E, 0x6B8E, 0x73AF, 0x73AF, 0x6B8E,
 0x634D, 0x5AEC, 0x52AB, 0x4A6A, 0x4A69, 0x73CF, 0x8430, 0x8C71, 0x8C71, 0x8430, 0x6B4C, 0x632C, 0x632C, 0x6B4D, 0x5ACB, 0x5269,
 0xB532, 0xDE57, 0x4A28, 0x3945, 0x3145, 0xB4F3, 0xCDD5, 0x5A28, 0xD617, 0x8C0F, 0xD637, 0xD616, 0xD5F5, 0xCDB5, 0xCDB5, 0xC533,
 0xCDB5, 0xD5F6, 0xB4F2, 0xA490, 0x6AC9, 0x8C10, 0x41C6, 0x9491, 0x73AE, 0x5B0C, 0x5AEC, 0x630C, 0x4A6A, 0x426A, 0x4A8A, 0x4249,
 0x4249, 0x3A4A, 0x428B, 0x3A6A, 0x32AB, 0x4ACC, 0x3229, 0x4A8A, 0x52CC, 0xA596, 0xB618, 0xB618, 0xBE39, 0xCEBB, 0xCE7A, 0xCE7A,
 0xD69A, 0xBDB6, 0xBD96, 0xC617, 0xB575, 0xB575, 0xBDB6, 0xB5B6, 0xAD75, 0xB5B7, 0xBDF8, 0xA535, 0xBDF8, 0xB5B7, 0xB5B7, 0x9CD2,
 0x9CD2, 0x9471, 0x9471, 0x8C50, 0x83EF, 0x9470, 0x7BCE, 0x9471, 0x8C30, 0x8C30, 0xB5B6, 0xA555, 0x9CF3, 0x9CB2, 0x9CB2, 0x94B2,
 0x9CF4, 0xA514, 0x9CF3, 0x9CF3, 0x8C71, 0x9CD3, 0x94B2, 0x7C10, 0x7BF0, 0x73AF, 0x6B6D, 0x738E, 0x73AE, 0x73AE, 0x738E, 0x630C,
 0x62EB, 0x632C, 0x73CF, 0x73CF, 0x7BF0, 0x7BF0, 0x73AF, 0x6BAE, 0x636D, 0x5B0C, 0x52AB, 0x4249, 0x4228, 0x52AA, 0x7BCF, 0x7BEF,
 0x8410, 0x7BEF, 0x5B0B, 0x630B, 0x62EB, 0x5ACB, 0x5AAA, 0x4A28, 0xBD53, 0x732B, 0x9C70, 0x5B0B, 0x39A6, 0xACF3, 0xA4B1, 0x732C,
 0x732B, 0x7B6D, 0xC574, 0xD5D5, 0xD5F5, 0xCDD5, 0xD5D5, 0xD5D5, 0xACD1, 0xD5F6, 0xCDD5, 0xD5F6, 0xCDD5, 0x8C10, 0x4A08, 0x83EE,
 0x6B2C, 0x6B6D, 0x632C, 0x5B0C, 0x4A8A, 0x4AAB, 0x4A8A, 0x426A, 0x4269, 0x42CC, 0x326A, 0x3A8A, 0x3249, 0x3AAB, 0x2A29, 0x530C,
 0x52EC, 0x9515, 0xA576, 0xBDF9, 0xC639, 0xCE7A, 0xCE59, 0xCE7A, 0xD69A, 0xBDD6, 0xCE38, 0xA4F3, 0xAD54, 0xAD34, 0xAD34, 0xA4F3,
 0xA4D3, 0x9CD3, 0xB5D8, 0xB5B7, 0xB5D7, 0xAD76, 0xA555, 0xB5B6, 0x9CB2, 0x9C91, 0x9450, 0x8C50, 0x9CB2, 0xA4F3, 0x9CB2, 0x9CB2,
 0x9471, 0x9491, 0x9492, 0xAD76, 0xAD76, 0xAD55, 0xA534, 0x9D14, 0x9CD3, 0x94B3, 0x94B2, 0x9472, 0x8C51, 0x8451, 0x8410, 0x73AE,
 0x73AE, 0x73CF, 0x7BF0, 0x8410, 0x8411, 0x8431, 0x7C10, 0x73CF, 0x7C10, 0x7C10, 0x7C10, 0x7C10, 0x8430, 0x7BF0, 0x73CF, 0x6B8E,
 0x6B6D, 0x5AEC, 0x4A8A, 0x4A48, 0x4228, 0x4208, 0x632C, 0x73CE, 0x7BCF, 0x73AE, 0x6B8D, 0x632C, 0x5ACB, 0x5ACA, 0x52AA, 0x4A28,
 0xB4F2, 0x8BCE, 0xCDF5, 0x83AE, 0x62CB, 0x3986, 0x5A89, 0x5AAA, 0x4A08, 0x9C50, 0x942F, 0xD5D4, 0xD5D5, 0xD5F5, 0xDE16, 0xD5F6,
 0xD5D5, 0xCDD5, 0xD5F5, 0xCDF5, 0xCD94, 0x7BAE, 0x41C7, 0x844F, 0x636D, 0x5AEB, 0x738E, 0x630D, 0x4A8B, 0x426A, 0x4A6A, 0x4A6A,
 0x424A, 0x3229, 0x432D, 0x4249, 0x3A4A, 0x3A49, 0x3A6A, 0x42AB, 0x3A29, 0x4A8B, 0x8452, 0xBDF8, 0xBE18, 0xC659, 0xC659, 0xC659,
 0xD67A, 0xCE38, 0xC617, 0xB574, 0xB575, 0xAD13, 0xAD13, 0xA4F3, 0x9CD2, 0x9491, 0x9CF4, 0xBDD8, 0xB5D7, 0xBDF8, 0xBDF8, 0xB5D7,
 0xAD75, 0x7B8D, 0x9491, 0x9471, 0x9471, 0x9CD2, 0xA4F3, 0x9C92, 0x9CB2, 0x9491, 0x8C71, 0xAD76, 0xA535, 0xAD55, 0xA555, 0x9CF4,
 0x94D3, 0x94B2, 0x8C51, 0x8C71, 0x8C51, 0x8431, 0x8430, 0x8451, 0x9492, 0x94B2, 0x9492, 0x9492, 0x8C92, 0x8C92, 0x8451, 0x8430,
 0x8451, 0x8410, 0x8430, 0x8430, 0x8410, 0x7C10, 0x73AF, 0x6B6E, 0x632D, 0x52CB, 0x4A6A, 0x4228, 0x39E8, 0x3186, 0x31A6, 0x738E,
 0x634C, 0x6B6D, 0x738E, 0x5AAA, 0x52AA, 0x630B, 0x62EB, 0x52AA, 0xCDB4, 0x836C, 0xBD11, 0x5A47, 0xACD2, 0x5248, 0x3145, 0x39A7,
 0x4228, 0x5A89, 0x9C50, 0xC5B5, 0xC553, 0xCDB4, 0xCD94, 0xDE16, 0xCDB4, 0xCDD5, 0xD5F5, 0xCDD5, 0xACD1, 0x9451, 0x28E4, 0x8C50,
 0x5B4C, 0x4ACB, 0x428A, 0x4A8A, 0x4A6A, 0x428A, 0x4A6A, 0x4229, 0x3A49, 0x3AAB, 0x3AAB, 0x3A49, 0x428A, 0x3A6A, 0x428A, 0x3249,
 0x4A8A, 0x4AAB, 0x8473, 0xB5B7, 0xAD96, 0xC639, 0xC659, 0xCE7A, 0xD69B, 0xD69A, 0xB5B6, 0xAD54, 0xAD33, 0x9CB2, 0x9491, 0x8C50,
 0x9491, 0x8C50, 0xA514, 0xB5D7, 0xB5B7, 0xBDF8, 0xBDF8, 0xB597, 0xC638, 0xA4F3, 0xAD34, 0x9CB3, 0x9491, 0x9CB2, 0xA513, 0x9CD3,
 0x9C92, 0x9472, 0xB576, 0xA555, 0xAD76, 0xA555, 0x9D14, 0xA535, 0x9CF3, 0x94B3, 0x94B3, 0x94B3, 0x94B2, 0x9CF3, 0x9CF3, 0x9D14,
 0x9CD3, 0x9CF3, 0x94B3, 0x9493, 0x94D3, 0x8C92, 0x8C92, 0x8C71, 0x8430, 0x8C51, 0x83EF, 0x7BCE, 0x6B4C, 0x6B4D, 0x6B6D, 0x630C,
 0x5AEB, 0x5AEB, 0x4A69, 0x4208, 0x2965, 0x2965, 0x2985, 0x5ACB, 0x5AEB, 0x52CB, 0x634D, 0x630B, 0x5289, 0x5ACA, 0x5289, 0x5269,
 0x8BAD, 0x8BAD, 0xBD12, 0x6AC8, 0x838C, 0xB4F2, 0x49E6, 0x2945, 0x31C7, 0xC5B6, 0x7B6D, 0x5227, 0xB513, 0x83AD, 0xE678, 0xCDD5,
 0xB4D1, 0xBD32, 0xD616, 0xD5F6, 0xC573, 0xA4F2, 0x3145, 0x7BAE, 0x6BAE, 0x638E, 0x428A, 0x4A69, 0x426A, 0x42AB, 0x4ACB, 0x3A49,
 0x4AAB, 0x328A, 0x4B0C, 0x3249, 0x426A, 0x29C8, 0x428A, 0x42AB, 0x3A29, 0x3A29, 0x5B0D, 0xA555, 0xB5B7, 0xC639, 0xC639, 0xBDF8,
 0xC618, 0xCE59, 0xD679, 0xBD96, 0xAD14, 0xBDD7, 0xB575, 0x9CB1, 0x9491, 0x8C30, 0x9491, 0xCE39, 0xCE59, 0xBE18, 0xB5B7, 0xB5B7,
 0xCE7A, 0xB5B7, 0xBE18, 0xB597, 0xAD75, 0x8C51, 0x9492, 0xA514, 0xA514, 0xA514, 0xB5B7, 0xB5B6, 0xAD76, 0xA555, 0xA555, 0xA555,
 0x94D3, 0x94D3, 0x9CD3, 0x9CF3, 0x9D14, 0xA514, 0x9D14, 0x9CF4, 0x94D3, 0x94B3, 0x94B2, 0x9492, 0x94B3, 0x8C92, 0x8C92, 0x8C71,
 0x8430, 0x7BCF, 0x736D, 0x7BAE, 0x6B6D, 0x62EB, 0x62CB, 0x5AAA, 0x528A, 0x5AAA, 0x5269, 0x4228, 0x31A6, 0x3185, 0x3165, 0x39A6,
 0x4228, 0x6B6D, 0x6B6D, 0x5289, 0x5289, 0x62EB, 0x630B, 0x5269, 0xBD32, 0x736B, 0x7B6C, 0xB512, 0x9C2F, 0xB4F1, 0x836B, 0xCE37,
 0x62EB, 0x5AAA, 0x3986, 0xDE58, 0x6B0C, 0x9C91, 0xDE37, 0x93ED, 0xD5F5, 0xCDD5, 0xD5F5, 0xCDD5, 0xCD93, 0xAD13, 0x5ACA, 0xB5B6,
 0x6B6D, 0x6B6D, 0x4269, 0x3A49, 0x4229, 0x4AEB, 0x426A, 0x4A6A, 0x424A, 0x42CB, 0x3229, 0x3A8B, 0x3209, 0x3249, 0x3A8A, 0x3A8A,
 0x31C8, 0x4A8A, 0x428B, 0xAD97, 0xBDF8, 0xC639, 0xBDF8, 0xC618, 0xC638, 0xC618, 0xCE39, 0xB555, 0xBDD7, 0xC639, 0xC618, 0xBDB6,
 0x9CD2, 0xA513, 0x9CB2, 0xA4F3, 0xBDF7, 0xBDD7, 0xB5B6, 0xB5D7, 0xC618, 0xC5D7, 0xBDD7, 0xBDF8, 0xB597, 0xAD76, 0xAD96, 0xA556,
 0xB596, 0xB597, 0xB5B7, 0xAD96, 0xA555, 0xAD76, 0xAD96, 0xA534, 0x9D14, 0x9CF3, 0x94D3, 0x9CF3, 0x9CD3, 0x9D14, 0x9D14, 0x94F3,
 0x94B2, 0x8C71, 0x94B2, 0x8C92, 0x94B2, 0x94B2, 0x8C71, 0x8451, 0x8410, 0x7BEF, 0x738D, 0x6B6D, 0x6B2C, 0x5ACA, 0x5268, 0x5AAA,
 0x5289, 0x4A28, 0x5269, 0x4208, 0x31A5, 0x31A6, 0x2965, 0x3165, 0x39E7, 0x4A49, 0x5AAA, 0x4207, 0x5289, 0x5269, 0x5269, 0x4A28,
 0xC573, 0xB532, 0xB532, 0xDE57, 0xC594, 0x93ED, 0xD5D5, 0xACD1, 0xC5B5, 0x5207, 0x5207, 0x39A6, 0x5228, 0xC5D7, 0x4269, 0x5A6A,
 0xCDF5, 0xC594, 0xC594, 0xCDB4, 0xCDB4, 0xC594, 0x6B0C, 0x5269, 0x7BEF, 0x52EB, 0x4AEC, 0x52CC, 0x4A4A, 0x426A, 0x3A29, 0x4AEB,
 0x3A69, 0x3AAB, 0x3249, 0x3A8A, 0x31E8, 0x3A6A, 0x324A, 0x42CB, 0x424A, 0x3A29, 0x424A, 0x6BAF, 0xC638, 0xC659, 0xBE18, 0xC639,
 0xC618, 0xC638, 0xC638, 0xC618, 0xAD34, 0xCE59, 0xCE59, 0xC619, 0xB596, 0xA4F3, 0xA4F3, 0xA514, 0xB596, 0xC638, 0xBDF8, 0xAD75,
 0xB596, 0xAD34, 0xAD55, 0xAD76, 0xB5B7, 0xAD76, 0xAD76, 0xAD76, 0xB596, 0xB596, 0xAD76, 0xAD55, 0xA555, 0xA555, 0xA535, 0xA535,
 0x9CF4, 0x94F3, 0x9CF3, 0x9CF4, 0x9CF4, 0x9CF3, 0x94B2, 0x9492, 0x9492, 0x9492, 0x8C71, 0x8C71, 0x9471, 0x8C51, 0x8450, 0x8C71,
 0x8430, 0x8430, 0x738E, 0x6B2C, 0x6B2C, 0x5A8A, 0x5248, 0x5A8A, 0x5249, 0x39C6, 0x41E7, 0x39C6, 0x39A6, 0x31A6, 0x3185, 0x3185,
 0x3185, 0x39A6, 0x39C6, 0x41E7, 0x39E6, 0x4A28, 0x4A49, 0x5AAA, 0x93ED, 0xC5B5, 0xCDF5, 0xC594, 0xB4D1, 0xCD94, 0xA44F, 0xC594,
 0xD5D5, 0xD5D5, 0xACD3, 0xA4D2, 0x3144, 0x3965, 0x52CB, 0x31A6, 0x51E7, 0xCDD6, 0xA470, 0xCD94, 0xCDD5, 0xCDB3, 0xC574, 0x39A6,
 0x73AE, 0x426A, 0x3A8A, 0x428B, 0x3249, 0x42CB, 0x3A29, 0x3A29, 0x424A, 0x328A, 0x328A, 0x2A08, 0x2A08, 0x4AAB, 0x428A, 0x42AB,
 0x3A09, 0x3A29, 0x52AC, 0x3A2A, 0xBE38, 0xC659, 0xCE7A, 0xCE59, 0xCE7A, 0xD69A, 0xC638, 0xCE58, 0xB595, 0xA4F3, 0xCE39, 0xCE59,
 0xC639, 0xC618, 0xBDD7, 0xB5D7, 0xC659, 0xBE18, 0xB596, 0xA4F3, 0xBDD7, 0x9CD2, 0x9CD3, 0xC618, 0xBDD7, 0xA535, 0xB5B7, 0xAD96,
 0xAD76, 0xAD55, 0xA555, 0xAD55, 0xA514, 0xA534, 0x9D14, 0x9D14, 0x9D14, 0x94D3, 0x94B2, 0x9CD3, 0x9CF4, 0x8C71, 0x94B2, 0x94B2,
 0x94B2, 0x9492, 0x9492, 0x7BEF, 0x8C71, 0x8430, 0x8410, 0x8410, 0x8410, 0x7BEF, 0x73AE, 0x738D, 0x6B2C, 0x5ACA, 0x5A89, 0x5269,
 0x5269, 0x4A48, 0x39A6, 0x39A6, 0x31A6, 0x31A6, 0x31A6, 0x39E7, 0x39C6, 0x41E7, 0x39C7, 0x5AAA, 0x5ACB, 0x5289, 0x4A69, 0x5ACA,
 0xCD94, 0x6AEA, 0x942E, 0xACB0, 0xCDB5, 0xCDB5, 0xD5F5, 0x8BED, 0xA470, 0xC574, 0xD616, 0xB534, 0xCD93, 0x4184, 0x2103, 0x5B2C,
 0x4AAA, 0x39E7, 0x3165, 0x2944, 0x9450, 0xCDB5, 0xC595, 0x4A49, 0x5B4D, 0x42AB, 0x426A, 0x4229, 0x42CB, 0x3AAA, 0x3A29, 0x31C7,
 0x3249, 0x3AAB, 0x42AB, 0x31C7, 0x42AA, 0x31A7, 0x3A08, 0x42AB, 0x3A09, 0x424A, 0x4229, 0x39E9, 0xB5D7, 0xCE7A, 0xD6BB, 0xCE9A,
 0xCE59, 0xCE9A, 0xCE59, 0xB596, 0xBDD6, 0xB575, 0xC618, 0xCE59, 0xCE59, 0xCE59, 0xCE59, 0xC659, 0xCE7A, 0xC659, 0xCE59, 0xA514,
 0xBE18, 0xBDF7, 0xA4F3, 0x9CD2, 0x9CD3, 0xBDF8, 0xBDF8, 0xB5B7, 0xB596, 0xAD76, 0xA535, 0xA535, 0x9D14, 0xA514, 0x94B2, 0x9CF4,
 0x9CF3, 0x8C71, 0x8C71, 0x8C72, 0x9492, 0x8C51, 0x8C51, 0x8C51, 0x8C51, 0x8430, 0x8410, 0x8430, 0x8430, 0x8410, 0x7BEF, 0x8410,
 0x8410, 0x73CF, 0x6B6D, 0x6B2C, 0x6B6D, 0x632C, 0x6B2C, 0x5AEB, 0x4A29, 0x4208, 0x41E7, 0x3986, 0x31A6, 0x39C7, 0x39C7, 0x39E7,
 0x41E7, 0x41E7, 0x39C7, 0x39C7, 0x4A69, 0x5ACB, 0x4A28, 0x52AA, 0xD5D4, 0x83AD, 0x9C6F, 0xB4F1, 0xA46F, 0xCDB4, 0x5A47, 0x838D,
 0xCDB5, 0x8BCC, 0xCD94, 0xC594, 0xC595, 0xD5F5, 0xCDD5, 0x5A89, 0x73AD, 0x734C, 0x3924, 0x4186, 0x3187, 0x3146, 0x5269, 0x630C,
 0x4208, 0x3A6A, 0x426A, 0x426A, 0x426A, 0x3A6A, 0x426A, 0x3A28, 0x4AAB, 0x3209, 0x3249, 0x29A7, 0x3A08, 0x4249, 0x31C7, 0x3A08,
 0x3A4A, 0x428B, 0x4A49, 0x4229, 0x4A8B, 0xC639, 0xD6BA, 0xCE9A, 0xCE7A, 0xCE59, 0xD69A, 0xCE59, 0xB5B6, 0xB5B6, 0xBDD7, 0xCE79,
 0xCE7A, 0xD69A, 0xD69A, 0xCE7A, 0xCE59, 0xBDF8, 0xBDF8, 0xC639, 0xBDF8, 0xC5F7, 0xA4F2, 0x9491, 0x9492, 0xB596, 0xBDD7, 0xB5B7,
 0xAD76, 0xAD55, 0x9CF4, 0xAD76, 0x9CF4, 0x840F, 0x7BAE, 0x94B3, 0x8C71, 0x8430, 0x8C51, 0x9472, 0x8C71, 0x8C71, 0x8410, 0x8410,
 0x8410, 0x8430, 0x8C51, 0x8430, 0x73CE, 0x7BEF, 0x73AE, 0x738E, 0x7BEF, 0x73AE, 0x738E, 0x6B4C, 0x62EB, 0x734D, 0x5A8A, 0x5269,
 0x41E7, 0x39C6, 0x3185, 0x31A5, 0x39C6, 0x31C6, 0x31A6, 0x39E7, 0x39C6, 0x41E7, 0x41E7, 0x41E7, 0x39C6, 0x52AA, 0x5AEB, 0x5AAA,
 0xACD1, 0xBD54, 0x6AC9, 0xBD12, 0xC574, 0xACB1, 0x7B6C, 0x9C71, 0x51E6, 0xD5D5, 0xD5B5, 0xC573, 0x8BEE, 0xD617, 0xACB0, 0x942F,
 0x7BCF, 0xB574, 0xBD53, 0xA4B1, 0xA4B1, 0x3986, 0x3145, 0x2104, 0x41C7, 0x4229, 0x4229, 0x4229, 0x4A6A, 0x3A29, 0x3A4A, 0x3A29,
 0x3A2A, 0x3A4A, 0x4ACB, 0x31E8, 0x39E8, 0x31C7, 0x31E8, 0x3A4A, 0x3A29, 0x4ACB, 0x4229, 0x4A4A, 0x424A, 0xD6BB, 0xDEFB, 0xCE9A,
 0xDEFB, 0xD6BB, 0xD6BB, 0xD6BA, 0xCE79, 0xB595, 0xCE59, 0xCE59, 0xCE7A, 0xD69A, 0xD69A, 0xCE7A, 0xC659, 0xC619, 0xBE18, 0xC619,
 0xCE59, 0xBDF7, 0xBDD7, 0x9CB2, 0x9471, 0x8C51, 0xB5B7, 0xB597, 0xAD76, 0xAD76, 0xA515, 0x9CF4, 0x9CD4, 0x9492, 0x7BEF, 0x8430,
 0x9492, 0x8C51, 0x83EF, 0x7BCF, 0x6B4D, 0x7BAE, 0x7BAE, 0x7BCE, 0x7BCE, 0x738E, 0x7BCF, 0x73AE, 0x738E, 0x73AE, 0x6B4D, 0x6B2C,
 0x736D, 0x738D, 0x6B2C, 0x5ACB, 0x526A, 0x5249, 0x4A28, 0x4A08, 0x39C7, 0x39A6, 0x39C6, 0x39C7, 0x39A6, 0x39C6, 0x39E7, 0x39E7,
 0x39C7, 0x39C6, 0x41E6, 0x41E7, 0x39A6, 0x41E7, 0x5AAA, 0x5AEA, 0x736D, 0xC5D6, 0xB512, 0xCD93, 0xD5D4, 0x62A8, 0xD616, 0x732B,
 0xC553, 0x6247, 0xCDB5, 0xBD52, 0xD636, 0x3144, 0xCDD5, 0xCDD5, 0x5AA9, 0xACF1, 0x838C, 0xB513, 0xB512, 0x8BEF, 0x31E7, 0x3228,
 0x2125, 0x2125, 0x3186, 0x31A7, 0x31A7, 0x31C7, 0x2966, 0x31C7, 0x3A08, 0x4249, 0x3A49, 0x3A29, 0x3A08, 0x2145, 0x3A08, 0x422A,
 0x426A, 0x3A8A, 0x3A29, 0x4208, 0x3A08, 0xBDF8, 0xDEBA, 0xD6BB, 0xD6DB, 0xD6BA, 0xD6DB, 0xD6BA, 0xCE9A, 0xC617, 0xB575, 0xD69A,
 0xCE79, 0xCE7A, 0xD6BA, 0xCE79, 0xC659, 0xCE7A, 0xCE5A, 0xC639, 0xC639, 0xC639, 0xC638, 0xAD55, 0x9CB2, 0x9471, 0xA4D3, 0xB5B6,
 0xAD55, 0xB5B6, 0xAD55, 0xAD55, 0xA555, 0xAD55, 0x9CF4, 0x9CF4, 0x9492, 0x8C51, 0x8410, 0x736D, 0x734D, 0x6B2C, 0x6B2B, 0x62EB,
 0x62EB, 0x6B4C, 0x632C, 0x6B8D, 0x73AE, 0x738D, 0x6B2C, 0x6B4C, 0x62CB, 0x5A8A, 0x5249, 0x5A8A, 0x5A8A, 0x4A49, 0x4A69, 0x4207,
 0x39C7, 0x39C7, 0x39C6, 0x39C6, 0x39C6, 0x39C7, 0x31A6, 0x31A7, 0x39C7, 0x39E7, 0x39C6, 0x39E6, 0x41E7, 0x39C7, 0x39E6, 0x39A5,
 0x732A, 0x62CA, 0xA4F2, 0xAD13, 0xC594, 0xDE58, 0xCDD5, 0xC594, 0xD5F5, 0xCDB4, 0xCDB4, 0xCDD5, 0xC5B5, 0xC595, 0x6B0B, 0x944F,
 0xB4B1, 0x7B2B, 0x83CE, 0xAD33, 0xBD74, 0x5248, 0x4249, 0x42EB, 0x4AEB, 0x31C7, 0x4249, 0x4249, 0x2966, 0x3187, 0x3A08, 0x2145,
 0x2986, 0x3186, 0x4229, 0x4A6A, 0x31A6, 0x18E3, 0x39E8, 0x31C7, 0x3208, 0x42AB, 0x4249, 0x4A6A, 0x4A8A, 0xAD96, 0xDEDB, 0xD69A,
 0xD6BB, 0xCE79, 0xD69A, 0xCE7A, 0xCE79, 0xDEDB, 0xBDD7, 0xD69A, 0xD6BA, 0xD6BA, 0xCE79, 0xD69A, 0xD69A, 0xCE7A, 0xCE7A, 0xCE5A,
 0xC639, 0xC659, 0xBDF8, 0xC618, 0xBDD6, 0x9492, 0x9471, 0xB596, 0xAD76, 0xA514, 0xAD55, 0xA534, 0xAD35, 0xA4F4, 0x83D0, 0x9CB3,
 0x8C30, 0x8C51, 0x840F, 0x738D, 0x6B2C, 0x62EB, 0x6B2C, 0x62EB, 0x62CB, 0x5AAA, 0x62EB, 0x5AEB, 0x6B0C, 0x6B2C, 0x6B2C, 0x6B0C,
 0x5249, 0x62CB, 0x4A28, 0x41C6, 0x4A07, 0x4A28, 0x39C6, 0x41E7, 0x3165, 0x3185, 0x31A5, 0x39C5, 0x39C6, 0x3185, 0x41E7, 0x4A28,
 0x5AEB, 0x6B4D, 0x62EB, 0x630B, 0x62EB, 0x5ACA, 0x5269, 0x41C7, 0xBD12, 0xACF2, 0x9450, 0x6ACA, 0x732C, 0x9C91, 0x940E, 0xACD1,
 0x62A9, 0xCDD4, 0xC5B4, 0xBD74, 0x7BCE, 0x5A68, 0x3965, 0xD617, 0xCDD5, 0xBD54, 0xBDB5, 0x9C70, 0x7B8D, 0x8CB2, 0x4B0C, 0x3A6B,
 0x3A49, 0x31E8, 0x3A08, 0x29A6, 0x4249, 0x4A6A, 0x4229, 0x3A28, 0x1904, 0x2104, 0x3186, 0x3186, 0x39A7, 0x4208, 0x31C7, 0x4269,
 0x4229, 0x5AEC, 0x4229, 0x4249, 0x4A6A, 0x5B0D, 0xEF5D, 0xDEDB, 0xD6BB, 0xDEFC, 0xD6DB, 0xD6DB, 0xCEBA, 0xD6BA, 0xD6BA, 0xC5F7,
 0xBDF7, 0xD6BA, 0xC659, 0xCE79, 0xD69A, 0xC659, 0xC618, 0xC618, 0xC638, 0xBE18, 0xC618, 0xC5F8, 0xBDF7, 0xAD96, 0xAD96, 0xAD55,
 0xA535, 0xA535, 0xA535, 0x9CF4, 0xA534, 0x94B2, 0x94B2, 0x8C71, 0x8C50, 0x7BCE, 0x738D, 0x630B, 0x5AEA, 0x6B2C, 0x6B2C, 0x6B4C,
 0x7BAE, 0x738E, 0x4A28, 0x5AAA, 0x5AAA, 0x5A8A, 0x5AAA, 0x5229, 0x5269, 0x5249, 0x41E7, 0x4207, 0x41C6, 0x41C6, 0x41C6, 0x3985,
 0x39A6, 0x39A6, 0x39A6, 0x39C7, 0x73AD, 0x6B4C, 0x630B, 0x630B, 0x634C, 0x6B2C, 0x62EB, 0x734D, 0x632C, 0x630B, 0x62EB, 0x62EC,
 0x30E2, 0x732C, 0x93EF, 0x8C2F, 0xC5F6, 0x5AEA, 0x62CA, 0x7BAE, 0x5AAA, 0x8C50, 0x5AA9, 0xCDB4, 0x5A89, 0xA46F, 0x9C2F, 0x5AEB,
 0x62CA, 0x7B6C, 0x6B4C, 0x8BAE, 0x630C, 0x4ACB, 0x42CC, 0x3A28, 0x42AA, 0x3A29, 0x426A, 0x4249, 0x3A08, 0x4249, 0x4229, 0x3A29,
 0x5B6E, 0x4ACC, 0x3A49, 0x31A6, 0x2166, 0x2145, 0x31C7, 0x4229, 0x4A8A, 0x5AEC, 0x5B0C, 0x52CB, 0x4A8A, 0x4A6A, 0x73AF, 0xDEFB,
 0xD6BA, 0xD6BA, 0xDEDB, 0xE75D, 0xDEFB, 0xD6DB, 0xD6BA, 0xD6DA, 0xC638, 0xD6BA, 0xD69A, 0xC618, 0xC639, 0xCE79, 0xCE59, 0xBDF7,
 0xBE18, 0xBE18, 0xC638, 0xC618, 0xC618, 0xB5B7, 0xB596, 0xA535, 0xAD55, 0xA514, 0xA534, 0x9CF3, 0x9CD3, 0x94B2, 0x9492, 0x7BCF,
 0x738D, 0x738D, 0x840F, 0x6B4C, 0x6B2C, 0x5AAA, 0x5AAA, 0x5269, 0x4A08, 0x4A08, 0x5249, 0x4A28, 0x4A28, 0x4A27, 0x4A28, 0x4A47,
 0x4A28, 0x4A28, 0x4A07, 0x41E7, 0x41E6, 0x39A6, 0x39A6, 0x39A5, 0x31A6, 0x3185, 0x39C6, 0x632B, 0x6B2C, 0x738D, 0x6B4C, 0x6B2C,
 0x62EB, 0x62EA, 0x5ACA, 0x62EB, 0x5ACB, 0x52CB, 0x6B4C, 0x5AAA, 0xCDF5, 0xC5B5, 0x2924, 0x5249, 0x83CE, 0xC595, 0xCDB6, 0x9C91,
 0x5269, 0x632C, 0x5B0C, 0xA512, 0x9CF2, 0x6B0B, 0x6B6C, 0x4A28, 0xCE17, 0x632B, 0xDE79, 0xC5F6, 0x4249, 0x4AAB, 0x532D, 0x428A,
 0x4249, 0x424A, 0x426A, 0x3A29, 0x3A08, 0x4249, 0x3A08, 0x3A29, 0x3A49, 0x2A29, 0x3A09, 0x428A, 0x42CB, 0x4269, 0x3A49, 0x29C7,
 0x3A08, 0x4249, 0x52AB, 0x5ACC, 0x5AEC, 0x630C, 0x5AEC, 0xD69A, 0xD6DB, 0xD6BA, 0xDEFB, 0xD6DB, 0xDEFB, 0xDEFB, 0xDEFB, 0xDEFB,
 0xD6BA, 0xD6DB, 0xC659, 0xC639, 0xC638, 0xBE18, 0xCE59, 0xC618, 0xBDF8, 0xCE59, 0xB576, 0xBDF8, 0xBDD7, 0xBDB7, 0xAD76, 0xAD55,
 0xA555, 0xA534, 0xA4F3, 0x9492, 0x9CD3, 0x9491, 0x8410, 0x8C30, 0x6B2C, 0x7BAE, 0x736D, 0x738D, 0x5AA9, 0x5289, 0x5A89, 0x5269,
 0x5269, 0x41C6, 0x49E7, 0x41C6, 0x4A07, 0x4A28, 0x4A28, 0x4A07, 0x4A28, 0x4A07, 0x41E7, 0x39C6, 0x3185, 0x3185, 0x2965, 0x3165,
 0x3185, 0x3185, 0x31A6, 0x5ACA, 0x632C, 0x632B, 0x630B, 0x6B2C, 0x5ACA, 0x630B, 0x630B, 0x62CB, 0x5AAB, 0x5B0C, 0x632B, 0x62EB,
 0xB534, 0x630C, 0x31E6, 0x636C, 0x6BAE, 0x9C91, 0x83AD, 0x9C91, 0x6B0B, 0xA4B2, 0x528A, 0x31C7, 0x83EE, 0x8BCE, 0xA4D2, 0xC595,
 0x734A, 0x6B0B, 0x83AF, 0x2208, 0x4A8A, 0x426A, 0x42CB, 0x3229, 0x4249, 0x3A29, 0x426A, 0x4A8B, 0x3A29, 0x2966, 0x4249, 0x426A,
 0x3249, 0x3AEC, 0x3249, 0x3269, 0x4B0C, 0x3208, 0x426A, 0x4269, 0x4208, 0x39E8, 0x39C8, 0x31A7, 0x3186, 0x4229, 0x4A8B, 0xE75D,
 0xD6FB, 0xD6FB, 0xDF1C, 0xD6BA, 0xE73C, 0xD6BB, 0xE75D, 0xDEFB, 0xD6BA, 0xCE58, 0xC638, 0xCE79, 0xCE59, 0xCE59, 0xCE59, 0xBDD7,
 0xC618, 0xB5D7, 0xB5B7, 0xBDD7, 0xBDD7, 0xB5B7, 0xAD75, 0xB596, 0xAD55, 0x9CF3, 0xA4F3, 0x8C51, 0x738E, 0x7BEF, 0x8C51, 0x83EF,
 0x7BEF, 0x738D, 0x7BCE, 0x6B2C, 0x5AAA, 0x62EA, 0x5269, 0x5269, 0x4A07, 0x41C6, 0x41C6, 0x41C6, 0x41C6, 0x41E7, 0x49E8, 0x41C6,
 0x39C6, 0x39C6, 0x31A5, 0x3185, 0x3184, 0x2964, 0x2944, 0x2944, 0x3185, 0x3185, 0x39C6, 0x73AE, 0x630B, 0x738D, 0x630B, 0x630B,
 0x6B2C, 0x632C, 0x6B4C, 0x62EA, 0x738E, 0x5B0C, 0x5ACB, 0x62EB, 0x5227, 0x94D1, 0x62EB, 0x4A69, 0x6BAE, 0x5ACA, 0xA4F2, 0x632C,
 0x5289, 0xD615, 0x9491, 0x42AB, 0x52AA, 0x8C2F, 0xAD33, 0x9C71, 0xAD13, 0x9CD2, 0x4AAA, 0x5B2C, 0x31E8, 0x2186, 0x3A6A, 0x426A,
 0x4249, 0x4249, 0x3A29, 0x424A, 0x4AAA, 0x4229, 0x31E7, 0x3208, 0x4AAB, 0x39E8, 0x3208, 0x3A08, 0x3A49, 0x3A29, 0x3A08, 0x4249,
 0x39E8, 0x4229, 0x4208, 0x39E8, 0x3A08, 0x4209, 0x4A6A, 0xD6BB, 0xD6FB, 0xD6BA, 0xDEFB, 0xD6FB, 0xE73C, 0xD6BA, 0xDEDB, 0xDEFC,
 0xD69A, 0xD699, 0xC5F6, 0xAD75, 0xC638, 0xC659, 0xBDD7, 0xC639, 0xC618, 0xC618, 0xBDF7, 0xBDF8, 0xB5B6, 0xB596, 0xAD75, 0xAD95,
 0xAD34, 0x9CD2, 0x94B2, 0x9491, 0x9491, 0x8C30, 0x8C30, 0x7BAE, 0x736D, 0x738E, 0x6B2C, 0x630B, 0x630B, 0x62CA, 0x5AAA, 0x5A89,
 0x4A08, 0x4A28, 0x41C6, 0x41C6, 0x41A5, 0x39A6, 0x3986, 0x39A4, 0x3185, 0x3185, 0x3164, 0x3185, 0x3165, 0x3145, 0x2944, 0x2964,
 0x3165, 0x3185, 0x3185, 0x632C, 0x6B2C, 0x8430, 0x6B4C, 0x62EB, 0x632C, 0x6B2C, 0x738D, 0x5ACA, 0x62EB, 0x52CB, 0x62EB, 0x62EB,
 0x62EB, 0x840F, 0x73AE, 0x5B2C, 0x29A6, 0x73AD, 0xBDD6, 0x8C71, 0x5269, 0xACF2, 0x62EA, 0x7C0F, 0x634C, 0x6B2D, 0x52CB, 0x5AAB,
 0x632C, 0x7C10, 0x3A08, 0x42AB, 0x4A8A, 0x29A7, 0x3A69, 0x426A, 0x428A, 0x3A28, 0x39E8, 0x3A29, 0x424A, 0x4ACB, 0x4A6A, 0x42CB,
 0x29C7, 0x4B0C, 0x4A8A, 0x3A08, 0x426A, 0x31A7, 0x39E8, 0x4A49, 0x4229, 0x528A, 0x4208, 0x39A7, 0x4208, 0x4208, 0x4209, 0x6B8E,
 0xCE9A, 0xD6FB, 0xE75C, 0xD6BA, 0xE75D, 0xDEFB, 0xE71C, 0xE71C, 0xDEDB, 0xD6DA, 0xBDF6, 0xB595, 0xBDD6, 0xC638, 0xBDF7, 0xBDF7,
 0xBDF8, 0xB5D7, 0xBDF8, 0xBDF8, 0xBDD7, 0xB596, 0xA513, 0x9CB1, 0xA4F3, 0xA4F3, 0x9CB2, 0x9471, 0x9CD3, 0x8C50, 0x8C30, 0x8430,
 0x83EF, 0x7BAE, 0x6B6D, 0x6B4C, 0x630B, 0x5ACA, 0x5ACA, 0x5289, 0x4A28, 0x41C6, 0x41C6, 0x39A6, 0x39A6, 0x39A6, 0x39A5, 0x3985,
 0x3185, 0x3164, 0x3164, 0x3165, 0x3164, 0x3165, 0x2944, 0x2944, 0x3165, 0x3185, 0x3185, 0x6B4C, 0x6B4C, 0x6B2C, 0x630B, 0x630B,
 0x6B6D, 0x5AEB, 0x738D, 0x6B2B, 0x62EB, 0x62CB, 0x62EB, 0x630B, 0x7BAE, 0xA513, 0x4A69, 0x3228, 0x428A, 0x4A89, 0x6B4C, 0x632B,
 0x4227, 0x9450, 0xA4F3, 0x7C10, 0x6B4C, 0x7B6D, 0x6B0B, 0xA4F2, 0x5ACA, 0x5AAA, 0x31C7, 0x3A4A, 0x4AEC, 0x4AAB, 0x3A4A, 0x4229,
 0x428A, 0x424A, 0x4229, 0x3A29, 0x428B, 0x2A29, 0x3208, 0x536E, 0x29E7, 0x3A69, 0x3A08, 0x3A08, 0x4269, 0x3A08, 0x31A7, 0x39E8,
 0x31E7, 0x31A7, 0x31A7, 0x4208, 0x39E8, 0x4208, 0x4A6A, 0x39E8, 0xD6BA, 0xD6DB, 0xCEBA, 0xEF7D, 0xDF1C, 0xE73C, 0xDEDB, 0xE71C,
 0xDF1C, 0xDEFB, 0xCE38, 0xC5F6, 0xBDB6, 0xBDD7, 0xC618, 0xC659, 0xBE18, 0xBE18, 0xB5B7, 0xB5B6, 0xB576, 0xB575, 0xA513, 0x8C2F,
 0x8C2F, 0xA513, 0x9CB2, 0x9C92, 0x9471, 0x9471, 0x738D, 0x73AE, 0x7BAE, 0x7BAE, 0x736D, 0x6B4D, 0x6B2C, 0x62EB, 0x6B2C, 0x62EB,
 0x528A, 0x4207, 0x39C6, 0x41C6, 0x41E7, 0x41C6, 0x39A6, 0x39A5, 0x3185, 0x3185, 0x3185, 0x3165, 0x3185, 0x3185, 0x3165, 0x3145,
 0x3185, 0x3185, 0x4207, 0x632C, 0x630B, 0x738D, 0x62EB, 0x6B4C, 0x5ACB, 0x4A69, 0x62EB, 0x630B, 0x630B, 0x5AAA, 0x630B, 0x5ACA,
 0x5A68, 0x83EE, 0x7BCE, 0x52CA, 0x530C, 0x4A8A, 0x5ACA, 0x9471, 0x738C, 0x8C4F, 0xACF3, 0x6B4C, 0x4229, 0x5A8A, 0x83AE, 0x73AE,
 0x83AD, 0x940F, 0x39C6, 0x3A08, 0x426A, 0x424A, 0x328A, 0x42AB, 0x4A6A, 0x4229, 0x4249, 0x3249, 0x32AB, 0x328A, 0x29E8, 0x3209,
 0x3208, 0x3A08, 0x29C7, 0x4249, 0x31E7, 0x31A7, 0x4208, 0x39E8, 0x39E8, 0x3A08, 0x39C7, 0x39C7, 0x39C7, 0x39E7, 0x4208, 0x31A7,
 0xD6BA, 0xD6DA, 0xDEDB, 0xCE79, 0xCE9A, 0xD6BA, 0xDEFB, 0xDEFB, 0xDF1C, 0xD6BA, 0xD699, 0xC5F7, 0xBDB6, 0xBDD6, 0xBDD6, 0xB5F7,
 0xC638, 0xBDF8, 0xB5B6, 0xB5B6, 0xAD55, 0xB575, 0xAD34, 0x840F, 0x9450, 0x8C10, 0x9CB2, 0x9CD2, 0x9CB2, 0x8C50, 0x736D, 0x7BCF,
 0x83EF, 0x7BEF, 0x738D, 0x738D, 0x6B6D, 0x738D, 0x6B2C, 0x5AAA, 0x5AAA, 0x5269, 0x5268, 0x5ACA, 0x5AAA, 0x62EB, 0x5269, 0x41E6,
 0x3986, 0x3185, 0x3185, 0x3185, 0x3185, 0x3185, 0x3165, 0x3165, 0x3165, 0x2965, 0x4A49, 0x630C, 0x632B, 0x7BAE, 0x632B, 0x6B4C,
 0x632C, 0x5AEB, 0x6B2C, 0x632B, 0x62EB, 0x62EB, 0x62CB, 0x62EB, 0x6AEA, 0xAD12, 0x736C, 0x6B6C, 0x5B6D, 0x4AEB, 0x4A89, 0x738D,
 0xBD95, 0x7C30, 0x5AAA, 0x7C30, 0x8430, 0x52A9, 0x5228, 0x62EA, 0x83AD, 0x49E7, 0x3A08, 0x2146, 0x5B6E, 0x31C7, 0x328A, 0x3A29,
 0x2145, 0x52AB, 0x39C7, 0x31A7, 0x21C7, 0x536E, 0x538E, 0x430C, 0x3A29, 0x39C8, 0x3208, 0x39C8, 0x3208, 0x2986, 0x39E8, 0x3A08,
 0x39E8, 0x39E8, 0x41E7, 0x39C7, 0x39C7, 0x39E7, 0x39E8, 0x424A, 0xDEFB, 0xD6DB, 0xDEDB, 0xDF1B, 0xD6BA, 0xDEFB, 0xDEDB, 0xDEDB,
 0xD69A, 0xD6DB, 0xDEFB, 0xD6DA, 0xB595, 0xBDD6, 0xB595, 0xC618, 0xBE18, 0xB5D7, 0xAD55, 0xA534, 0xB575, 0xB575, 0x9CD3, 0xAD75,
 0xAD14, 0xAD34, 0x94B2, 0x9CF3, 0xA4F3, 0x8C50, 0x8C51, 0x8C51, 0x8C30, 0x8C30, 0x7BAE, 0x7BCE, 0x738D, 0x6B4C, 0x632B, 0x632B,
 0x5289, 0x6B4C, 0x630B, 0x630C, 0x6B2C, 0x52AA, 0x5289, 0x5268, 0x4A49, 0x41E7, 0x39C6, 0x31A5, 0x39A5, 0x31A5, 0x3165, 0x3165,
 0x3185, 0x2965, 0x4A28, 0x630C, 0x6B4C, 0x6B2C, 0x630B, 0x630B, 0x6B4C, 0x5AEB, 0x738D, 0x6B4C, 0x62EA, 0x630B, 0x5ACB, 0x6B4C,
 0x7B6C, 0x5269, 0x9471, 0x840F, 0x4269, 0x4ACB, 0x73AE, 0x62EA, 0x5269, 0x638D, 0x532D, 0x6B8D, 0x6B4C, 0x4207, 0x4208, 0x39C7,
 0x4A49, 0x7B8E, 0x8451, 0x534D, 0x428A, 0x4249, 0x0945, 0x2A09, 0x426A, 0x39E8, 0x31A7, 0x39E8, 0x326A, 0x29C7, 0x19C7, 0x29A8,
 0x638E, 0x3166, 0x2986, 0x2125, 0x2965, 0x2966, 0x4229, 0x3A08, 0x41E8, 0x4208, 0x39E7, 0x39C7, 0x4229, 0x3A28, 0x3A08, 0x4209,
 0xCE79, 0xDEDB, 0xE71C, 0xDEFB, 0xEF5C, 0xE73C, 0xDEFB, 0xD6BA, 0xCE79, 0xDEDB, 0xD6DB, 0xDEFB, 0xCE38, 0xBDD6, 0xB575, 0xC618,
 0xC659, 0xBDD7, 0xBDD7, 0xAD55, 0xA534, 0xAD35, 0xAD75, 0xB5B6, 0xB596, 0xAD54, 0x9CD2, 0xA514, 0xA4F3, 0x8C51, 0x8C30, 0x9471,
 0x83EF, 0x7BCE, 0x83EF, 0x7BCE, 0x736D, 0x736D, 0x6B4C, 0x630C, 0x630B, 0x5ACA, 0x6B8D, 0x738E, 0x6B4C, 0x630B, 0x5AEA, 0x5AAA,
 0x4A48, 0x4A28, 0x4A48, 0x4A48, 0x41E7, 0x39A6, 0x3165, 0x3186, 0x3185, 0x2965, 0x630B, 0x630B, 0x4A28, 0x630C, 0x630B, 0x630B,
 0x736D, 0x6B2C, 0x6B4C, 0x5AAA, 0x5ACA, 0x630B, 0x5AEB, 0x5ACB, 0x5289, 0x5289, 0x5ACA, 0x52A9, 0x6BCE, 0x4AEB, 0x634D, 0x738D,
 0x9CB2, 0x4B0A, 0x636D, 0x5AAB, 0x4A07, 0x52AA, 0x4289, 0x4A69, 0x528A, 0x52AA, 0x638E, 0x3A29, 0x29C7, 0x3208, 0x326A, 0x42AB,
 0x428A, 0x2145, 0x2986, 0x4229, 0x426A, 0x6BAF, 0x3208, 0x39C8, 0x31A7, 0x1965, 0x20C4, 0x31A7, 0x2145, 0x2966, 0x41E8, 0x39E7,
 0x31C7, 0x39C7, 0x3186, 0x2986, 0x31A6, 0x3A08, 0x3A07, 0x39C8, 0xE73C, 0xDF1B, 0xE71B, 0xEF5D, 0xE73C, 0xE73C, 0xDEFB, 0xDEFB,
 0xD69A, 0xDEDB, 0xD6DB, 0xD6BA, 0xCE79, 0xCE38, 0xB575, 0xBDD6, 0xC618, 0xBE18, 0xBE18, 0xB5B6, 0xAD75, 0xAD75, 0xB596, 0xAD75,
 0xAD75, 0xB595, 0xA513, 0x9CD3, 0xA4F3, 0x94B2, 0x9471, 0x9491, 0x8C50, 0x8C30, 0x8C50, 0x83EF, 0x738D, 0x6B6C, 0x6B6D, 0x6B6D,
 0x6B8D, 0x6B2C, 0x736D, 0x6B4D, 0x6B6D, 0x7BCE, 0x630B, 0x5AAA, 0x5268, 0x4A69, 0x4A28, 0x4A48, 0x4207, 0x39C6, 0x39A6, 0x31A5,
 0x3185, 0x2965, 0x5B0B, 0x6B4C, 0x9491, 0x6B2C, 0x6B2C, 0x630B, 0x630B, 0x6B2C, 0x6B2B, 0x62EB, 0x5AAA, 0x6B2B, 0x5AEB, 0x528A,
 0x5289, 0x6B0B, 0xA4D1, 0x734B, 0x73CF, 0x52EB, 0x5A8A, 0x62CB, 0x5AAA, 0x4B0B, 0x634C, 0xBD75, 0x9491, 0x63AE, 0x5AEB, 0x634D,
 0x7BAE, 0x636D, 0x4AEB, 0x31C7, 0x428A, 0x3A49, 0x3AAB, 0x29A7, 0x29E7, 0x5B4D, 0x2966, 0x3A8A, 0x31A7, 0x31E8, 0x3A08, 0x3146,
 0x2146, 0x536D, 0x31A7, 0x31E8, 0x3A28, 0x3186, 0x39C7, 0x31A6, 0x2945, 0x2965, 0x4228, 0x4A69, 0x4A49, 0x4208, 0x3A08, 0x4A8A,
 0xD69A, 0xDEFB, 0xE71B, 0xEF3C, 0xD699, 0xD6DA, 0xE73C, 0xE73C, 0xE71C, 0xDEFB, 0xD6BA, 0xDEDB, 0xD69A, 0xDEBA, 0xB5B6, 0xAD54,
 0xC618, 0xBDF7, 0xC618, 0xC618, 0xBDD7, 0xAD76, 0xAD75, 0xB5B6, 0xB5B6, 0xAD54, 0x9CB2, 0xAD54, 0xAD54, 0x8C30, 0x94B2, 0x9CD2,
 0x94B1, 0x9471, 0x9471, 0x840F, 0x7BEE, 0x738D, 0x6B6D, 0x73AE, 0x73CE, 0x6B2C, 0x6B6D, 0x6B4C, 0x6B6D, 0x6B6D, 0x632C, 0x5ACA,
 0x5289, 0x5289, 0x5269, 0x4A48, 0x41E7, 0x39A6, 0x39C6, 0x3185, 0x3185, 0x2965, 0x632C, 0x6B2C, 0x630B, 0x630B, 0x630B, 0x62EB,
 0x630B, 0x630B, 0x632B, 0x62EB, 0x62EB, 0x62EA, 0x630B, 0x630C, 0x632C, 0x8430, 0x6B2B, 0x6B4C, 0x73EF, 0x636D, 0x5ACB, 0x630C,
 0x8C50, 0x42CC, 0x630B, 0x944F, 0x52AA, 0x5ACB, 0x5B0C, 0x7BCF, 0x732B, 0x6B4D, 0x3A28, 0x31C7, 0x3A29, 0x4AEC, 0x430C, 0x3A29,
 0x31E8, 0x21A7, 0x39C8, 0x21C7, 0x39E8, 0x4229, 0x39E8, 0x31C7, 0x31C8, 0x2145, 0x39E8, 0x2946, 0x31A6, 0x31C7, 0x3A08, 0x39E8,
 0x39E7, 0x39E7, 0x39E7, 0x39C7, 0x39E7, 0x2966, 0x4208, 0x4A6A, 0xDEFB, 0xE73C, 0xE71B, 0xE6FB, 0xDEB9, 0xEF5C, 0xE73C, 0xE73C,
 0xDEDB, 0xD6BA, 0xE71C, 0xDEDB, 0xE71C, 0xD69A, 0xCE79, 0xBDF7, 0xD679, 0xC618, 0xC618, 0xC5F7, 0xC5F8, 0xAD76, 0xAD75, 0xB5B6,
 0xAD55, 0xA513, 0x9CD2, 0xAD54, 0xAD74, 0xAD34, 0xAD34, 0x9CD2, 0x9CD2, 0x8C50, 0x9471, 0x8C50, 0x73AD, 0x738D, 0x738D, 0x73AD,
 0x7BCF, 0x738E, 0x6B4C, 0x6B6D, 0x6B6D, 0x738E, 0x632C, 0x52AA, 0x5ACA, 0x5A8A, 0x4A48, 0x4A48, 0x39C6, 0x31A6, 0x39E7, 0x3186,
 0x3185, 0x2985, 0x630B, 0x630B, 0x5AEA, 0x5B0A, 0x630B, 0x6B4D, 0x632C, 0x630C, 0x5ACA, 0x62EB, 0x6B2C, 0x6B4C, 0x632B, 0x5ACB,
 0x5269, 0x528A, 0xB534, 0x5AEB, 0x638D, 0x4A69, 0x6B2C, 0x5289, 0x8450, 0x9CD3, 0x5B2C, 0x738D, 0x94D2, 0x4AAA, 0x736C, 0x5A48,
 0x942F, 0xA554, 0x4ACB, 0x3A49, 0x3A69, 0x3249, 0x3A29, 0x4249, 0x422A, 0x2987, 0x2208, 0x52EC, 0x39E8, 0x4A49, 0x3A49, 0x3A49,
 0x4249, 0x39E8, 0x29C7, 0x3A29, 0x31A7, 0x31C7, 0x4208, 0x3A29, 0x4249, 0x3A08, 0x39E7, 0x4228, 0x4A69, 0x4A49, 0x4A4A, 0x4A6A,
 0xE6FB, 0xDEFB, 0xE71B, 0xE6FB, 0xCE37, 0xF79D, 0xEF3C, 0xDEDB, 0xE71C, 0xDEDB, 0xD6BA, 0xD6BA, 0xDEDB, 0xD6DA, 0xD69A, 0xC638,
 0xCE38, 0xD69A, 0xC638, 0xC638, 0xB596, 0xBDD7, 0xBDD7, 0xAD34, 0xB595, 0xB575, 0xA513, 0xAD34, 0xAD54, 0xAD34, 0xA513, 0xA513,
 0x9CD2, 0x8C50, 0x8C50, 0x9471, 0x7BAE, 0x738D, 0x7BEF, 0x73AD, 0x6B6D, 0x6B4C, 0x736D, 0x738E, 0x738D, 0x738D, 0x736D, 0x6B2C,
 0x5ACB, 0x5289, 0x41E7, 0x4A28, 0x31A5, 0x39A6, 0x39C6, 0x39A6, 0x3186, 0x2965, 0x5AEB, 0x6B4C, 0x6B4C, 0x630B, 0x6B4C, 0x6B4C,
 0x6B4C, 0x6B2C, 0x6B4C, 0x5AAA, 0x6B2C, 0x62EA, 0x736D, 0x6B0B, 0x632C, 0x6B6D, 0x6B4C, 0x4A69, 0x632B, 0x5268, 0x6AAA, 0x41A5,
 0x6B8D, 0x8471, 0x73CF, 0x3A69, 0x4A8A, 0x6AEB, 0x4165, 0x8BCD, 0x7BAE, 0x636D, 0x3209, 0x39C8, 0x3A28, 0x3228, 0x3A29, 0x426A,
 0x3249, 0x39E8, 0x4AEC, 0x3A29, 0x52AB, 0x4A29, 0x2187, 0x2A29, 0x3229, 0x31C7, 0x428A, 0x31E8, 0x4A8A, 0x4249, 0x39C7, 0x3A08,
 0x41E8, 0x41E8, 0x4208, 0x4229, 0x39C7, 0x4208, 0x4209, 0x2104, 0xDEDA, 0xDEFB, 0xE71B, 0xE6FB, 0xDEDA, 0xE71B, 0xE73C, 0xD6BA,
 0xD6BA, 0xDEDB, 0xDEDB, 0xDEDB, 0xDEFB, 0xDEDB, 0xCE79, 0xDEDB, 0xCE59, 0xC617, 0xCE38, 0xC5F7, 0xBDF7, 0xBDD7, 0xB596, 0xAD55,
 0xB5B6, 0xBDD6, 0xAD75, 0xB5B6, 0xA4F3, 0xAD33, 0xA513, 0xA4F2, 0x9CD2, 0x9470, 0x840F, 0x8430, 0x7BCF, 0x83EF, 0x7BCE, 0x7BCF,
 0x6B4D, 0x6B4C, 0x6B6D, 0x6B6D, 0x6B2C, 0x6B2C, 0x632C, 0x5289, 0x4A48, 0x4207, 0x39C6, 0x39C6, 0x3165, 0x3185, 0x39A6, 0x3185,
 0x3186, 0x2965, 0x5AEB, 0x7BAE, 0x62EB, 0x6B4C, 0x736D, 0x734D, 0x632B, 0x6B6C, 0x630B, 0x5ACA, 0x6B4C, 0x630B, 0x630B, 0x62CA,
 0x6BAD, 0x39E7, 0x738D, 0x6AEB, 0xBD74, 0xBD74, 0xBD13, 0xACF2, 0x9471, 0x5B4C, 0x6B2B, 0x634C, 0x8BCD, 0x7B6C, 0x83AE, 0x83CE,
 0x9C91, 0x4A48, 0x3A49, 0x430B, 0x3A49, 0x3A69, 0x3A8A, 0x3A09, 0x4B4D, 0x3A08, 0x1145, 0x5B2D, 0x4229, 0x39E8, 0x31E8, 0x3A6A,
 0x428A, 0x3A29, 0x3A29, 0x4249, 0x3A28, 0x4229, 0x39C7, 0x39E7, 0x4208, 0x39A7, 0x39C7, 0x3A08, 0x4228, 0x4249, 0x4A6A, 0x6B6D,
 0xE6FB, 0xE71B, 0xE73C, 0xE71B, 0xDF1B, 0xE73C, 0xDEFB, 0xEF3C, 0xEF5D, 0xE73C, 0xDEFB, 0xE71B, 0xD69A, 0xCE59, 0xCE9A, 0xCE79,
 0xCE79, 0xCE79, 0xC617, 0xC617, 0xBDF7, 0xBDF7, 0xB596, 0xB596, 0xB595, 0xBDD6, 0xB595, 0xB5B6, 0xB575, 0x9CD2, 0x9491, 0x8C50,
 0x8C30, 0x9491, 0x842F, 0x94B1, 0x840F, 0x7BAE, 0x73AE, 0x738D, 0x738D, 0x738D, 0x6B6D, 0x6B4D, 0x6B2C, 0x62EB, 0x7B8E, 0x528A,
 0x5289, 0x4A28, 0x4A48, 0x3185, 0x3185, 0x3185, 0x39A6, 0x31A5, 0x3185, 0x2965, 0x5ACA, 0x6B6C, 0x6B2C, 0x6B4C, 0x630B, 0x5ACA,
 0x5ACA, 0x6B2B, 0x736D, 0x6B2B, 0x630B, 0x6B2C, 0x5AAA, 0x630B, 0x5A89, 0x4A89, 0x6B2C, 0x83EF, 0x6AC9, 0xA4B0, 0x9C4F, 0x736C,
 0x9431, 0x636D, 0x4A69, 0x4165, 0x83AD, 0xACF1, 0x7B6D, 0xA44F, 0x8C0F, 0x3A69, 0x3ACB, 0x534D, 0x532D, 0x3A49, 0x3249, 0x3A29,
 0x3228, 0x31E8, 0x2A28, 0x31C8, 0x4208, 0x31E8, 0x29C8, 0x3A09, 0x3A28, 0x31C7, 0x3A48, 0x3208, 0x3A07, 0x39E7, 0x39C7, 0x39E8,
 0x39C7, 0x31A6, 0x39E8, 0x3A29, 0x3A08, 0x4A6A, 0x4249, 0xBE38, 0xDEDA, 0xDEDA, 0xE73C, 0xDEDA, 0xE75C, 0xDEFB, 0xEF7D, 0xE73C,
 0xE71C, 0xDEFB, 0xE71C, 0xD6BA, 0xD679, 0xCE79, 0xCE79, 0xCE99, 0xC5F7, 0xC617, 0xC5F7, 0xC638, 0xC638, 0xBDD7, 0xBDD7, 0xBDF7,
 0xB595, 0xB595, 0xAD54, 0xB595, 0xAD54, 0x9CD2, 0xA513, 0xA4F2, 0x9471, 0x8C50, 0x83EF, 0x8C50, 0x7BAE, 0x7BAE, 0x7BEE, 0x73AD,
 0x738E, 0x6B4C, 0x6B4C, 0x632C, 0x630C, 0x62EB, 0x5AAA, 0x4A49, 0x5ACB, 0x5269, 0x4A28, 0x3185, 0x31A6, 0x31A6, 0x31A6, 0x31A5,
 0x31A5, 0x2965, 0x630B, 0x630B, 0x6B6D, 0x5ACA, 0x62EB, 0x6B4C, 0x630B, 0x6B2B, 0x7B8D, 0x6B4C, 0x6B2C, 0x840F, 0x630B, 0x630B,
 0x4A69, 0x73AE, 0x62EB, 0x5ACB, 0xC553, 0xC573, 0x49C5, 0xBD33, 0x6B4D, 0x52EC, 0x5AEC, 0x8BEE, 0x8BAD, 0xCDB4, 0x9C70, 0x62EB,
 0x4A69, 0x3A69, 0x536D, 0x29C6, 0x31C7, 0x3A29, 0x42AB, 0x42AB, 0x4229, 0x21E7, 0x4B0C, 0x39C8, 0x39E8, 0x3A08, 0x3A49, 0x5B0D,
 0x4249, 0x31E7, 0x2986, 0x31C7, 0x39E7, 0x4269, 0x31C7, 0x4208, 0x4229, 0x31A6, 0x31A7, 0x42AA, 0x3A29, 0x4A49, 0x532C, 0xEF5C,
 0xDEBA, 0xDEBA, 0xE71C, 0xE6FB, 0xE71C, 0xEF5C, 0xE73C, 0xEF3C, 0xDEDB, 0xDEFB, 0xDEDB, 0xE71C, 0xD6BA, 0xD6BA, 0xCE79, 0xC659,
 0xC638, 0xD699, 0xBDD6, 0xB595, 0xB5B6, 0xC5F8, 0xBDB6, 0xC5F7, 0xB5B6, 0xB595, 0xB5B5, 0xAD34, 0xA513, 0x9CD2, 0xA513, 0x9491,
 0x8C30, 0x8C30, 0x738D, 0x8C50, 0x83EF, 0x7BCE, 0x840F, 0x73AD, 0x736D, 0x6B6D, 0x6B4C, 0x632C, 0x6B2C, 0x62EB, 0x5289, 0x4A28,
 0x5ACA, 0x4207, 0x3185, 0x3186, 0x3186, 0x39A6, 0x31A6, 0x3186, 0x31A6, 0x2965, 0x630B, 0x62EB, 0x6B4C, 0x632B, 0x6B2C, 0x630B,
 0x630B, 0x736D, 0x62CB, 0x7BAE, 0x630B, 0x6B2C, 0x5ACA, 0x6AEB, 0xAD75, 0x6B2C, 0x62CB, 0x736D, 0x6269, 0xC553, 0x49C5, 0xBD95,
 0x6B4D, 0x8450, 0x630C, 0x7BCE, 0x6B2B, 0xACB2, 0x9D33, 0x630B, 0x6B8E, 0x2A49, 0x31E8, 0x41E7, 0x31A7, 0x29A7, 0x29E8, 0x3228,
 0x39E9, 0x538E, 0x4B2D, 0x3A09, 0x2A09, 0x39E8, 0x39C8, 0x39E8, 0x39C7, 0x39E8, 0x3A08, 0x31E8, 0x39C7, 0x3A08, 0x4A8A, 0x39E8,
 0x39C7, 0x39C7, 0x4A28, 0x4208, 0x4289, 0x4208, 0x4249, 0xD6BA, 0xD69A, 0xCE59, 0xDEBA, 0xDEFB, 0xE71B, 0xE73C, 0xE71B, 0xE71C,
 0xE71C, 0xDEBA, 0xDEDB, 0xDEDB, 0xDEDB, 0xCE59, 0xCE79, 0xC638, 0xCE79, 0xCE58, 0xC617, 0xB595, 0xBDF7, 0xB596, 0xB595, 0xAD34,
 0xBDD7, 0xB595, 0xAD54, 0xAD33, 0xAD54, 0x9CD2, 0xA533, 0x9471, 0x9CD2, 0x8C71, 0x9491, 0x8C30, 0x7BCE, 0x7BAE, 0x840F, 0x738D,
 0x738D, 0x738D, 0x6B6D, 0x6B2C, 0x736D, 0x528A, 0x52AA, 0x528A, 0x39C6, 0x39A6, 0x4207, 0x39A6, 0x3185, 0x31A5, 0x31A5, 0x3185,
 0x3185, 0x2945, 0x5AEB, 0x5B0B, 0x6B4C, 0x6B2C, 0x630B, 0x736D, 0x5AAA, 0x630B, 0x6B2C, 0x6B0B, 0x6B2B, 0x62EB, 0x5ACA, 0x734C,
 0x4A69, 0x4228, 0x5AAA, 0x736D, 0x6289, 0xBD53, 0x7B8D, 0x7B8D, 0x5249, 0x7BCE, 0xAD55, 0x9CD2, 0xA4F3, 0x3227, 0x6AEB, 0x8C71,
 0x5ACB, 0x3A8A, 0x3A28, 0x3207, 0x3A29, 0x3A49, 0x532C, 0x3A8A, 0x2229, 0x3A09, 0x29E8, 0x4AEC, 0x3A8B, 0x4249, 0x31C7, 0x4229,
 0x39E8, 0x4229, 0x4249, 0x31E8, 0x3A08, 0x39E8, 0x3A28, 0x39E8, 0x4A69, 0x39E8, 0x4A28, 0x39A7, 0x31E7, 0x3229, 0x3A29, 0xE6DA,
 0xDEFB, 0xAD34, 0xE6FB, 0xDEDA, 0xE71B, 0xEF7D, 0xE71B, 0xDEFB, 0xDEDB, 0xD6BA, 0xD6BA, 0xDEFB, 0xCE59, 0xCE59, 0xCE58, 0xC658,
 0xBE18, 0xC618, 0xBDD7, 0xC5F7, 0xB576, 0xB595, 0xC5F7, 0xB575, 0xAD55, 0xB5B6, 0xB595, 0xB574, 0xA4F3, 0x9CD2, 0xA534, 0x9CF3,
 0x8C30, 0x9491, 0x9491, 0x8C50, 0x738D, 0x738D, 0x842F, 0x73AD, 0x6B6D, 0x6B6D, 0x632C, 0x6B4D, 0x5ACA, 0x4A49, 0x39C7, 0x4A48,
 0x3185, 0x41E7, 0x31A6, 0x3185, 0x3185, 0x31A6, 0x31A6, 0x31A5, 0x3185, 0x2965, 0x6B4D, 0x62EB, 0x6B4C, 0x6B2C, 0x6B2C, 0x736C,
 0x630B, 0x6B2C, 0x6B2C, 0x62EB, 0x736D, 0x5ACA, 0x632C, 0x630B, 0x4269, 0x4A8A, 0x5AAA, 0x5248, 0xC574, 0x9C70, 0x9430, 0xACB0,
 0x30E4, 0x5AC9, 0x4A28, 0x6B0B, 0x39E7, 0x6ACA, 0x6B8C, 0x4AEB, 0x52EB, 0x52AA, 0x39C7, 0x3A6A, 0x3A29, 0x4229, 0x3A49, 0x3208,
 0x42CC, 0x29E7, 0x31A7, 0x39E8, 0x39C7, 0x3207, 0x4208, 0x3A08, 0x39E8, 0x29A7, 0x39E8, 0x39E8, 0x39E8, 0x39E8, 0x4A49, 0x39A7,
 0x39C6, 0x31C7, 0x3A08, 0x39E8, 0x4AEB, 0x4249, 0x39E8, 0xDEFA, 0xDEFB, 0xD6BA, 0xD6BA, 0xCE59, 0xE71C, 0xE71C, 0xDEBA, 0xEF5C,
 0xDEDB, 0xD6BA, 0xDEFB, 0xD679, 0xD679, 0xCE59, 0xC638, 0xBDD7, 0xBE17, 0xC617, 0xBDF7, 0xBDD7, 0xB596, 0xBDF7, 0xBDD6, 0xA4F2,
 0xB595, 0xAD54, 0xAD75, 0xA513, 0x9CB2, 0x9CD2, 0xA513, 0x9CB2, 0x9CD2, 0x8C30, 0x94B2, 0x8410, 0x83EF, 0x840F, 0x73AD, 0x7BEE,
 0x7BEE, 0x738D, 0x6B4D, 0x6B4D, 0x5AAA, 0x5AEB, 0x4A48, 0x4A69, 0x4207, 0x4A68, 0x39E6, 0x3185, 0x3185, 0x39A6, 0x3186, 0x3185,
 0x2985, 0x2966, 0x6B4D, 0x632B, 0x7BCE, 0x62EB, 0x62EB, 0x5ACA, 0x62EA, 0x6B4C, 0x630A, 0x4A27, 0x62EB, 0x62EB, 0x634C, 0x630B,
 0x8C30, 0x4A8A, 0x5A8A, 0x8BCD, 0x7B6C, 0x4A89, 0x7B8D, 0xA4F2, 0x3944, 0xAD53, 0x52CB, 0x9471, 0x4228, 0x83AD, 0xA4F2, 0x42CC,
 0x632C, 0x3A07, 0x39E7, 0x3A69, 0x3208, 0x3A8A, 0x3249, 0x4B4D, 0x31C8, 0x3249, 0x31E8, 0x434D, 0x31E7, 0x39C7, 0x39E8, 0x41E8,
 0x31E8, 0x3A08, 0x31E7, 0x4249, 0x31A7, 0x4249, 0x3A08, 0x39C7, 0x31A6, 0x39E8, 0x3A49, 0x4269, 0x4A6A, 0x4A49, 0x6B8E, 0xD679,
 0xD6BA, 0xDEDA, 0xE71C, 0xE6FB, 0xDEBA, 0xE71B, 0xE71B, 0xE71C, 0xE73C, 0xDEDB, 0xDEDA, 0xD699, 0xC638, 0xCE38, 0xCE59, 0xBDF7,
 0xC618, 0xBDF7, 0xBE17, 0xBDD6, 0xAD55, 0xBDB6, 0xBDB5, 0xAD13, 0xAD13, 0xA513, 0xA513, 0xA513, 0xAD34, 0xA534, 0xA513, 0x94B2,
 0x9491, 0x8430, 0x8C70, 0x8C50, 0x8C71, 0x840F, 0x8430, 0x8C30, 0x7BCE, 0x6B6D, 0x738D, 0x6B4D, 0x62EB, 0x5289, 0x4A49, 0x4208,
 0x5A8A, 0x3185, 0x41E7, 0x39C6, 0x3185, 0x3185, 0x39A6, 0x3165, 0x2985, 0x2145, 0x73AE, 0x632B, 0x6B2C, 0x6B0C, 0x62EB, 0x630B,
 0x6B0C, 0x5AAA, 0x6B2C, 0x5AAA, 0x630B, 0x5ACA, 0x630B, 0x5ACB, 0x5269, 0x4A29, 0x3985, 0xA470, 0x946F, 0x4268, 0x41C6, 0x62CA,
 0x4A28, 0x62EC, 0x5ACB, 0x7BAD, 0x734C, 0x5269, 0x5AAA, 0x4289, 0x736D, 0x52AA, 0x3A28, 0x3208, 0x3A29, 0x3229, 0x42AB, 0x4B4D,
 0x2A08, 0x39E8, 0x2208, 0x3A49, 0x3A28, 0x4249, 0x3208, 0x4249, 0x4B0C, 0x3208, 0x5ACB, 0x39A7, 0x3A28, 0x4A8A, 0x5AEB, 0x4A8A,
 0x4A6A, 0x4AAB, 0x4AEC, 0x4A8A, 0x3A08, 0x4A49, 0xEF5D, 0xDEDB, 0xDEDA, 0xDEFB, 0xDEFB, 0xDEDB, 0xCE58, 0xCE58, 0xE6FB, 0xD699,
 0xDEBA, 0xDEBA, 0xD6BA, 0xCE59, 0xCE59, 0xBDF7, 0xC638, 0xC5F8, 0xBDD7, 0xBDF7, 0xBDD7, 0xBDF7, 0xC5F7, 0xB5B6, 0xB575, 0x9C90,
 0x9470, 0xAD54, 0xA513, 0x9CB1, 0xAD34, 0xAD34, 0xA513, 0x9491, 0x8C71, 0x842F, 0x9491, 0x8C71, 0x8C30, 0x9491, 0x9491, 0x7BEF,
 0x8410, 0x73AE, 0x738D, 0x5AAA, 0x5289, 0x4A28, 0x4A28, 0x4A28, 0x41E7, 0x39A6, 0x39C7, 0x3186, 0x3185, 0x31A5, 0x3185, 0x2965,
 0x2985, 0x2145, 0x632C, 0x630B, 0x6B4C, 0x630B, 0x6B4C, 0x630B, 0x6B4C, 0x630B, 0x630B, 0x630C, 0x5ACA, 0x4A48, 0x630B, 0x6B2B,
 0x41C7, 0x5A8A, 0x7B6D, 0x5A48, 0x9C91, 0x31E7, 0x4A89, 0x3A28, 0x39E7, 0x62CB, 0x4A08, 0x62A9, 0xC553, 0x83CE, 0x8BEF, 0x4A07,
 0x6B6D, 0x3A07, 0x4208, 0x4A49, 0x4249, 0x3A29, 0x31C7, 0x3209, 0x2249, 0x3A49, 0x19C7, 0x4AAB, 0x39E8, 0x39E8, 0x3A28, 0x3A28,
 0x3A29, 0x3A29, 0x2966, 0x39C7, 0x4A49, 0x3A08, 0x3A08, 0x4269, 0x3A08, 0x4AEB, 0x4269, 0x52CB, 0x4AAB, 0x3A08, 0xD69A, 0xDEDA,
 0xDEFB, 0xE71B, 0xDEFB, 0xDEFB, 0xEF3C, 0xCE79, 0xDEDA, 0xD679, 0xE6FB, 0xE71C, 0xD69A, 0xD6BA, 0xC638, 0xBDF7, 0xBDD7, 0xBDD7,
 0xC638, 0xBDD7, 0xBDF7, 0xBDD7, 0xBDB6, 0xC618, 0x9CB2, 0x9C90, 0x8C50, 0x9CD2, 0x9491, 0x8C50, 0x8C50, 0x9471, 0xA534, 0x9CF3,
 0x94D2, 0x94B1, 0x94D2, 0x8C50, 0x8C71, 0x9CD2, 0x8C70, 0x8430, 0x7BCE, 0x7BEF, 0x73AE, 0x5ACA, 0x5AAA, 0x5AAA, 0x4A28, 0x5269,
 0x4207, 0x41E7, 0x39C6, 0x3185, 0x3185, 0x3185, 0x3185, 0x3185, 0x2985, 0x2165, 0x632C, 0x6B2C, 0x6B2C, 0x6B4C, 0x62EB, 0x630B,
 0x630B, 0x632B, 0x6B2C, 0x6B2C, 0x736D, 0x630B, 0x632B, 0x6B2B, 0x41C7, 0x6AEB, 0x732C, 0x5228, 0x5ACA, 0x52CA, 0x3A07, 0x52AA,
 0x528A, 0x4A27, 0x9450, 0x83AD, 0xA470, 0xAD11, 0x9430, 0x83CE, 0x7BAD, 0x3A07, 0x4248, 0x39E7, 0x3208, 0x3229, 0x31E8, 0x3A49,
 0x2A29, 0x31E8, 0x31C7, 0x29A7, 0x3A08, 0x39E7, 0x3228, 0x2A08, 0x3A49, 0x426A, 0x4208, 0x41E8, 0x4208, 0x4208, 0x4208, 0x4A69,
 0x4208, 0x3A69, 0x3A28, 0x4249, 0x4A49, 0x31C6, 0xDE9A, 0xD6BA, 0xD6BA, 0xDEBA, 0xDEDB, 0xD69A, 0xD69A, 0xD6BA, 0xD69A, 0xDEDA,
 0xE6FB, 0xDEDA, 0xCE99, 0xD679, 0xC638, 0xBDF7, 0xB596, 0xB5D7, 0xB5B6, 0xC618, 0xB596, 0xAD75, 0xB575, 0xAD55, 0xA4F2, 0x9C91,
 0x9CB2, 0x9491, 0x94B2, 0xA513, 0x94B2, 0x9CF3, 0x8C71, 0x94B2, 0x94D2, 0x94B1, 0x8C50, 0x8C91, 0x8C71, 0x9491, 0x8450, 0x7BEF,
 0x840F, 0x7BEF, 0x6B6D, 0x6B6D, 0x630B, 0x528A, 0x5269, 0x62EB, 0x4A29, 0x41E8, 0x2965, 0x3186, 0x2985, 0x3185, 0x31A5, 0x31A5,
 0x2985, 0x2165, 0x5AEB, 0x6B4D, 0x6B2C, 0x630B, 0x630B, 0x632C, 0x62EB, 0x630B, 0x630B, 0x630B, 0x5AA9, 0x5ACA, 0x6B4C, 0x5ACA,
 0x41E7, 0x9CB2, 0x7B4D, 0x52CA, 0x29A6, 0x31E7, 0x3A68, 0x39A5, 0x4207, 0x39A6, 0xAD13, 0x9450, 0xC5D6, 0x840F, 0x4207, 0x4A07,
 0x52AA, 0x39E7, 0x3A08, 0x39E8, 0x3208, 0x42AB, 0x2A07, 0x3A29, 0x3A8B, 0x3228, 0x534C, 0x3AAB, 0x29C7, 0x426A, 0x29C7, 0x2A07,
 0x31E7, 0x2986, 0x31C7, 0x39E7, 0x41E8, 0x39E8, 0x31E7, 0x3A08, 0x4249, 0x4269, 0x3A28, 0x3A08, 0x3A49, 0x8471, 0xDE9A, 0xCE79,
 0xDEDB, 0xDEBA, 0xDEDA, 0xE6FB, 0xE6FB, 0xE73C, 0xDEDA, 0xD679, 0xDEDB, 0xCE58, 0xC638, 0xCE79, 0xC618, 0xB5B6, 0xBDF7, 0xBDD7,
 0xBDD7, 0xB5B6, 0xB5B6, 0xBDD7, 0xBDB6, 0xBDF7, 0xB595, 0xAD34, 0x9CB2, 0xA514, 0x9CF3, 0x9CF3, 0x9CF3, 0x9CF3, 0x9CD2, 0x94B1,
 0x9CF3, 0x8C91, 0x9491, 0x8C71, 0x9491, 0x8C71, 0x8C50, 0x7BCE, 0x7BCE, 0x73AE, 0x738E, 0x5B0B, 0x5ACB, 0x52AA, 0x4208, 0x4A69,
 0x5269, 0x39E7, 0x39C7, 0x3165, 0x2965, 0x3185, 0x3185, 0x3165, 0x2986, 0x2145, 0x5AEB, 0x6B4C, 0x6B2C, 0x632C, 0x6B2C, 0x630B,
 0x630B, 0x62EA, 0x630B, 0x62EA, 0x62CA, 0x6B2C, 0x5ACA, 0x62EB, 0x2944, 0x73AE, 0x83EF, 0x4ACA, 0x4A88, 0x3A07, 0x3A07, 0x630B,
 0x5289, 0x41E7, 0x6AEA, 0x9471, 0x62EB, 0x9470, 0xB534, 0x5228, 0x5A8A, 0x39C7, 0x3A07, 0x3A08, 0x4269, 0x21E7, 0x3269, 0x2208,
 0x32AA, 0x4289, 0x29C7, 0x2A69, 0x3A69, 0x3A29, 0x31C7, 0x3A28, 0x426A, 0x4208, 0x39A7, 0x41E8, 0x31A7, 0x2986, 0x3A08, 0x2986,
 0x39E7, 0x29A6, 0x4269, 0x3A49, 0x31C7, 0xE75C, 0xD69A, 0xCEBA, 0xD6BA, 0xD6BA, 0xD699, 0xDEDA, 0xDEFB, 0xDEBA, 0xD69A, 0xDEDB,
 0xC638, 0xD69A, 0xC618, 0xCE59, 0xBDD7, 0xB5D7, 0xB5D7, 0xAD75, 0xAD75, 0xB5D6, 0xA514, 0xB5B6, 0xB596, 0xAD75, 0xBDB6, 0xA514,
 0x9CF3, 0xA534, 0x9D14, 0xA534, 0xA514, 0x9CF3, 0x8C50, 0x9CF3, 0x9CD2, 0x8C71, 0x94B2, 0x8C71, 0x8C91, 0x9491, 0x840F, 0x7BEF,
 0x73AE, 0x738D, 0x632C, 0x6B4D, 0x630B, 0x62EB, 0x4A49, 0x5ACB, 0x39A6, 0x39C6, 0x4A69, 0x2985, 0x2965, 0x3165, 0x2965, 0x2965,
 0x2965, 0x2965, 0x5AEB, 0x6B4C, 0x6B2C, 0x630B, 0x630B, 0x632C, 0x6B4C, 0x62EB, 0x630C, 0x5ACA, 0x62EB, 0x5AEB, 0x62EB, 0x6B2C,
 0x3145, 0x4A8A, 0x5AEB, 0x4269, 0x2184, 0x3A07, 0x4A28, 0x4A48, 0x9471, 0x3186, 0x9C71, 0x8C30, 0x4A48, 0x9450, 0x6B0B, 0xA4B2,
 0x5ACB, 0x4208, 0x3A28, 0x29A6, 0x31E8, 0x42CB, 0x29E7, 0x2A28, 0x2A69, 0x3AAA, 0x2A28, 0x3ACB, 0x3A69, 0x3A89, 0x29E7, 0x29C7,
 0x3A28, 0x31C7, 0x4228, 0x41E8, 0x39C7, 0x39E8, 0x4208, 0x4229, 0x3A08, 0x39E8, 0x4229, 0x39E8, 0x31E7, 0xD699, 0xCE9A, 0xD6BA,
 0xD6BA, 0xDEDB, 0xDEFB, 0xDEDA, 0xDEDB, 0xD69A, 0xCE59, 0xCE79, 0xCE59, 0xC618, 0xD69A, 0xC638, 0xBDF7, 0xB596, 0xB5D7, 0xB5B6,
 0xA534, 0xB5B6, 0xA514, 0xB595, 0xB575, 0xB595, 0xB575, 0xAD75, 0xAD54, 0xA513, 0xA534, 0x9CF3, 0xA513, 0x9CF3, 0x94B2, 0x9CF3,
 0x94B2, 0x8C71, 0x94B2, 0x8C71, 0x8430, 0x8C71, 0x840F, 0x7BCE, 0x738D, 0x738D, 0x738E, 0x5AEB, 0x62EB, 0x62EB, 0x4A49, 0x4A48,
 0x41E7, 0x4A48, 0x4A69, 0x2985, 0x2965, 0x3165, 0x2965, 0x2965, 0x2945, 0x39E8, 0x5B0C, 0x632C, 0x6B6D, 0x6B4C, 0x738D, 0x630B,
 0x630C, 0x62EB, 0x632C, 0x630B, 0x6B4C, 0x62EB, 0x62EB, 0x6B0C, 0x49C6, 0x4228, 0x39C7, 0x3207, 0x2164, 0x2985, 0x6B4C, 0x4268,
 0x7BAE, 0x5B0C, 0x8C50, 0x5AAA, 0x6B2C, 0x83EF, 0x9430, 0x83CF, 0x4208, 0x39C7, 0x10C3, 0x31E8, 0x21C7, 0x29E8, 0x2A07, 0x3208,
 0x4269, 0x2A49, 0x2A28, 0x4ACB, 0x4A8A, 0x29C7, 0x31E7, 0x3228, 0x3207, 0x31E7, 0x31E7, 0x31A6, 0x39E7, 0x39C7, 0x31C7, 0x31E8,
 0x3A09, 0x31C8, 0x31C7, 0x426A, 0x4AAA, 0xD699, 0xCE9A, 0xD69A, 0xCE99, 0xD6BA, 0xCE79, 0xD699, 0xE71C, 0xCE99, 0xD6BA, 0xC638,
 0xC658, 0xC638, 0xBDF6, 0xB5B5, 0xB596, 0xAD55, 0xA514, 0xAD75, 0xBDD7, 0xAD96, 0xAD75, 0xAD75, 0xB595, 0xB596, 0xAD55, 0xAD55,
 0xAD54, 0xA534, 0x9CD2, 0x9CF3, 0x9CF3, 0x9CD2, 0x94D2, 0x9CF2, 0x8C92, 0x8C91, 0x94B2, 0x8430, 0x8C50, 0x8430, 0x7C0F, 0x7BCE,
 0x6B8D, 0x6B6D, 0x632C, 0x5AEB, 0x632C, 0x62EB, 0x5ACB, 0x5ACB, 0x4208, 0x4A49, 0x31C6, 0x2965, 0x2985, 0x2965, 0x2965, 0x2164,
 0x2144, 0x5B2C, 0x6BAE, 0x5B0B, 0x632B, 0x632C, 0x738D, 0x6B2C, 0x62EB, 0x62EB, 0x632D, 0x5AEB, 0x632C, 0x6B0C, 0x5AAA, 0x630B,
 0x39C6, 0x2964, 0x52AA, 0x3228, 0x1923, 0x29E7, 0x29C6, 0x2943, 0x5ACA, 0x5AEB, 0x29A6, 0x5AAB, 0x5ACA, 0x4A08, 0x730A, 0x5A89,
 0x4208, 0x31E7, 0x31A7, 0x31C8, 0x2A08, 0x2A07, 0x2A07, 0x2A28, 0x2A07, 0x2A07, 0x3ACB, 0x3208, 0x21A6, 0x2A07, 0x31E7, 0x31C7,
 0x3208, 0x3A08, 0x3A28, 0x3A08, 0x4229, 0x39E8, 0x39E8, 0x39E7, 0x31C7, 0x424A, 0x39E8, 0x3A4A, 0xE6FB, 0xCE79, 0xCE99, 0xCE79,
 0xD6BA, 0xCE99, 0xD699, 0xDEBA, 0xCE59, 0xD6BA, 0xCE79, 0xCE58, 0xC638, 0xC638, 0xCE38, 0xB574, 0x9CD3, 0xB5D7, 0xAD55, 0xAD76,
 0xB5B7, 0xB5B6, 0xA534, 0xB5B6, 0xAD75, 0xAD75, 0xAD75, 0xAD54, 0xAD54, 0xA534, 0xA554, 0x9CD2, 0x9CD3, 0x9CD3, 0x9CD3, 0x9CB2,
 0x9492, 0x8C91, 0x9CF3, 0x840F, 0x8C70, 0x8450, 0x7C0F, 0x7BEE, 0x738D, 0x6B4D, 0x632C, 0x5AEB, 0x5ACB, 0x4A69, 0x52AA, 0x528A,
 0x4A69, 0x4A69, 0x4207, 0x2985, 0x2985, 0x3185, 0x2965, 0x2144, 0x2165, 0x5B6E, 0x5AEC, 0x636D, 0x630B, 0x632B, 0x6B6C, 0x630B,
 0x62EB, 0x62EB, 0x630B, 0x630B, 0x630B, 0x62EB, 0x5AEB, 0x632C, 0x39E7, 0x3185, 0x29A5, 0x29A5, 0x2185, 0x2185, 0x2965, 0x4A27,
 0x4A28, 0x6B8D, 0x3208, 0x39E8, 0x736E, 0x734C, 0x8BCD, 0x738D, 0x4208, 0x3A08, 0x29A7, 0x31C7, 0x3A49, 0x31E7, 0x3228, 0x3229,
 0x2A07, 0x3228, 0x21E7, 0x3228, 0x3269, 0x3269, 0x31E7, 0x31A7, 0x31C7, 0x31C7, 0x31E7, 0x3207, 0x3A08, 0x39C7, 0x39C7, 0x31A7,
 0x3A07, 0x31C7, 0x3A08, 0x3A08, 0xD679, 0xCE38, 0xCE59, 0xCE9A, 0xCE79, 0xD69A, 0xD6BA, 0xE71C, 0xD6BA, 0xD699, 0xCE99, 0xC658,
 0xBDF7, 0xC618, 0xBDF7, 0xBDD6, 0xAD95, 0xAD55, 0xAD75, 0xB5B6, 0xB5B6, 0xB5B6, 0xAD55, 0xB596, 0xAD75, 0xAD54, 0xAD95, 0xAD95,
 0xA513, 0xA513, 0x9CF3, 0x9491, 0x9CB2, 0x9CD3, 0x94B2, 0x9492, 0x8C71, 0x8C71, 0x94B2, 0x8C50, 0x8C71, 0x8430, 0x7BCE, 0x73AD,
 0x7BCE, 0x6B6D, 0x632C, 0x630C, 0x5ACB, 0x52CA, 0x52AA, 0x5ACB, 0x528A, 0x528A, 0x41C7, 0x2985, 0x2965, 0x2985, 0x2985, 0x2144,
 0x2985, 0x530C, 0x52CB, 0x6B4D, 0x62EB, 0x6B6C, 0x6B2C, 0x6B4C, 0x630B, 0x6B2C, 0x5ACA, 0x630C, 0x5AAA, 0x62EB, 0x5ACA, 0x5AEB,
 0x3A07, 0x1903, 0x1903, 0x29A6, 0x2985, 0x2124, 0x5A89, 0x730C, 0x6B4D, 0x4A49, 0x31E7, 0x4229, 0x5AAB, 0x7B8D, 0x6B2D, 0x4208,
 0x31C6, 0x2986, 0x3208, 0x31E8, 0x3208, 0x29C6, 0x3A48, 0x2A08, 0x3248, 0x3AAA, 0x2207, 0x3228, 0x3A28, 0x2986, 0x21A6, 0x31E7,
 0x2985, 0x3A28, 0x31C7, 0x29A6, 0x39E7, 0x39E7, 0x39E8, 0x39E8, 0x4A8B, 0x4229, 0x4229, 0x7BAE, 0xD699, 0xCE38, 0xC617, 0xCE99,
 0xD69A, 0xCE59, 0xD69A, 0xD69A, 0xD699, 0xCE79, 0xCE59, 0xC638, 0xBE18, 0xBDF7, 0xBE18, 0xC638, 0xAD54, 0xA514, 0xAD75, 0xBDF7,
 0xB596, 0xAD96, 0xA554, 0xAD75, 0xAD75, 0xA554, 0xA534, 0xA554, 0xA514, 0xA534, 0x9CF3, 0x94B1, 0x94B2, 0x94D2, 0x9491, 0x9471,
 0x8C51, 0x9492, 0x94B2, 0x8C50, 0x8C50, 0x7C0F, 0x634C, 0x73AE, 0x73AE, 0x6B6D, 0x632C, 0x5AEB, 0x5AEB, 0x5AEB, 0x5ACA, 0x52AA,
 0x4228, 0x5289, 0x4207, 0x2984, 0x2965, 0x2965, 0x2965, 0x2944, 0x2986, 0x4ACB, 0x73CF, 0x5ACB, 0x6B2C, 0x6B6C, 0x5ACA, 0x630B,
 0x630B, 0x62EB, 0x6B4C, 0x5ACB, 0x630C, 0x630C, 0x62EB, 0x630B, 0x2144, 0x2144, 0x1904, 0x39A6, 0x2124, 0x2944, 0x39C6, 0x4A08,
 0x4208, 0x3186, 0x4A6A, 0x528A, 0x7B8C, 0x5289, 0x5B0C, 0x5AAA, 0x42AA, 0x29A7, 0x21A7, 0x29A6, 0x29C7, 0x2186, 0x3248, 0x19C6,
 0x21C6, 0x2A07, 0x21E7, 0x29C7, 0x29E7, 0x3A28, 0x21C6, 0x29E7, 0x29A6, 0x29C7, 0x31A7, 0x31A7, 0x31E7, 0x39C6, 0x31C6, 0x4269,
 0x39E7, 0x41E7, 0x3A08, 0xD6B8, 0xD679, 0xCE58, 0xC638, 0xC658, 0xD699, 0xCE58, 0xD699, 0xD679, 0xCE59, 0xCE58, 0xC638, 0xBDF7,
 0xBDF7, 0xB5B7, 0xB5B6, 0xBDD7, 0xB596, 0xA4F3, 0xAD54, 0xB5B6, 0xB5B6, 0xA575, 0xA554, 0xAD54, 0xAD75, 0xAD75, 0xA534, 0x9CF3,
 0x9CF3, 0x9CD2, 0x9CD2, 0x9CF2, 0x9CD2, 0x94D2, 0x8C71, 0x8C50, 0x8C92, 0x94B2, 0x8430, 0x8C71, 0x840F, 0x840F, 0x738D, 0x6B8D,
 0x6B6C, 0x6B4C, 0x632C, 0x630C, 0x5ACB, 0x632B, 0x52CA, 0x52CA, 0x39E7, 0x4228, 0x3185, 0x31A5, 0x2965, 0x2965, 0x2945, 0x2945,
 0x29C7, 0x530C, 0x4AEB, 0x6B4D, 0x6B2C, 0x6B4C, 0x630B, 0x5ACA, 0x5AEB, 0x62EB, 0x7BCE, 0x5ACA, 0x6B2C, 0x5ACA, 0x62CB, 0x62EB
};
#endif

// delay function for testing which delays n ms
// defined in ST7735.c and probably should not be public,
// but this is easier than using the SysTick or general-
// purpose timers
void Delay1ms(uint32_t n);

// private function draws a color band on the screen
void static drawthecolors(unsigned char red, unsigned char green, unsigned char blue){
  static uint16_t y = 0;
  ST7735_DrawFastHLine(0, y, ST7735_TFTWIDTH, ST7735_Color565(red, green, blue));
  y = y + 1;
  if(y >= ST7735_TFTHEIGHT){
     y = 0;
  }
  Delay1ms(10);
}
int main0(void){ // no PLL, 16 MHz
  PLL_Init();    // 120 MHz
  Output_Init();
  printf("hello world");
  while(1){
  }
} 
int main(void){uint32_t j; // main 1 
  PLL_Init();    // 120 MHz
  ST7735_InitR(INITR_REDTAB);
  ST7735_FillScreen(0);                 // set screen to black
  ST7735_OutString("Graphics test\n");
  ST7735_OutString("cubic function\n");
  ST7735_PlotClear(0,4095);  // range from 0 to 4095
  for(j=0;j<128;j++){
    ST7735_PlotPoints(j*j/2+900-(j*j/256)*j,32*j); // cubic,linear
    ST7735_PlotNext(); 
  }   // called 128 times
  while(1){
  }
}
int main2(void){  // main 2
  int32_t x, y, dx, dy;
  PLL_Init();    // 120 MHz
  // initialize user SW1 on PJ0
                                   // activate clock for Port J
  SYSCTL_RCGCGPIO_R |= SYSCTL_RCGCGPIO_R8;
                                   // allow time for clock to stabilize
  while((SYSCTL_PRGPIO_R&SYSCTL_PRGPIO_R8) == 0){};
  GPIO_PORTJ_DIR_R &= ~0x01;       // make PJ0 in (PJ0 built-in SW1)
  GPIO_PORTJ_AFSEL_R &= ~0x01;     // disable alt funct on PJ0
  GPIO_PORTJ_PUR_R |= 0x01;        // enable pull-up on PJ0
  GPIO_PORTJ_DEN_R |= 0x01;        // enable digital I/O on PJ0
                                   // configure PJ0 as GPIO
  GPIO_PORTJ_PCTL_R = (GPIO_PORTJ_PCTL_R&0xFFFFFFF0)+0x00000000;
  GPIO_PORTJ_AMSEL_R &= ~0x01;     // disable analog functionality on PJ0

  // test DrawChar() and DrawCharS()
  ST7735_InitR(INITR_REDTAB);
  ST7735_FillScreen(0);                 // set screen to black
  ST7735_DrawCharS(0, 0, 'c', ST7735_Color565(255, 0, 0), 0, 1);
  ST7735_DrawCharS(6, 0, 'h', ST7735_Color565(255, 128, 0), 0, 1);
  ST7735_DrawCharS(12, 0, 'a', ST7735_Color565(255, 255, 0), 0, 1);
  ST7735_DrawCharS(18, 0, 'r', ST7735_Color565(128, 255, 0), 0, 1);
  ST7735_DrawCharS(30, 0, 'T', ST7735_Color565(0, 255, 0), 0, 1);
  ST7735_DrawCharS(36, 0, 'E', ST7735_Color565(0, 255, 255), 0, 1);
  ST7735_DrawCharS(42, 0, 'S', ST7735_Color565(0, 0, 255), 0, 1);
  ST7735_DrawCharS(48, 0, 'T', ST7735_Color565(128, 0, 255), 0, 1);

  ST7735_DrawCharS(0, 8, 'c', ST7735_Color565(255, 0, 0), 0, 2);
  ST7735_DrawCharS(12, 8, 'h', ST7735_Color565(255, 128, 0), 0, 2);
  ST7735_DrawCharS(24, 8, 'a', ST7735_Color565(255, 255, 0), 0, 2);
  ST7735_DrawCharS(36, 8, 'r', ST7735_Color565(128, 255, 0), 0, 2);
  ST7735_DrawCharS(60, 8, 'T', ST7735_Color565(0, 255, 0), 0, 2);
  ST7735_DrawCharS(72, 8, 'E', ST7735_Color565(0, 255, 255), 0, 2);
  ST7735_DrawCharS(84, 8, 'S', ST7735_Color565(0, 0, 255), 0, 2);
  ST7735_DrawCharS(96, 8, 'T', ST7735_Color565(128, 0, 255), 0, 2);

  ST7735_DrawCharS(0, 24, 'c', ST7735_Color565(255, 0, 0), 0, 3);
  ST7735_DrawCharS(18, 24, 'h', ST7735_Color565(255, 128, 0), 0, 3);
  ST7735_DrawCharS(36, 24, 'a', ST7735_Color565(255, 255, 0), 0, 3);
  ST7735_DrawCharS(54, 24, 'r', ST7735_Color565(128, 255, 0), 0, 3);
  ST7735_DrawCharS(90, 24, 'T', ST7735_Color565(0, 255, 0), 0, 3);
  ST7735_DrawCharS(108, 24, 'E', ST7735_Color565(0, 255, 255), 0, 3);
  ST7735_DrawCharS(126, 24, 'S', ST7735_Color565(0, 0, 255), 0, 3); // off the screen
  ST7735_DrawCharS(144, 24, 'T', ST7735_Color565(128, 0, 255), 0, 3); // totally off the screen

  ST7735_DrawCharS(0, 48, 'c', ST7735_Color565(255, 0, 0), 0, 4);
  ST7735_DrawCharS(24, 48, 'h', ST7735_Color565(255, 128, 0), 0, 4);
  ST7735_DrawCharS(48, 48, 'a', ST7735_Color565(255, 255, 0), 0, 4);
  ST7735_DrawCharS(72, 48, 'r', ST7735_Color565(128, 255, 0), 0, 4);
  ST7735_DrawCharS(120, 48, 'T', ST7735_Color565(0, 255, 0), 0, 4); // off the screen
  ST7735_DrawCharS(144, 48, 'E', ST7735_Color565(0, 255, 255), 0, 4); // totally off the screen
  ST7735_DrawCharS(168, 48, 'S', ST7735_Color565(0, 0, 255), 0, 4); // totally off the screen
  ST7735_DrawCharS(192, 48, 'T', ST7735_Color565(128, 0, 255), 0, 4); // totally off the screen

  ST7735_DrawCharS(0, 80, 'c', ST7735_Color565(255, 0, 0), 0, 6);
  ST7735_DrawCharS(36, 80, 'h', ST7735_Color565(255, 128, 0), 0, 6);
  ST7735_DrawCharS(72, 80, 'a', ST7735_Color565(255, 255, 0), 0, 6);
  ST7735_DrawCharS(108, 80, 'r', ST7735_Color565(128, 255, 0), 0, 6); // off the screen

  ST7735_DrawChar(0, 135, 'A', ST7735_Color565(255, 128, 128), 0, 2);
  ST7735_DrawChar(12, 135, 'd', ST7735_Color565(255, 0, 0), 0, 2);
  ST7735_DrawChar(24, 135, 'v', ST7735_Color565(255, 128, 0), 0, 2);
  ST7735_DrawChar(48, 135, 'c', ST7735_Color565(255, 255, 0), 0, 2);
  ST7735_DrawChar(60, 135, 'h', ST7735_Color565(128, 255, 0), 0, 2);
  ST7735_DrawChar(72, 135, 'a', ST7735_Color565(0, 255, 0), 0, 2);
  ST7735_DrawChar(84, 135, 'r', ST7735_Color565(0, 255, 255), 0, 2);
  ST7735_DrawChar(108, 135, 't', ST7735_Color565(0, 0, 255), 0, 2);
  ST7735_DrawChar(120, 135, 'e', ST7735_Color565(128, 0, 255), 0, 2); // off the screen
  ST7735_DrawChar(132, 135, 's', ST7735_Color565(255, 0, 255), 0, 2); // totally off the screen
  ST7735_DrawChar(144, 135, 't', ST7735_Color565(255, 255, 255), 0, 2); // totally off the screen

  ST7735_DrawChar(0, 151, 'A', ST7735_Color565(255, 128, 128), 0, 1);
  ST7735_DrawChar(6, 151, 'd', ST7735_Color565(255, 0, 0), 0, 1);
  ST7735_DrawChar(12, 151, 'v', ST7735_Color565(255, 128, 0), 0, 1);
  ST7735_DrawChar(24, 151, 'c', ST7735_Color565(255, 255, 0), 0, 1);
  ST7735_DrawChar(30, 151, 'h', ST7735_Color565(128, 255, 0), 0, 1);
  ST7735_DrawChar(36, 151, 'a', ST7735_Color565(0, 255, 0), 0, 1);
  ST7735_DrawChar(42, 151, 'r', ST7735_Color565(0, 255, 255), 0, 1);
  ST7735_DrawChar(54, 151, 't', ST7735_Color565(0, 0, 255), 0, 1);
  ST7735_DrawChar(60, 151, 'e', ST7735_Color565(128, 0, 255), 0, 1);
  ST7735_DrawChar(66, 151, 's', ST7735_Color565(255, 0, 255), 0, 1);
  ST7735_DrawChar(72, 151, 't', ST7735_Color565(255, 255, 255), 0, 1);
  Delay1ms(500);
  while(GPIO_PORTJ0 == 0x01){};    // wait for button press

  // test DrawBitmap() including clipping test with images off the screen
  ST7735_FillScreen(0xFFFF);            // set screen to white
  ST7735_DrawBitmap(0, 5, Test2, 5, 6);   // top left corner of the screen
  ST7735_DrawBitmap(59, 74, Test2, 5, 6); // center of the screen
  ST7735_DrawBitmap(125, 74, Test2, 5, 6);// clip right
  ST7735_DrawBitmap(59, 162, Test2, 5, 6);// clip bottom
  ST7735_DrawBitmap(-2, 74, Test2, 5, 6); // clip left
  ST7735_DrawBitmap(59, 2, Test2, 5, 6);  // clip top
  Delay1ms(500);
  while(GPIO_PORTJ0 == 0x01){};    // wait for button press

#if (FREE == 0)
  ST7735_FillScreen(0xFFFF);            // set screen to white
  ST7735_DrawBitmap(4, 159, Calvin, 120, 160);
  Delay1ms(500);
  while(GPIO_PORTJ0 == 0x01){};    // wait for button press
#endif

  ST7735_FillScreen(0xFFFF);            // set screen to white
  x = 44;
  y = 159;
  dx = 1;
  dy = 1;
  while(1){
    ST7735_DrawBitmap(x, y, Logo, 40, 160);
    x = x + dx;
    y = y + dy;
    if((x >= (ST7735_TFTWIDTH - 40 + 15)) || (x <= -15)){
      dx = -1*dx;
    }
    if((y >= (ST7735_TFTHEIGHT + 8)) || (y <= (ST7735_TFTHEIGHT - 8))){
      dy = -1*dy;
    }
  }
}
int main3(void){  // main 3
  uint8_t red, green, blue;
  PLL_Init();    // 120 MHz

  ST7735_InitR(INITR_REDTAB);
  ST7735_FillScreen(0);                 // set screen to black

  // test display with a colorful demo
  red = 255;
  green = 0;
  blue = 0;
  while(1){
    // transition from red to yellow by increasing green
    for(green=0; green<255; green=green+1){
      drawthecolors(red, green, blue);
    }
    // transition from yellow to green by decreasing red
    for(red=255; red>0; red=red-1){
      drawthecolors(red, green, blue);
    }
    // transition from green to light blue by increasing blue
    for(blue=0; blue<255; blue=blue+1){
      drawthecolors(red, green, blue);
    }
    // transition from light blue to true blue by decreasing green
    for(green=255; green>0; green=green-1){
      drawthecolors(red, green, blue);
    }
    // transition from true blue to pink by increasing red
    for(red=0; red<255; red=red+1){
      drawthecolors(red, green, blue);
    }
    // transition from pink to red by decreasing blue
    for(blue=255; blue>0; blue=blue-1){
      drawthecolors(red, green, blue);
    }
  }
}


void BookExamples(void){ // examples from the book
  char cc = 0x56; // (V)
  int32_t xx = 100;
  int16_t yy = -100;
  float zz = 3.14159265;
  printf("Hello world\n");	    //Hello world
  printf("cc = %c %d\n",cc,cc);	//cc = V 86 
  printf("cc = %#x\n",cc);	    //cc = 0x56
  printf("xx = %c %d\n",xx,xx);	//xx = d 100 
  printf("xx = %#x\n",xx);	    //xx = 0x64
  printf("yy = %d\n",yy);	      //yy = -100 
  printf("%#x   \n",yy);	      //yy = 0xffffff9c
  printf("%e \n",zz);	          //zz = 3.14159e+00
  printf("%E \n",zz);	          //zz = 3.14159E+00
  printf("%f     \n",zz);	      //zz = 3.14159
  printf("%g     \n",zz);	      //zz = 3.14159 (shorter of two, either f or e)
  printf("%3.2f     \n",zz);	  //zz =  3.14
}

int main4(void){ int32_t i,n; // main 4
  PLL_Init();    // 120 MHz
  Output_Init();              // initialize output device
  Output_Color(ST7735_YELLOW);
  BookExamples();
  n = 0;
  while(1){
    printf("\ni="); 
    for(i=0; i<1; i++){
      printf("%d ",i+n);
    }

    n = n+10000000; // notice what happens when this goes above 2,147,483,647
  }
}

